@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 15e69cbabfcf2da9c6f8ab4b90cbd369915d7e1a $
+// $Id: a1a6e21e1beda33ffefa67289230338766776d45 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -569,12 +569,6 @@ class BootWindow : public Fl_Window
 		scannedIWAD_t iwad = m_IWADs[value - 1];
 		g_SelectedWADs.iwad = iwad.path;
 
-		if (iwad.id != NULL && iwad.id->mIdName == "CHEX QUEST")
-		{
-			g_SelectedWADs.options.push_back("-deh");
-			g_SelectedWADs.options.push_back("chex.deh");
-		}
-
 		// PWADs
 		for (const auto& pwad : m_selectedPWADs)
 		{
