@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f3bb6391efb8c9b6bb674bbb43252b16503d5ca0 $
+// $Id: 1746cb8c159fbefac706de386a1fcae046f0c5e9 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -28,7 +28,7 @@
 
 #include "gui_resource.h"
 
-#if defined(_WIN32) && !defined(_XBOX)
+#if defined(_WIN32)
 
 #include "FL/x.H"
 #include "win32inc.h"
