@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 37eeb85369f789e5e544df2f30521719cf3facd1 $
+// $Id: 34fe35a31574bf15277c27976713c8fd6db2fa19 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -42,15 +42,11 @@
 #include "i_system.h"
 #include "hu_stuff.h"
 
-#ifdef _XBOX
-	#include "i_xbox.h"
-#elif __SWITCH__
+#ifdef __SWITCH__
 	#include "nx_io.h"
 #endif
 
-#if defined(SDL12)
-#include "i_input_sdl12.h"
-#elif defined(SDL20)
+#if defined(SDL20)
 #include "i_input_sdl20.h"
 #endif
 
@@ -594,9 +590,7 @@ bool I_InitInput()
 
 	atterm(I_ShutdownInput);
 
-	#if defined(SDL12)
-	input_subsystem = new ISDL12InputSubsystem();
-	#elif defined(SDL20)
+	#ifdef SDL20
 	input_subsystem = new ISDL20InputSubsystem();
 	#endif
 
@@ -924,4 +918,4 @@ void IInputSubsystem::getEvent(event_t* ev)
 }
 
 
-VERSION_CONTROL (i_input_cpp, "$Id: 37eeb85369f789e5e544df2f30521719cf3facd1 $")
+VERSION_CONTROL (i_input_cpp, "$Id: 34fe35a31574bf15277c27976713c8fd6db2fa19 $")
