@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: fe1ec65db9481a748165e236f008cee8bd2418bb $
+// $Id: 78fa95386b40a4a2767ec906708892dcad0031bc $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -433,13 +433,24 @@ void ISDL20MouseInputDevice::resume()
 {
 	mActive = true;
 	reset();
+
+	// [RV] Always use relative mouse mode and
+	// force unscaled relative motion across supported SDL versions
 	SDL_SetRelativeMouseMode(SDL_TRUE);
+
+	#if SDL_VERSION_ATLEAST(2, 0, 14)
+		SDL_SetHintWithPriority(SDL_HINT_MOUSE_RELATIVE_SCALING, "0", SDL_HINT_OVERRIDE);
+	#endif
+
+	#if SDL_VERSION_ATLEAST(2, 26, 0)
+		SDL_SetHintWithPriority(SDL_HINT_MOUSE_RELATIVE_SYSTEM_SCALE, "0", SDL_HINT_OVERRIDE);
+	#endif
+
 	SDL_EventState(SDL_MOUSEMOTION, SDL_ENABLE);
 	SDL_EventState(SDL_MOUSEBUTTONDOWN, SDL_ENABLE);
 	SDL_EventState(SDL_MOUSEBUTTONUP, SDL_ENABLE);
 }
 
-
 //
 // ISDL20MouseInputDevice::gatherEvents
 //
@@ -1043,4 +1054,4 @@ void ISDL20InputSubsystem::releaseInput()
 
 #endif	// SDL20
 
-VERSION_CONTROL(i_input_sdl20_cpp, "$Id: fe1ec65db9481a748165e236f008cee8bd2418bb $")
+VERSION_CONTROL(i_input_sdl20_cpp, "$Id: 78fa95386b40a4a2767ec906708892dcad0031bc $")
