@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 7dd21986831e7f75442eebbfa975370409cbac77 $
+// $Id: 5f43c930bcd4d15b5c246a23b4cd70552d1e8260 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -25,17 +25,6 @@
 
 #include "odamex.h"
 
-// denis - todo - remove
-#include "win32inc.h"
-#ifdef _WIN32
-    #ifndef _XBOX
-        #undef GetMessage
-        typedef bool (WINAPI *SetAffinityFunc)(HANDLE hProcess, DWORD mask);
-    #endif // !_XBOX
-#else
-    #include <sched.h>
-#endif // WIN32
-
 #ifdef UNIX
 // for getuid and geteuid
 #include <unistd.h>
@@ -64,10 +53,6 @@
 #include "c_console.h"
 #include "z_zone.h"
 
-#ifdef _XBOX
-#include "i_xbox.h"
-#endif
-
 // Use main() on windows for msvc
 #if defined(_MSC_VER) && !defined(GCONSOLE)
 #    pragma comment(linker, "/subsystem:windows /ENTRY:mainCRTStartup")
@@ -172,82 +157,22 @@ int main(int argc, char *argv[])
 		// denis - if argv[1] starts with "odamex://"
 		if(argc == 2 && argv && argv[1])
 		{
-			const char *protocol = "odamex://";
-			const char *uri = argv[1];
+			static constexpr std::string_view protocol = "odamex://";
+			std::string_view uri = argv[1];
 
-			if(strncmp(uri, protocol, strlen(protocol)) == 0)
+			if(uri.substr(0, protocol.length()) == protocol)
 			{
-				std::string location = uri + strlen(protocol);
+				std::string_view location = uri.substr(protocol.length());
 				size_t term = location.find_first_of('/');
 
 				if(term == std::string::npos)
 					term = location.length();
 
 				Args.AppendArg("-connect");
-				Args.AppendArg(location.substr(0, term).c_str());
+				Args.AppendArg(std::string(location.substr(0, term)).c_str());
 			}
 		}
 
-#if defined(SDL12)
-        // [Russell] - No more double-tapping of capslock to enable autorun
-        SDL_putenv((char*)"SDL_DISABLE_LOCK_KEYS=1");
-
-		// Set SDL video centering
-		SDL_putenv((char*)"SDL_VIDEO_WINDOW_POS=center");
-		SDL_putenv((char*)"SDL_VIDEO_CENTERED=1");
-#endif
-
-#if defined _WIN32 && !defined _XBOX
-
-	#if defined(SDL12)
-    	// From the SDL 1.2.10 release notes:
-    	//
-    	// > The "windib" video driver is the default now, to prevent
-    	// > problems with certain laptops, 64-bit Windows, and Windows
-    	// > Vista.
-    	//
-    	// The hell with that.
-
-   		// SoM: the gdi interface is much faster for windowed modes which are more
-   		// commonly used. Thus, GDI is default.
-		//
-		// GDI mouse issues fill many users with great sadness. We are going back
-		// to directx as defulat for now and the people will rejoice. --Hyper_Eye
-     	if (Args.CheckParm ("-gdi"))
-        	putenv((char*)"SDL_VIDEODRIVER=windib");
-    	else
-        	putenv((char*)"SDL_VIDEODRIVER=directx");
-	#endif	// SDL12
-
-
-        // Set the process affinity mask to 1 on Windows, so that all threads
-        // run on the same processor.  This is a workaround for a bug in
-        // SDL_mixer that causes occasional crashes.  Thanks to entryway and fraggle for this.
-        //
-        // [ML] 8/6/10: Updated to match prboom+'s I_SetAffinityMask.  We don't do everything
-        // you might find in there but we do enough for now.
-        HMODULE kernel32_dll = LoadLibrary("kernel32.dll");
-
-        if (kernel32_dll)
-        {
-            SetAffinityFunc SetAffinity = (SetAffinityFunc)GetProcAddress(kernel32_dll, "SetProcessAffinityMask");
-
-            if (SetAffinity)
-            {
-                if (!SetAffinity(GetCurrentProcess(), 1))
-                    LOG << "Failed to set process affinity mask: " << GetLastError() << std::endl;
-            }
-        }
-#endif	// _WIN32 && !_XBOX
-
-#ifdef X11
-	#if defined(SDL12)
-		// [SL] 2011-12-21 - Ensure we're getting raw DGA mouse input from X11,
-		// bypassing X11's mouse acceleration
-		putenv((char*)"SDL_VIDEO_X11_DGAMOUSE=1");
-	#endif	// SDL12
-#endif	// X11
-
 		unsigned int sdl_flags = SDL_INIT_TIMER;
 
 #ifdef _MSC_VER
@@ -316,4 +241,4 @@ int main(int argc, char *argv[])
 	return 0;
 }
 
-VERSION_CONTROL (i_main_cpp, "$Id: 7dd21986831e7f75442eebbfa975370409cbac77 $")
+VERSION_CONTROL (i_main_cpp, "$Id: 5f43c930bcd4d15b5c246a23b4cd70552d1e8260 $")
