@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b8b970c84ee228d00c65fa558776fa3b69e2026f $
+// $Id: 0123a88ef796a990d10a5f32f31f1fef59d12d29 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -387,7 +387,7 @@ static std::list<MidiEvent*> *I_ReadMidiTrack(MEMFILE *mf)
 
 	if (chunkheader.chunk_id != cTrackChunkId)
 	{
-		Printf(PRINT_WARNING, "I_ReadMidiTrack: Unexpected chunk header ID\n");
+		PrintFmt(PRINT_WARNING, "I_ReadMidiTrack: Unexpected chunk header ID\n");
 		return NULL;
 	}
 
@@ -400,7 +400,7 @@ static std::list<MidiEvent*> *I_ReadMidiTrack(MEMFILE *mf)
 
 		if (!newevent)
 		{
-			Printf(PRINT_WARNING, "I_ReadMidiTrack: Unable to read MIDI event\n");
+			PrintFmt(PRINT_WARNING, "I_ReadMidiTrack: Unable to read MIDI event\n");
 
 			I_ClearMidiEventList(eventlist);
 			delete eventlist;
@@ -484,7 +484,7 @@ void MidiSong::_ParseSong(MEMFILE *mf)
 
 	if (chunkheader.chunk_id != cHeaderChunkId)
 	{
-		Printf(PRINT_WARNING, "MidiSong::_ParseSong: Unexpected file header ID\n");
+		PrintFmt(PRINT_WARNING, "MidiSong::_ParseSong: Unexpected file header ID\n");
 		return;
 	}
 
@@ -499,7 +499,7 @@ void MidiSong::_ParseSong(MEMFILE *mf)
 
 	if (fileheader.format_type != 0 && fileheader.format_type != 1)
 	{
-		Printf(PRINT_WARNING, "MidiSong::_ParseSong: Only type 0 or type 1 MIDI files are supported.\n");
+		PrintFmt(PRINT_WARNING, "MidiSong::_ParseSong: Only type 0 or type 1 MIDI files are supported.\n");
 		return;
 	}
 
@@ -509,7 +509,7 @@ void MidiSong::_ParseSong(MEMFILE *mf)
 		std::list<MidiEvent*> *eventlist = I_ReadMidiTrack(mf);
 		if (!eventlist)
 		{
-			Printf(PRINT_WARNING, "MidiSong::_ParseSong: Error reading track %lu.\n", i + 1);
+			PrintFmt(PRINT_WARNING, "MidiSong::_ParseSong: Error reading track {}.\n", i + 1);
 			return;
 		}
 
@@ -838,4 +838,4 @@ void I_MidiInitFallback()
 		variation[127][program] = 1;
 }
 
-VERSION_CONTROL (i_midi_cpp, "$Id: b8b970c84ee228d00c65fa558776fa3b69e2026f $")
+VERSION_CONTROL (i_midi_cpp, "$Id: 0123a88ef796a990d10a5f32f31f1fef59d12d29 $")
