@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 69f1b5068bff32f0a492e3575be82050839ea4f7 $
+// $Id: 1bf6b99d2ebdb3dbf6deac954356128cddd16e70 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -24,7 +24,7 @@
 #include "odamex.h"
 
 #include "win32inc.h"
-#if defined(_WIN32) && !defined(_XBOX)
+#if defined(_WIN32)
 #include <mmsystem.h>
 #endif
 
@@ -46,7 +46,7 @@ MusicSystem* musicsystem = NULL;
 MusicSystemType current_musicsystem_type = MS_NONE;
 
 void S_StopMusic();
-void S_ChangeMusic (std::string musicname, bool looping);
+void S_ChangeMusic (std::string musicname, bool looping, int order = 0);
 
 EXTERN_CVAR (snd_musicvolume)
 EXTERN_CVAR (snd_musicsystem)
@@ -142,7 +142,7 @@ bool S_MusicIsWave(byte* data, size_t length)
 //
 void I_ResetMidiVolume()
 {
-	#if defined(_WIN32) && !defined(_XBOX)
+	#if defined(_WIN32)
 	SDL_LockAudio();
 
 	for (UINT device = MIDI_MAPPER; device != midiOutGetNumDevs(); device++)
@@ -288,7 +288,7 @@ static MusicSystemType I_SelectMusicSystem(byte *data, size_t length)
 	return MS_SDLMIXER;
 }
 
-void I_PlaySong(const OByteSpan data, const bool loop)
+void I_PlaySong(const OByteSpan data, const bool loop, const int order)
 {
 	if (!musicsystem)
 		return;
@@ -304,7 +304,7 @@ void I_PlaySong(const OByteSpan data, const bool loop)
 		I_InitMusic(newtype);
 	}
 
-	musicsystem->startSong(data.data(), data.size(), loop);
+	musicsystem->startSong(data.data(), data.size(), loop, order);
 
 	// Hack for problems with Windows Vista/7 & SDL_Mixer
 	// See comment for I_ResetMidiVolume().
@@ -339,4 +339,4 @@ bool I_QrySongPlaying (int handle)
 	return false;
 }
 
-VERSION_CONTROL (i_music_cpp, "$Id: 69f1b5068bff32f0a492e3575be82050839ea4f7 $")
+VERSION_CONTROL (i_music_cpp, "$Id: 1bf6b99d2ebdb3dbf6deac954356128cddd16e70 $")
