@@ -1,7 +1,7 @@
-// Emacs style mode select   -*- C++ -*- 
+// Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: dfd1e1b08df39d25f13397a0fb694462b8097b8a $
+// $Id: e2df1e566593b7b8ca8f732a484064d7a0dbc2c5 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -68,7 +68,7 @@ void I_ResumeSong();
 //  plays a song, and when the song is done,
 //  starts playing it again in an endless loop.
 // Horrible thing to do, considering.
-void I_PlaySong(const OByteSpan data, const bool loop);
+void I_PlaySong(const OByteSpan data, const bool loop, const int order);
 // Stops a song over 3 seconds.
 void I_StopSong();
 void I_UpdateMusic();
