@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 2e2e133846e79a3d139e3ea28fb71016e67105ca $
+// $Id: 71117888f3f904c9ef76bd304634d312f2e84a3e $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -34,7 +34,7 @@ class MusicSystem
 	MusicSystem() { }
 	virtual ~MusicSystem() { }
 
-	virtual void startSong(byte* data, size_t length, bool loop);
+	virtual void startSong(byte* data, size_t length, bool loop, int order);
 	virtual void stopSong();
 	virtual void pauseSong();
 	virtual void resumeSong();
@@ -74,10 +74,10 @@ class SilentMusicSystem : public MusicSystem
   public:
 	SilentMusicSystem()
 	{
-		Printf(PRINT_WARNING, "I_InitMusic: Music playback disabled.\n");
+		PrintFmt(PRINT_WARNING, "I_InitMusic: Music playback disabled.\n");
 	}
 
-	void startSong(byte* data, size_t length, bool loop) override { }
+	void startSong(byte* data, size_t length, bool loop, int order) override { }
 	void stopSong() override { }
 	void pauseSong() override { }
 	void resumeSong() override { }
@@ -109,7 +109,7 @@ class MidiMusicSystem : public MusicSystem
 	MidiMusicSystem();
 	~MidiMusicSystem() override;
 
-	void startSong(byte* data, size_t length, bool loop) override;
+	void startSong(byte* data, size_t length, bool loop, int order) override;
 	void stopSong() override;
 	void pauseSong() override;
 	void resumeSong() override;
