@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 1712a13603ec1f042f86c73f0cf70b48c90ed7ec $
+// $Id: 9005371a36e8f96ede3682eea0a71cf2d705ed51 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -43,7 +43,7 @@ class AuMusicSystem : public MusicSystem
 	AuMusicSystem();
 	~AuMusicSystem() override;
 
-	void startSong(byte* data, size_t length, bool loop) override;
+	void startSong(byte* data, size_t length, bool loop, int order) override;
 	void stopSong() override;
 	void pauseSong() override;
 	void resumeSong() override;
