@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: e404c3f3be716c5d9f6ada389bf986e96deddc97 $
+// $Id: 86b8cefa28aaf11f14247a5f4a593f2287942f23 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -37,7 +37,7 @@ class PortMidiMusicSystem : public MidiMusicSystem
 	PortMidiMusicSystem();
 	~PortMidiMusicSystem() override;
 
-	void startSong(byte *data, size_t length, bool loop) override;
+	void startSong(byte *data, size_t length, bool loop, int order) override;
 	void stopSong() override;
 	void pauseSong() override;
 	void restartSong() override;
