@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 3a4c7f21f90e9a2c65f3f1167da76e173d0a4e17 $
+// $Id: 8eff99bd5f45fb528e4f38dc741d16f1d11dae3b $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -37,7 +37,7 @@ class SdlMixerMusicSystem : public MusicSystem
 	SdlMixerMusicSystem();
 	~SdlMixerMusicSystem() override;
 
-	void startSong(byte* data, size_t length, bool loop) override ;
+	void startSong(byte* data, size_t length, bool loop, int order) override ;
 	void stopSong() override ;
 	void pauseSong() override ;
 	void resumeSong() override ;
