@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: fd29451d5e98989380624e18e397cf11486ff46b $
+// $Id: 9dc78160f06669d0d4f12e67a4f886e71043be10 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -25,7 +25,9 @@
 
 #include <SDL.h>
 
-#if (SDL_MAJOR_VERSION == 2)
+#if (SDL_MAJOR_VERSION == 3)
+	#define SDL3
+#elif (SDL_MAJOR_VERSION == 2)
 	#define SDL20
 	#if (SDL_MINOR_VERSION > 0 || SDL_PATCHLEVEL >= 16)
 		#define SDL2016
