@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: ffb9794a37d1623f2ca45001148cb909fde5ef39 $
+// $Id: aef606bb6467dba3ba2cc9759983c50b87574a91 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -95,21 +95,21 @@ void I_BaseError(const std::string& errortext);
 [[noreturn]] void I_BaseFatalError(const std::string& errortext);
 
 template <typename... ARGS>
-void I_Warning(const fmt::string_view format, const ARGS&... args)
+void I_Warning(fmt::format_string<ARGS...> format, ARGS&&... args)
 {
-	I_BaseWarning(fmt::format(format, args...));
+	I_BaseWarning(fmt::format(format, std::forward<ARGS>(args)...));
 }
 
 template <typename... ARGS>
-void I_Error(const fmt::string_view format, const ARGS&... args)
+void I_Error(fmt::format_string<ARGS...> format, ARGS&&... args)
 {
-	I_BaseError(fmt::format(format, args...));
+	I_BaseError(fmt::format(format, std::forward<ARGS>(args)...));
 }
 
 template <typename... ARGS>
-[[noreturn]] void I_FatalError(const fmt::string_view format, const ARGS&... args)
+[[noreturn]] void I_FatalError(fmt::format_string<ARGS...> format, ARGS&&... args)
 {
-	I_BaseFatalError(fmt::format(format, args...));
+	I_BaseFatalError(fmt::format(format, std::forward<ARGS>(args)...));
 }
 
 void addterm (void (STACK_ARGS *func)(void), const char *name);
