@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f92ae62e5be8cb0415343d6ea3e52d3187df96c4 $
+// $Id: 87930b3a95b511873c8544546c6c79d283c88425 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -33,9 +33,7 @@
 #include "i_video.h"
 #include "v_video.h"
 
-#if defined(SDL12)
-#include "i_video_sdl12.h"
-#elif defined(SDL20)
+#if defined(SDL20)
 #include "i_video_sdl20.h"
 #else
 #error "no video subsystem selected"
@@ -51,15 +49,12 @@
 
 // [Russell] - Just for windows, display the icon in the system menu and
 // alt-tab display
-#if defined(_WIN32) && !defined(_XBOX)
+#if defined(_WIN32)
 	#include "win32inc.h"
     #include "SDL_syswm.h"
     #include "resource.h"
 #endif	// _WIN32
 
-// Declared in doomtype.h as part of argb_t
-uint8_t argb_t::a_num, argb_t::r_num, argb_t::g_num, argb_t::b_num;
-
 // Global IVideoSubsystem instance for video startup and shutdown
 static IVideoSubsystem* video_subsystem = NULL;
 
@@ -934,9 +929,7 @@ void I_InitHardware()
 	}
 	else
 	{
-		#if defined(SDL12)
-		video_subsystem = new ISDL12VideoSubsystem();
-		#elif defined(SDL20)
+		#if defined(SDL20)
 		video_subsystem = new ISDL20VideoSubsystem();
 		#endif
 		assert(video_subsystem != NULL);
@@ -1431,4 +1424,4 @@ int I_GetAspectCorrectWidth(int surface_height, int asset_height, int asset_widt
 	return aspect_scale_ratio * asset_width;
 }
 
-VERSION_CONTROL (i_video_cpp, "$Id: f92ae62e5be8cb0415343d6ea3e52d3187df96c4 $")
+VERSION_CONTROL (i_video_cpp, "$Id: 87930b3a95b511873c8544546c6c79d283c88425 $")
