@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 8b08715e10455f4cbdc952eda7168d6b6fb45f96 $
+// $Id: cc47b67a40d723d67ea4e38481f0c44c899acbf5 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -122,10 +122,11 @@ public:
 	bool isFullScreen() const
 	{	return window_mode != WINDOW_Windowed;	}
 
+	[[nodiscard]]
 	bool operator==(const IVideoMode& other) const
 	{
 		return width == other.width && height == other.height &&
-			bpp == other.bpp && 
+			bpp == other.bpp &&
 			window_mode == other.window_mode &&
 			vsync == other.vsync &&
 			stretch_mode == other.stretch_mode;
@@ -232,23 +233,13 @@ public:
 	virtual bool supports8bpp() const
 	{
 		const IVideoModeList* modelist = getSupportedVideoModes();
-		for (IVideoModeList::const_iterator it = modelist->begin(); it != modelist->end(); ++it)
-		{
-			if (it->bpp == 8)
-				return true;
-		}
-		return false;
+		return std::any_of(modelist->cbegin(), modelist->cend(), [](const auto& mode){ return mode.bpp == 8; });
 	}
 
 	virtual bool supports32bpp() const
 	{
 		const IVideoModeList* modelist = getSupportedVideoModes();
-		for (IVideoModeList::const_iterator it = modelist->begin(); it != modelist->end(); ++it)
-		{
-			if (it->bpp == 32)
-				return true;
-		}
-		return false;
+		return std::any_of(modelist->cbegin(), modelist->cend(), [](const auto& mode){ return mode.bpp == 32; });
 	}
 
 	virtual const IVideoMode& getNativeMode() const = 0;
@@ -318,7 +309,7 @@ public:
 
 	inline uint8_t* getBuffer()
 	{
-		return const_cast<uint8_t*>(static_cast<const IWindowSurface&>(*this).getBuffer());
+		return const_cast<uint8_t*>(std::as_const(*this).getBuffer());
 	}
 
 	inline const uint8_t* getBuffer(uint16_t x, uint16_t y) const
@@ -328,7 +319,7 @@ public:
 
 	inline uint8_t* getBuffer(uint16_t x, uint16_t y)
 	{
-		return const_cast<uint8_t*>(static_cast<const IWindowSurface&>(*this).getBuffer(x, y));
+		return const_cast<uint8_t*>(std::as_const(*this).getBuffer(x, y));
 	}
 
 	inline uint16_t getWidth() const
@@ -424,7 +415,7 @@ public:
 
 	virtual IWindowSurface* getWindowSurface()
 	{
-		return const_cast<IWindowSurface*>(static_cast<const IWindowSurfaceManager&>(*this).getWindowSurface());
+		return const_cast<IWindowSurface*>(std::as_const(*this).getWindowSurface());
 	}
 
 	virtual void lockSurface() { }
@@ -492,7 +483,7 @@ public:
 
 	virtual IWindowSurface* getPrimarySurface()
 	{
-		return const_cast<IWindowSurface*>(static_cast<const IWindow&>(*this).getPrimarySurface());
+		return const_cast<IWindowSurface*>(std::as_const(*this).getPrimarySurface());
 	}
 
 	virtual uint16_t getWidth() const
@@ -635,7 +626,7 @@ public:
 
 	virtual IWindow* getWindow()
 	{
-		return const_cast<IWindow*>(static_cast<const IVideoSubsystem&>(*this).getWindow());
+		return const_cast<IWindow*>(std::as_const(*this).getWindow());
 	}
 
 	virtual int getMonitorCount() const
