@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 26ac9006be9c82a61cb1f312a280e169a3f973ec $
+// $Id: 99d38c1cb9fe2f702277197f33d7dbead4a1482c $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -44,15 +44,11 @@
 
 // [Russell] - Just for windows, display the icon in the system menu and alt-tab display
 #include "win32inc.h"
-#if defined(_WIN32) && !defined(_XBOX)
+#if defined(_WIN32)
     #include <SDL_syswm.h>
     #include "resource.h"
 #endif // WIN32
 
-#ifdef _XBOX
-#include "i_xbox.h"
-#endif
-
 EXTERN_CVAR (vid_fullscreen)
 EXTERN_CVAR (vid_widescreen)
 EXTERN_CVAR (vid_pillarbox)
@@ -395,7 +391,7 @@ ISDL20Window::ISDL20Window(uint16_t width, uint16_t height, uint8_t bpp, EWindow
 {
 	setRendererDriver();
 	const char* driver_name = getRendererDriver();
-	Printf(PRINT_HIGH, "V_Init: rendering mode \"%s\"\n", driver_name);
+	PrintFmt(PRINT_HIGH, "V_Init: rendering mode \"{}\"\n", driver_name);
 
 	SDL_SetHint(SDL_HINT_VIDEO_MINIMIZE_ON_FOCUS_LOSS, "0");
 
@@ -664,7 +660,7 @@ void ISDL20Window::setWindowTitle(const std::string& str)
 //
 void ISDL20Window::setWindowIcon()
 {
-	#if defined(_WIN32) && !defined(_XBOX)
+	#if defined(_WIN32)
 	// [SL] Use Win32-specific code to make use of multiple-icon sizes
 	// stored in the executable resources.
 	//
@@ -686,9 +682,9 @@ void ISDL20Window::setWindowIcon()
 			SendMessage(WindowHandle, WM_SETICON, ICON_BIG, (LPARAM)hIcon);
 		}
 	}
-	#endif	// _WIN32 && !_XBOX
+	#endif	// _WIN32
 
-	#if !defined(_WIN32) && !defined(_XBOX)
+	#if !defined(_WIN32)
 	SDL_Surface* icon_surface = SDL_CreateRGBSurfaceFrom(
 											(void*)app_icon.pixel_data, app_icon.width, app_icon.height,
 											app_icon.bytes_per_pixel * 8, app_icon.width * app_icon.bytes_per_pixel,
@@ -696,7 +692,7 @@ void ISDL20Window::setWindowIcon()
 
 	SDL_SetWindowIcon(mSDLWindow, icon_surface);
 	SDL_FreeSurface(icon_surface);
-	#endif	// !_WIN32 && !_XBOX
+	#endif	// !_WIN32
 }
 
 
@@ -1014,4 +1010,4 @@ int ISDL20VideoSubsystem::getMonitorCount() const
 }
 #endif	// SDL20
 
-VERSION_CONTROL (i_video_sdl20_cpp, "$Id: 26ac9006be9c82a61cb1f312a280e169a3f973ec $")
+VERSION_CONTROL (i_video_sdl20_cpp, "$Id: 99d38c1cb9fe2f702277197f33d7dbead4a1482c $")
