@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 7dba71b7876b219e7d2755b45342f83aee116490 $
+// $Id: 38a5392a2606961143c11997318c58eff0bb405d $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom 1.22).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -72,7 +72,7 @@ OBinding DefaultBindings[] =
 	{"s", "+back"},
 	{"a", "+moveleft"},
 	{"d", "+moveright"},
-#ifdef _XBOX
+#ifdef GCONSOLE
 	{"hat1right", "messagemode2"},
 	{"hat1left", "spynext"},
 	{"hat1up", "messagemode"},
@@ -579,8 +579,8 @@ END_COMMAND(bind)
 BEGIN_COMMAND(unbind)
 {
 	if (argc < 2) {
-		Printf(PRINT_WARNING, "Unbinds a key. \"all\" unbinds every key.\n");
-		Printf(PRINT_WARNING, "Usage: unbind <key>\n");
+		PrintFmt(PRINT_WARNING, "Unbinds a key. \"all\" unbinds every key.\n");
+		PrintFmt(PRINT_WARNING, "Usage: unbind <key>\n");
 		return;
 	}
 
@@ -603,8 +603,8 @@ BEGIN_COMMAND(undoublebind)
 {
 	if (argc < 2)
 	{
-		Printf(PRINT_WARNING, "Unbinds a doublekey. \"all\" unbinds every doublebind key.\n");
-		Printf(PRINT_WARNING, "Usage: undoublebind <key>\n");
+		PrintFmt(PRINT_WARNING, "Unbinds a doublekey. \"all\" unbinds every doublebind key.\n");
+		PrintFmt(PRINT_WARNING, "Usage: undoublebind <key>\n");
 		return;
 	}
 
@@ -626,8 +626,8 @@ BEGIN_COMMAND(unambind)
 {
 	if (argc < 2)
 	{
-		Printf(PRINT_WARNING, "Unbinds an automap key. \"all\" unbinds every automap key.\n");
-		Printf(PRINT_WARNING, "Usage: unambind <key>\n");
+		PrintFmt(PRINT_WARNING, "Unbinds an automap key. \"all\" unbinds every automap key.\n");
+		PrintFmt(PRINT_WARNING, "Usage: unambind <key>\n");
 		return;
 	}
 
@@ -652,9 +652,9 @@ BEGIN_COMMAND(unnetdemobind)
 {
 	if (argc < 2)
 	{
-		Printf(PRINT_WARNING,
-		       "Unbinds a netdemo key. \"all\" unbinds every existing netdemo key.\n");
-		Printf(PRINT_WARNING, "Usage: unnetdemobind <key>\n");
+		PrintFmt(PRINT_WARNING,
+		         "Unbinds a netdemo key. \"all\" unbinds every existing netdemo key.\n");
+		PrintFmt(PRINT_WARNING, "Usage: unnetdemobind <key>\n");
 		return;
 	}
 
@@ -684,4 +684,4 @@ END_COMMAND(unbindall)
 
 
 
-VERSION_CONTROL (c_bind_cpp, "$Id: 7dba71b7876b219e7d2755b45342f83aee116490 $")
+VERSION_CONTROL (c_bind_cpp, "$Id: 38a5392a2606961143c11997318c58eff0bb405d $")
