@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: af539c79caf6e6c4e57b94751cc83521bb99828e $
+// $Id: 6a02753078293187e77675e252314504320798b3 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -638,7 +638,7 @@ void ConsoleHistory::movePositionDown()
 void ConsoleHistory::dump()
 {
 	for (const auto& it : history)
-		Printf(PRINT_HIGH, "   %s\n", it);
+		PrintFmt(PRINT_HIGH, "   {}\n", it);
 }
 
 class ConsoleCompletions
@@ -1163,6 +1163,10 @@ void C_AddNotifyString(int printlevel, const char* color_code, const char* sourc
 	if (printlevel == PRINT_FILTERCHAT)
 		return;
 
+	// Do not display filtered normal messages
+	if (printlevel == PRINT_FILTERHIGH)
+		return;
+
 	const int width = I_GetSurfaceWidth() / V_TextScaleXAmount();
 
 	if (addtype == APPENDLINE && NotifyStrings[NUMNOTIFIES-1].printlevel == printlevel)
@@ -1211,15 +1215,14 @@ void C_AddNotifyString(int printlevel, const char* color_code, const char* sourc
 // Prints the given string to stdout, stripping away any color markup
 // escape codes.
 //
-static size_t C_PrintStringStdOut(const char* str)
+static size_t C_PrintStringStdOut(std::string str)
 {
-	std::string sanitized_str(str);
-	StripColorCodes(sanitized_str);
+	StripColorCodes(str);
 
-	fmt::print("{}", sanitized_str);
+	fmt::print("{}", str);
 	fflush(stdout);
 
-	return sanitized_str.length();
+	return str.length();
 }
 
 
@@ -1244,6 +1247,9 @@ static size_t C_PrintString(int printlevel, const char* color_code, const char*
 	if (printlevel == PRINT_FILTERCHAT)
 		printlevel = PRINT_CHAT;
 
+	if (printlevel == PRINT_FILTERHIGH)
+		printlevel = PRINT_HIGH;
+
 	const char* line_start = outline;
 	const char* line_end = line_start;
 
@@ -1344,7 +1350,7 @@ size_t C_BasePrint(const int printlevel, const char* color_code, const std::stri
 	}
 
 	if (print_stdout && gamestate != GS_FORCEWIPE)
-		C_PrintStringStdOut(newStr.c_str());
+		C_PrintStringStdOut(newStr);
 
 	if (!con_coloredmessages)
 		StripColorCodes(newStr);
@@ -2008,7 +2014,7 @@ static bool C_HandleKey(const event_t* ev)
 		History.addString(text);
 		History.resetPosition();
 
-		Printf(127, "]%s\n", text);
+		PrintFmt(127, "]{}\n", text);
 		AddCommandString(text);
 		CmdLine.clear();
 	}
@@ -2139,7 +2145,7 @@ static bool C_HandleKey(const event_t* ev)
 			History.addString(CmdLine.text);
 			History.resetPosition();
 
-			Printf(127, "]%s\n", CmdLine.text.c_str());
+			PrintFmt(127, "]{}\n", CmdLine.text.c_str());
 			AddCommandString(CmdLine.text.c_str());
 			CmdLine.clear();
 			CmdCompletions.clear();
@@ -2242,7 +2248,7 @@ BEGIN_COMMAND(echo)
 	if (argc > 1)
 	{
 		const std::string str = C_ArgCombine(argc - 1, (const char **)(argv + 1));
-		Printf(PRINT_HIGH, "%s\n", str.c_str());
+		PrintFmt(PRINT_HIGH, "{}\n", str);
 	}
 }
 END_COMMAND(echo)
@@ -2285,7 +2291,7 @@ void C_MidPrint(const char *msg, player_t *p, int msgtime)
 
 		char *newmsg = strdup(str.c_str());
 
-		Printf(PRINT_HIGH, "%s\n", newmsg);
+		PrintFmt(PRINT_HIGH, "{}\n", newmsg);
 		midprinting = false;
 
 		if ( (MidMsg = V_BreakLines(I_GetSurfaceWidth() / V_TextScaleXAmount(), (byte *)newmsg)) )
@@ -2431,4 +2437,4 @@ void C_RevealSecret()
 		S_Sound(CHAN_INTERFACE, "misc/secret", 1, ATTN_NONE);
 }
 
-VERSION_CONTROL (c_console_cpp, "$Id: af539c79caf6e6c4e57b94751cc83521bb99828e $")
+VERSION_CONTROL (c_console_cpp, "$Id: 6a02753078293187e77675e252314504320798b3 $")
