@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 0470003c2ad43dfdb6bfb9f97eb33e73602b8379 $
+// $Id: 77537bf12e09b3b522c1cab25e20453ea51c9dd8 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -96,8 +96,8 @@ static struct DownloadState
  */
 void CL_DownloadInit()
 {
-	Printf("CL_DownloadInit: Init HTTP subsystem (libcurl %d.%d.%d)\n",
-	       LIBCURL_VERSION_MAJOR, LIBCURL_VERSION_MINOR, LIBCURL_VERSION_PATCH);
+	PrintFmt("CL_DownloadInit: Init HTTP subsystem (libcurl {}.{}.{})\n",
+	         LIBCURL_VERSION_MAJOR, LIBCURL_VERSION_MINOR, LIBCURL_VERSION_PATCH);
 
 	curl_global_init(CURL_GLOBAL_ALL);
 
@@ -142,7 +142,7 @@ bool CL_StartDownload(const Websites& urls, const OWantFile& filename, unsigned
 {
 	if (::dlstate.state != STATE_READY)
 	{
-		Printf(PRINT_WARNING, "Can't start download when download state is not ready.\n");
+		PrintFmt(PRINT_WARNING, "Can't start download when download state is not ready.\n");
 		return false;
 	}
 
@@ -170,24 +170,24 @@ bool CL_StartDownload(const Websites& urls, const OWantFile& filename, unsigned
 
 	if (checkurls.empty())
 	{
-		Printf(PRINT_WARNING, "No sites were provided for download.\n");
+		PrintFmt(PRINT_WARNING, "No sites were provided for download.\n");
 		return false;
 	}
 
 	if (W_IsFilenameCommercialWAD(filename.getBasename()))
 	{
-		Printf(PRINT_WARNING, "%s is a commercial WAD file and cannot be downloaded by Odamex.\n"
-		                      "A copy can be obtained through purchasing DOOM + DOOM II from Steam or GOG.\n",
-							  filename.getBasename());
+		PrintFmt(PRINT_WARNING, "{} is a commercial WAD file and cannot be downloaded by Odamex.\n"
+		                        "A copy can be obtained through purchasing DOOM + DOOM II from Steam or GOG.\n",
+		                        filename.getBasename());
 		return false;
 	}
 
 	if (W_IsFilehashCommercialWAD(filename.getWantedMD5()))
 	{
 		const fileIdentifier_t* id = W_GameInfo(filename.getWantedMD5());
-		Printf(PRINT_WARNING, "%s is a renamed commercial wad file containing %s.\n"
-		                      "A copy of %s can be obtained through purchasing DOOM + DOOM II from Steam or GOG.\n",
-							  filename.getBasename(), id->mNiceName, id->mFilename);
+		PrintFmt(PRINT_WARNING, "{} is a renamed commercial wad file containing {}.\n"
+		                        "A copy of {} can be obtained through purchasing DOOM + DOOM II from Steam or GOG.\n",
+		                        filename.getBasename(), id->mNiceName, id->mFilename);
 		return false;
 	}
 
@@ -229,7 +229,7 @@ static void CheckDone(const OTransferInfo& info)
 	::dlstate.state = STATE_DOWNLOADING;
 	::dlstate.url = info.url;
 
-	Printf("Found file at %s.\n", info.url);
+	PrintFmt("Found file at {}.\n", info.url);
 }
 
 /**
@@ -248,9 +248,9 @@ static void CheckError(const char* msg)
 	// Three strikes and you're out.
 	if (::dlstate.checkfails >= 3)
 	{
-		Printf(PRINT_WARNING, "Could not find %s at %s (%s)...\n",
-		       ::dlstate.checkfilename,
-		       ::dlstate.checkurls.at(::dlstate.checkurlidx), msg);
+		PrintFmt(PRINT_WARNING, "Could not find {} at {} ({})...\n",
+		         ::dlstate.checkfilename,
+		         ::dlstate.checkurls.at(::dlstate.checkurlidx), msg);
 
 		// Check the next base URL.
 		::dlstate.checkfails = 0;
@@ -258,8 +258,8 @@ static void CheckError(const char* msg)
 		if (::dlstate.checkurlidx >= ::dlstate.checkurls.size())
 		{
 			// No more base URL's to check - our luck has run out.
-			Printf(PRINT_WARNING, "Download failed, no sites have %s for download.\n",
-			       ::dlstate.checkfilename);
+			PrintFmt(PRINT_WARNING, "Download failed, no sites have {} for download.\n",
+			         ::dlstate.checkfilename);
 			::dlstate.Ready();
 		}
 	}
@@ -303,7 +303,7 @@ static void TickCheck()
 		}
 
 		::dlstate.state = STATE_CHECKING;
-		Printf("Checking for file at %s...\n", fullurl);
+		PrintFmt("Checking for file at {}...\n", fullurl);
 	}
 
 	// Tick the checker - the done/error callbacks mutate the state appropriately,
@@ -350,7 +350,7 @@ static void TransferDone(const OTransferInfo& info)
 {
 	std::string bytes;
 	StrFormatBytes(bytes, info.speed);
-	Printf("Download completed at %s/s.\n", bytes);
+	PrintFmt("Download completed at {}/s.\n", bytes);
 
 	if (::dlstate.flags & DL_RECONNECT)
 		CL_Reconnect();
@@ -358,7 +358,7 @@ static void TransferDone(const OTransferInfo& info)
 
 static void TransferError(const char* msg)
 {
-	Printf(PRINT_WARNING, "Download error (%s).\n", msg);
+	PrintFmt(PRINT_WARNING, "Download error ({}).\n", msg);
 }
 
 static void TickDownload()
@@ -392,7 +392,7 @@ static void TickDownload()
 				break;
 
 			// Otherwise, set the destination to the empty string and try again.
-			Printf(PRINT_WARNING, "Could not save to %s (%s)\n", dest, strerror(err));
+			PrintFmt(PRINT_WARNING, "Could not save to {} ({})\n", dest, strerror(err));
 			dest = "";
 		}
 
@@ -415,7 +415,7 @@ static void TickDownload()
 		}
 
 		::dlstate.state = STATE_DOWNLOADING;
-		Printf("Downloading %s...\n", ::dlstate.url);
+		PrintFmt("Downloading {}...\n", ::dlstate.url);
 	}
 
 	if (!::dlstate.transfer->tick())
@@ -429,8 +429,8 @@ static void TickDownload()
 			if (::dlstate.checkurlidx >= ::dlstate.checkurls.size())
 			{
 				// No more base URL's to check - our luck has run out.
-				Printf(PRINT_WARNING, "Download failed, no sites have %s for download.\n",
-				       ::dlstate.checkfilename);
+				PrintFmt(PRINT_WARNING, "Download failed, no sites have {} for download.\n",
+				         ::dlstate.checkfilename);
 				::dlstate.Ready();
 			}
 		}
@@ -505,12 +505,12 @@ EXTERN_CVAR(cl_downloadsites)
 
 static void DownloadHelp()
 {
-	Printf("download - Downloads a WAD file\n\n"
-	       "Usage:\n"
-	       "  ] download get <FILENAME>\n"
-	       "  Downloads the file FILENAME from your configured download sites.\n"
-	       "  ] download stop\n"
-	       "  Stop an in-progress download.");
+	PrintFmt("download - Downloads a WAD file\n\n"
+	         "Usage:\n"
+	         "  ] download get <FILENAME>\n"
+	         "  Downloads the file FILENAME from your configured download sites.\n"
+	         "  ] download stop\n"
+	         "  Stop an in-progress download.");
 }
 
 BEGIN_COMMAND(download)
@@ -538,7 +538,7 @@ BEGIN_COMMAND(download)
 	if (stricmp(argv[1], "stop") == 0)
 	{
 		if (CL_StopDownload())
-			Printf(PRINT_WARNING, "Download cancelled.\n");
+			PrintFmt(PRINT_WARNING, "Download cancelled.\n");
 
 		return;
 	}
@@ -547,4 +547,4 @@ BEGIN_COMMAND(download)
 }
 END_COMMAND(download)
 
-VERSION_CONTROL(cl_download_cpp, "$Id: 0470003c2ad43dfdb6bfb9f97eb33e73602b8379 $")
+VERSION_CONTROL(cl_download_cpp, "$Id: 77537bf12e09b3b522c1cab25e20453ea51c9dd8 $")
