@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f1fa83c11b89b180501ed967549e44d061ae502b $
+// $Id: 73f85bfaa5114637295e788bb6c80fed84795fcb $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
@@ -65,10 +65,7 @@
 #include "g_spawninv.h"
 #include "g_gametype.h"
 #include "p_horde.h"
-
-#ifdef _XBOX
-#include "i_xbox.h"
-#endif
+#include "g_musinfo.h"
 
 #include <math.h> // for pow()
 
@@ -197,6 +194,13 @@ CVAR_FUNC_IMPL(cl_mouselook)
 	R_InitSkyMap ();
 }
 
+CVAR_FUNC_IMPL(joy_freelook)
+{
+	// [RV] - Center view, Update Skies
+	AddCommandString("centerview");
+	R_InitSkyMap();
+}
+
 char			demoname[256];
 bool 			demoplayback;
 
@@ -305,8 +309,8 @@ BEGIN_COMMAND (turnspeeds)
 {
 	if (argc == 1)
 	{
-		Printf (PRINT_HIGH, "Current turn speeds: %d %d %d\n",
-				angleturn[0], angleturn[1], angleturn[2]);
+		PrintFmt(PRINT_HIGH, "Current turn speeds: {} {} {}\n",
+				 angleturn[0], angleturn[1], angleturn[2]);
 	}
 	else
 	{
@@ -350,8 +354,8 @@ BEGIN_COMMAND (togglerun)
 {
 	cl_run.Set(!cl_run.value());
 
-	Printf(PRINT_HIGH, "Always run %s\n",
-			cl_run.value() ? "on" : "off");
+	PrintFmt(PRINT_HIGH, "Always run {}\n",
+			 cl_run.value() ? "on" : "off");
 }
 END_COMMAND (togglerun)
 
@@ -841,7 +845,7 @@ int outrate;
 
 BEGIN_COMMAND(netstat)
 {
-    Printf (PRINT_HIGH, "in = %d  out = %d \n", netin, netout);
+    PrintFmt(PRINT_HIGH, "in = {}  out = {} \n", netin, netout);
 }
 END_COMMAND(netstat)
 
@@ -1073,8 +1077,8 @@ void G_Ticker (void)
 				MSG_WriteMarker(&net_buffer, clc_disconnect);
 				NET_SendPacket(net_buffer, serveraddr);
 
-				Printf(PRINT_WARNING,
-				       "Got unknown challenge %d while connecting, disconnecting.\n", type);
+				PrintFmt(PRINT_WARNING,
+				         "Got unknown challenge {} while connecting, disconnecting.\n", type);
 			}
 		}
 	}
@@ -1572,7 +1576,7 @@ void G_DoLoadGame (void)
 	FILE *stdfile = fopen (savename.c_str(), "rb");
 	if (stdfile == NULL)
 	{
-		Printf (PRINT_HIGH, "Could not read savegame '%s'\n", savename);
+		PrintFmt(PRINT_HIGH, "Could not read savegame '{}'\n", savename);
 		return;
 	}
 
@@ -1580,13 +1584,13 @@ void G_DoLoadGame (void)
 	size_t readlen = fread (text, 16, 1, stdfile);
 	if (readlen < 1)
 	{
-		Printf (PRINT_HIGH, "Failed to read savegame '%s'\n", savename);
+		PrintFmt(PRINT_HIGH, "Failed to read savegame '{}'\n", savename);
 		fclose(stdfile);
 		return;
 	}
 	if (strncmp (text, SAVESIG, 16))
 	{
-		Printf (PRINT_HIGH, "Savegame '%s' is from a different version\n", savename);
+		PrintFmt(PRINT_HIGH, "Savegame '{}' is from a different version\n", savename);
 
 		fclose(stdfile);
 
@@ -1595,7 +1599,7 @@ void G_DoLoadGame (void)
 	readlen = fread (text, 8, 1, stdfile);
 	if (readlen < 1)
 	{
-		Printf (PRINT_HIGH, "Failed to read savegame '%s'\n", savename);
+		PrintFmt(PRINT_HIGH, "Failed to read savegame '{}'\n", savename);
 		fclose(stdfile);
 		return;
 	}
@@ -1606,9 +1610,9 @@ void G_DoLoadGame (void)
 	FLZOFile savefile (stdfile, FFile::EReading);
 
 	if (!savefile.IsOpen ())
-		I_Error ("Savegame '{}' is corrupt\n", savename);
+		I_Error("Savegame '{}' is corrupt\n", savename);
 
-	Printf (PRINT_HIGH, "Loading savegame '%s'...\n", savename);
+	PrintFmt(PRINT_HIGH, "Loading savegame '{}'...\n", savename);
 
 	CL_QuitNetGame(NQ_SILENT);
 
@@ -1640,6 +1644,7 @@ void G_DoLoadGame (void)
 
 	arc >> level.time;
 
+	P_SerializeMusInfo(arc);
 
 	for (i = 0; i < NUM_WORLDVARS; i++)
 	{
@@ -1698,11 +1703,7 @@ void G_SaveGame (int slot, std::string_view description)
  */
 void G_BuildSaveName(std::string &name, int slot)
 {
-#ifdef _XBOX
-	std::string path = xbox_GetSavePath(name, slot);
-#else
 	std::string path = M_GetUserFileName(name);
-#endif
 	name = fmt::sprintf("%s" PATHSEP "odasv%d.ods", path, slot);
 }
 
@@ -1722,11 +1723,7 @@ void G_DoSaveGame()
         return;
 	}
 
-#ifdef _XBOX
-	xbox_WriteSaveMeta(name.substr(0, name.rfind(PATHSEPCHAR)), description.c_str());
-#endif
-
-	Printf (PRINT_HIGH, "Saving game to '%s'...\n", name);
+	PrintFmt(PRINT_HIGH, "Saving game to '{}'...\n", name);
 
 	fwrite (description.c_str(), SAVESTRINGSIZE, 1, stdfile);
 	fwrite (SAVESIG, 16, 1, stdfile);
@@ -1750,13 +1747,14 @@ void G_DoSaveGame()
 	P_SerializeHorde(arc);
 
 	arc << level.time;
+	P_SerializeMusInfo(arc);
 
 	for (int i = 0; i < NUM_WORLDVARS; i++)
 	{
 		arc << ACS_WorldVars[i];
 		ACSWorldGlobalArray worldarr = ACS_WorldArrays[i];
 		arc << worldarr.size();
-		for (const auto [key, val] : worldarr)
+		for (const auto& [key, val] : worldarr)
 		{
 			arc << key;
 			arc << val;
@@ -1768,20 +1766,19 @@ void G_DoSaveGame()
 		arc << ACS_GlobalVars[i];
 		ACSWorldGlobalArray globalarr = ACS_GlobalArrays[i];
 		arc << globalarr.size();
-		for (const auto [key, val] : globalarr)
+		for (const auto& [key, val] : globalarr)
 		{
 			arc << key;
 			arc << val;
 		}
 	}
 
-
 	arc << (BYTE)0x1d;			// consistancy marker
 
 	gameaction = ga_nothing;
 	savedescription[0] = 0;
 
-	Printf (PRINT_HIGH, "%s\n", GStrings(GGSAVED));
+	PrintFmt(PRINT_HIGH, "{}\n", GStrings(GGSAVED));
 	arc.Close ();
 
     if (level.info->snapshot != NULL)
@@ -1865,12 +1862,12 @@ BEGIN_COMMAND(playdemo)
 		}
 		else
 		{
-			Printf(PRINT_WARNING, "Cannot play demo because WAD didn't load\n");
-			Printf(PRINT_WARNING, "Use the 'wad' command\n");
+			PrintFmt(PRINT_WARNING, "Cannot play demo because WAD didn't load\n");
+			PrintFmt(PRINT_WARNING, "Use the 'wad' command\n");
 		}
 	}
 	else
-		Printf(PRINT_HIGH, "Usage: playdemo lumpname or file\n");
+		PrintFmt(PRINT_HIGH, "Usage: playdemo lumpname or file\n");
 }
 END_COMMAND(playdemo)
 
@@ -1883,7 +1880,7 @@ BEGIN_COMMAND(streamdemo)
 	}
 	else
 	{
-		Printf(PRINT_HIGH, "Usage: streamdemo lumpname or file\n");
+		PrintFmt(PRINT_HIGH, "Usage: streamdemo lumpname or file\n");
 	}
 }
 END_COMMAND(streamdemo)
@@ -1919,7 +1916,7 @@ void G_DoPlayDemo(bool justStreamInput)
 		std::string found = M_FindUserFileName(::defdemoname, ".lmp");
 		if (found.empty())
 		{
-			Printf(PRINT_WARNING, "Could not find demo %s\n", ::defdemoname);
+			PrintFmt(PRINT_WARNING, "Could not find demo {}\n", ::defdemoname);
 			gameaction = ga_fullconsole;
 			return;
 		}
@@ -1936,7 +1933,7 @@ void G_DoPlayDemo(bool justStreamInput)
 		if (bytelen)
 			Z_Free(demobuffer);
 
-		Printf(PRINT_WARNING, "DOOM Demo file too short\n");
+		PrintFmt(PRINT_WARNING, "DOOM Demo file too short\n");
 		gameaction = ga_fullconsole;
 		return;
 	}
@@ -1950,7 +1947,7 @@ void G_DoPlayDemo(bool justStreamInput)
 		demo_p[0] == DOOM_1_9p_DEMO ||
 		demo_p[0] == DOOM_1_9_1_DEMO)
 	{
-		Printf(PRINT_HIGH, "Playing DOOM demo %s\n", defdemoname);
+		PrintFmt(PRINT_HIGH, "Playing DOOM demo {}\n", defdemoname);
 
 		demostartgametic = gametic;
 		demoversion = *demo_p++ == DOOM_1_9_1_DEMO ? LMP_DOOM_1_9_1 : LMP_DOOM_1_9;
@@ -1991,7 +1988,7 @@ void G_DoPlayDemo(bool justStreamInput)
 			if (!validplayer(con))
 			{
 				Z_Free(demobuffer);
-				Printf(PRINT_HIGH, "DOOM Demo: invalid console player %d of %lu\n", who + 1, players.size());
+				PrintFmt(PRINT_HIGH, "DOOM Demo: invalid console player {} of {}\n", who + 1, players.size());
 				gameaction = ga_fullconsole;
 				return;
 			}
@@ -2063,7 +2060,7 @@ void G_DoPlayDemo(bool justStreamInput)
 	}
 	else
 	{
-		Printf(PRINT_WARNING, "Unsupported demo format.  If you are trying to play an Odamex " \
+		PrintFmt(PRINT_WARNING, "Unsupported demo format.  If you are trying to play an Odamex " \
 						"netdemo, please use the netplay command\n");
 		gameaction = ga_nothing;
 	}
@@ -2144,9 +2141,13 @@ bool G_CheckDemoStatus (void)
 			AActor *mo = idplayer(1).mo;
 
 			if (mo)
-				Printf(PRINT_HIGH, "demotest:%x %x %x %x\n", mo->angle, mo->x, mo->y, mo->z);
+				PrintFmt(PRINT_HIGH, "demotest:{:x} {:x} {:x} {:x}\n",
+					static_cast<uint32_t>(mo->angle),
+					static_cast<uint32_t>(mo->x),
+					static_cast<uint32_t>(mo->y),
+					static_cast<uint32_t>(mo->z));
 			else
-				Printf(PRINT_WARNING, "demotest:no player\n");
+				PrintFmt(PRINT_WARNING, "demotest:no player\n");
 
 			demotest = false;
 
@@ -2164,15 +2165,15 @@ bool G_CheckDemoStatus (void)
 				int realtics = endtime * TICRATE / 1000;
 				float fps = float(gametic * TICRATE) / realtics;
 
-				Printf(PRINT_HIGH, "timed %i gametics in %i realtics (%.1f fps)\n",
-						gametic, realtics, fps);
+				PrintFmt(PRINT_HIGH, "timed {} gametics in {} realtics ({:.1f} fps)\n",
+				         gametic, realtics, fps);
 
 				// exit the application
 				CL_QuitCommand();
 				return false;
 			}
 			else
-				Printf (PRINT_HIGH, "Demo ended.\n");
+				PrintFmt(PRINT_HIGH, "Demo ended.\n");
 
 			demoplayback = false;
 			gameaction = ga_fullconsole;
@@ -2189,4 +2190,4 @@ bool G_CheckDemoStatus (void)
 }
 
 
-VERSION_CONTROL (g_game_cpp, "$Id: f1fa83c11b89b180501ed967549e44d061ae502b $")
+VERSION_CONTROL (g_game_cpp, "$Id: 73f85bfaa5114637295e788bb6c80fed84795fcb $")
