@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f41ae9ba3ac21ff99ebb35cf75fd7658cbd69ba7 $
+// $Id: e03e880ef2e065d69d7cb474929441651809184c $
 //
 // Copyright (C) 2012 by Alex Mayfield.
 //
@@ -23,7 +23,6 @@
 
 #include "odamex.h"
 
-#include <map>
 #include <sstream>
 
 #include "c_maplist.h"
@@ -384,11 +383,11 @@ void CMD_MaplistCallback(const maplist_qrows_t &result) {
 		const auto& [map, lastmap, _, wads] = *entry;
 		char flag = ' ';
 		if (show_this_map && index == this_index) {
-			flag = '*';
+			flag = '>';
 		} else if (index == next_index) {
 			flag = '+';
 		}
-		PrintFmt(PRINT_HIGH, "{}{}. {} {}{}\n", flag, index + 1,
+		PrintFmt(PRINT_HIGH, " {}{}. {} {}{}\n", flag, index + 1,
 			   JoinStrings(wads, " "), map,
 			   lastmap.empty() ? "" : fmt::format(" lastmap={}", lastmap));
 	}
