@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f2a768f0433165616eddc07ab94dfd21773b629a $
+// $Id: fef96509cb8a215aa047a4c0d15bb9b85963632c $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -64,6 +64,7 @@
 #include "infomap.h"
 #include "cl_replay.h"
 #include "r_interp.h"
+#include "m_doomobjcontainer.h"
 
 // Extern data from other files.
 
@@ -84,6 +85,8 @@ EXTERN_CVAR(hud_revealsecrets)
 EXTERN_CVAR(mute_enemies)
 EXTERN_CVAR(mute_spectators)
 EXTERN_CVAR(show_messages)
+EXTERN_CVAR(co_novileghosts)
+EXTERN_CVAR(sv_sharekeys)
 
 extern std::string digest;
 extern bool forcenetdemosplit;
@@ -99,7 +102,7 @@ void CL_ClearPlayerJustTeleported(player_t* player);
 void CL_ClearSectorSnapshots();
 player_t& CL_FindPlayer(size_t id);
 std::string CL_GenerateNetDemoFileName(
-    const std::string& filename = cl_netdemoname.cstring());
+    const std::string& filename = cl_netdemoname.str());
 bool CL_PlayerJustTeleported(player_t* player);
 void CL_QuitAndTryDownload(const OWantFile& missing_file);
 void CL_ResyncWorldIndex();
@@ -108,7 +111,7 @@ void G_PlayerReborn(player_t& p); // [Toke - todo] clean this function
 void P_DestroyButtonThinkers();
 void P_ExplodeMissile(AActor* mo);
 void P_PlayerLeavesGame(player_s* player);
-void P_SetPsprite(player_t* player, int position, statenum_t stnum);
+void P_SetPsprite(player_t* player, int position, int32_t stnum);
 void P_SetButtonTexture(line_t* line, short texture);
 
 /**
@@ -200,7 +203,7 @@ static void CL_Disconnect(const odaproto::svc::Disconnect* msg)
 		buffer = fmt::sprintf("Disconnected from server\n");
 	}
 
-	Printf("%s", msg->message());
+	PrintFmt("{}", msg->message());
 	CL_QuitNetGame(NQ_SILENT);
 }
 
@@ -212,7 +215,7 @@ static void CL_PlayerInfo(const odaproto::svc::PlayerInfo* msg)
 	player_t& p = consoleplayer();
 
 	uint32_t weaponowned = msg->player().weaponowned();
-	UnpackBoolArray(p.weaponowned, NUMWEAPONS, weaponowned);
+	UnpackBoolArray(p.weaponowned.data(), NUMWEAPONS, weaponowned);
 
 	uint32_t cards = msg->player().cards();
 	UnpackBoolArray(p.cards, NUMCARDS, cards);
@@ -504,7 +507,7 @@ static void CL_SpawnMobj(const odaproto::svc::SpawnMobj* msg)
 	mobjtype_t type = static_cast<mobjtype_t>(msg->current().type());
 	statenum_t state = static_cast<statenum_t>(msg->current().statenum());
 
-	if (type < MT_PLAYER || type >= NUMMOBJTYPES)
+	if (!mobjinfo.contains(type))
 		return;
 
 	P_ClearId(netid);
@@ -584,10 +587,12 @@ static void CL_SpawnMobj(const odaproto::svc::SpawnMobj* msg)
 	    (mo->target->oflags & hordeBossModMask))
 	{
 		mo->oflags |= MFO_FULLBRIGHT;
-		mo->effects = FX_YELLOWFOUNTAIN;
+		mo->effects |= FX_YELLOWFOUNTAIN;
 		mo->translation = translationref_t(&::bosstable[0]);
 	}
 
+	P_FriendlyEffects(mo);
+
 	AActor* tracer = NULL;
 	if (bflags & baseline_t::TRACER)
 		tracer = P_FindThingById(msg->current().tracerid());
@@ -627,7 +632,7 @@ static void CL_SpawnMobj(const odaproto::svc::SpawnMobj* msg)
 			mo->tics = 1;
 	}
 
-	if (state >= S_NULL && state < NUMSTATES)
+    if(state >= S_NULL && states.contains(state))
 	{
 		P_SetMobjState(mo, state);
 	}
@@ -674,12 +679,17 @@ static void CL_SpawnMobj(const odaproto::svc::SpawnMobj* msg)
 		mo->flags = msg->current().flags();
 	}
 
+	if (msg->spawn_flags() & SVC_SM_FLAGS2)
+	{
+		mo->flags2 = msg->current().flags2();
+	}
+
 	if (msg->spawn_flags() & SVC_SM_OFLAGS)
 	{
 		mo->oflags = msg->current().oflags();
 
 		// [AM] HACK! Assume that any monster with a flag is a boss.
-		if (mo->oflags)
+		if (mo->oflags & hordeBossModMask)
 		{
 			mo->effects = FX_YELLOWFOUNTAIN;
 			mo->translation = translationref_t(&::bosstable[0]);
@@ -695,7 +705,7 @@ static void CL_SpawnMobj(const odaproto::svc::SpawnMobj* msg)
 			tics = -1;
 
 		// already spawned as gibs?
-		if (!mo || mo->state - states == S_GIBS)
+		if (!mo || mo->state == &states[S_GIBS])
 			return;
 
 		if ((frame & FF_FRAMEMASK) >= sprites[mo->sprite].numframes)
@@ -787,9 +797,9 @@ static void CL_LoadMap(const odaproto::svc::LoadMap* msg)
 		OWantFile file;
 		if (!OWantFile::makeWithHash(file, name, OFILE_WAD, hash))
 		{
-			Printf(PRINT_WARNING,
-			       "Could not construct wanted file \"%s\" that server requested.\n",
-			       name);
+			PrintFmt(PRINT_WARNING,
+			         "Could not construct wanted file \"{}\" that server requested.\n",
+			         name);
 			CL_QuitNetGame(NQ_DISCONNECT);
 			return;
 		}
@@ -810,9 +820,9 @@ static void CL_LoadMap(const odaproto::svc::LoadMap* msg)
 		OWantFile file;
 		if (!OWantFile::makeWithHash(file, name, OFILE_DEH, hash))
 		{
-			Printf(PRINT_WARNING,
-			       "Could not construct wanted patch \"%s\" that server requested.\n",
-			       name);
+			PrintFmt(PRINT_WARNING,
+			         "Could not construct wanted patch \"{}\" that server requested.\n",
+			         name);
 			CL_QuitNetGame(NQ_DISCONNECT);
 			return;
 		}
@@ -830,7 +840,7 @@ static void CL_LoadMap(const odaproto::svc::LoadMap* msg)
 	{
 		if (::missingCommercialIWAD)
 		{
-			Printf(PRINT_WARNING, "Server requires commercial IWAD that was not found.\n");
+			PrintFmt(PRINT_WARNING, "Server requires commercial IWAD that was not found.\n");
 			CL_QuitNetGame(NQ_DISCONNECT);
 			return;
 		}
@@ -958,7 +968,7 @@ static void CL_UserInfo(const odaproto::svc::UserInfo* msg)
 
 	p->userinfo.gender = static_cast<gender_t>(msg->gender());
 	if (p->userinfo.gender < 0 || p->userinfo.gender >= NUMGENDER)
-		p->userinfo.gender = GENDER_NEUTER;
+		p->userinfo.gender = GENDER_OTHER;
 
 	p->userinfo.color[0] = 255;
 	p->userinfo.color[1] = msg->color().r();
@@ -1138,8 +1148,15 @@ static void CL_SpawnPlayer(const odaproto::svc::SpawnPlayer* msg)
 
 	// give all cards in death match mode
 	if (!G_IsCoopGame())
+	{
 		for (size_t i = 0; i < NUMCARDS; i++)
 			p->cards[i] = true;
+	}
+	else if (sv_sharekeys)
+	{
+		const uint32_t cards = msg->cards();
+		UnpackBoolArray(p->cards, NUMCARDS, cards);
+	}
 
 	if (p->id == consoleplayer_id)
 	{
@@ -1305,6 +1322,48 @@ static void CL_KillMobj(const odaproto::svc::KillMobj* msg)
 	P_KillMobj(source, target, inflictor, joinkill);
 }
 
+//
+// CL_RaiseMobj
+//
+static void CL_RaiseMobj(const odaproto::svc::RaiseMobj* msg)
+{
+	uint32_t srcid = msg->source_netid();
+	uint32_t cpsid = msg->corpse().netid();
+
+	AActor* source = P_FindThingById(srcid);
+	AActor* corpsehit = P_FindThingById(cpsid);
+
+	if (!corpsehit)
+		return;
+
+	corpsehit->x = msg->corpse().pos().x();
+	corpsehit->y = msg->corpse().pos().y();
+	corpsehit->z = msg->corpse().pos().z();
+	corpsehit->angle = msg->corpse().angle();
+	corpsehit->momx = msg->corpse().mom().x();
+	corpsehit->momy = msg->corpse().mom().y();
+	corpsehit->momz = msg->corpse().mom().z();
+
+	mobjinfo_t* info = corpsehit->info;
+
+	P_SetMobjState(corpsehit, info->raisestate);
+
+	// [Nes] - Classic demo compatability: Ghost monster bug.
+	if (co_novileghosts)
+	{
+		corpsehit->height = P_ThingInfoHeight(info); // [RH] Use real mobj height
+		corpsehit->radius = info->radius;            // [RH] Use real radius
+	}
+	else
+	{
+		corpsehit->height <<= 2;
+	}
+
+	corpsehit->flags = info->flags;
+	corpsehit->health = info->spawnhealth;
+	corpsehit->target = AActor::AActorPtr();
+}
+
 ///////////////////////////////////////////////////////////
 ///// CL_Fire* called when someone uses a weapon  /////////
 ///////////////////////////////////////////////////////////
@@ -1320,7 +1379,7 @@ static void CL_FireWeapon(const odaproto::svc::FireWeapon* msg)
 	weapontype_t firedweap = static_cast<weapontype_t>(msg->readyweapon());
 	if (firedweap < 0 || firedweap > wp_nochange)
 	{
-		Printf("CL_FireWeapon: unknown weapon %d\n", firedweap);
+		PrintFmt("CL_FireWeapon: unknown weapon {}\n", firedweap);
 		return;
 	}
 	int servertic = msg->servertic();
@@ -1387,13 +1446,13 @@ static void CL_Print(const odaproto::svc::Print* msg)
 
 	// TODO : Clientchat moved, remove that but PRINT_SERVERCHAT
 	if (level == PRINT_CHAT)
-		Printf(level, "%c*%s", TEXTCOLOR_ESCAPE, str);
+		PrintFmt(level, "{:c}*{}", TEXTCOLOR_ESCAPE, str);
 	else if (level == PRINT_TEAMCHAT)
-		Printf(level, "%c!%s", TEXTCOLOR_ESCAPE, str);
+		PrintFmt(level, "{:c}!{}", TEXTCOLOR_ESCAPE, str);
 	else if (level == PRINT_SERVERCHAT)
-		Printf(level, "%s%s", TEXTCOLOR_YELLOW, str);
+		PrintFmt(level, "{:c}{}", TEXTCOLOR_YELLOW, str);
 	else
-		Printf(level, "%s", str);
+		PrintFmt(level, "{}", str);
 
 	if (show_messages)
 	{
@@ -1814,9 +1873,9 @@ static void CL_Say(const odaproto::svc::Say* msg)
 	if (message_visibility == 0)
 	{
 		if (strnicmp(message, "/me ", 4) == 0)
-			Printf(publicmsg, "* %s %s\n", name, &message[4]);
+			PrintFmt(publicmsg, "* {} {}\n", name, &message[4]);
 		else
-			Printf(publicmsg, "%s: %s\n", name, message);
+			PrintFmt(publicmsg, "{}: {}\n", name, message);
 
 		if (show_messages && !filtermessage)
 		{
@@ -1827,9 +1886,9 @@ static void CL_Say(const odaproto::svc::Say* msg)
 	else if (message_visibility == 1)
 	{
 		if (strnicmp(message, "/me ", 4) == 0)
-			Printf(publicteammsg, "* %s %s\n", name, &message[4]);
+			PrintFmt(publicteammsg, "* {} {}\n", name, &message[4]);
 		else
-			Printf(publicteammsg, "%s: %s\n", name, message);
+			PrintFmt(publicteammsg, "{}: {}\n", name, message);
 
 		if (show_messages && cl_chatsounds && !filtermessage)
 			S_Sound(CHAN_INTERFACE, "misc/teamchat", 1, ATTN_NONE);
@@ -2006,10 +2065,8 @@ static void CL_SecretEvent(const odaproto::svc::SecretEvent* msg)
 	if (!::hud_revealsecrets || ::hud_revealsecrets > 2)
 		return;
 
-	std::string buf;
-	buf = fmt::sprintf("%s%s %sfound a secret!\n", TEXTCOLOR_YELLOW,
-	                   player.userinfo.netname, TEXTCOLOR_NORMAL);
-	Printf("%s", buf);
+	PrintFmt("{}{} {}found a secret!\n", TEXTCOLOR_YELLOW,
+	                player.userinfo.netname, TEXTCOLOR_NORMAL);
 
 	if (::hud_revealsecrets == 1)
 		S_Sound(CHAN_INTERFACE, "misc/secret", 1, ATTN_NONE);
@@ -2090,7 +2147,7 @@ static void CL_ServerGametic(const odaproto::svc::ServerGametic* msg)
 	::last_svgametic = newtic;
 
 #ifdef _WORLD_INDEX_DEBUG_
-	Printf(PRINT_HIGH, "Gametic %i, received world index %i\n", gametic, last_svgametic);
+	PrintFmt(PRINT_HIGH, "Gametic {}, received world index {}\n", gametic, last_svgametic);
 #endif // _WORLD_INDEX_DEBUG_
 }
 
@@ -2162,8 +2219,8 @@ static void CL_PlayerState(const odaproto::svc::PlayerState* msg)
 	{
 		if (i < msg->player().psprites_size())
 		{
-			unsigned int state = msg->player().psprites().Get(i).statenum();
-			if (state >= NUMSTATES)
+			const int32_t state = msg->player().psprites().Get(i).statenum();
+            if (!states.contains(state))
 			{
 				continue;
 			}
@@ -2296,11 +2353,11 @@ static void CL_PlayerQueuePos(const odaproto::svc::PlayerQueuePos* msg)
 	{
 		if (queuePos > 0 && player.QueuePosition == 0)
 		{
-			Printf(PRINT_HIGH, "Position in line to play: %u\n", queuePos);
+			PrintFmt(PRINT_HIGH, "Position in line to play: {}\n", queuePos);
 		}
 		else if (player.spectator && queuePos == 0 && player.QueuePosition > 0)
 		{
-			Printf(PRINT_HIGH, "You have been removed from the queue.\n");
+			PrintFmt(PRINT_HIGH, "You have been removed from the queue.\n");
 		}
 	}
 
@@ -2396,6 +2453,7 @@ static void CL_SectorProperties(const odaproto::svc::SectorProperties* msg)
 			sector->base_ceiling_yoffs = msg->sector().base_ceiling_yoffs();
 			sector->base_floor_angle = msg->sector().base_floor_angle();
 			sector->base_floor_yoffs = msg->sector().base_floor_yoffs();
+			break;
 		case SPC_Special:
 			sector->special = msg->sector().special();
 		default:
@@ -2449,7 +2507,7 @@ static void CL_SetMobjState(const odaproto::svc::MobjState* msg)
 	AActor* mo = P_FindThingById(msg->netid());
 	int s = msg->mostate();
 
-	if (mo == NULL || s < 0 || s >= NUMSTATES)
+    if (mo == NULL || !states.contains(s))
 		return;
 
 	P_SetMobjState(mo, static_cast<statenum_t>(s));
@@ -2574,7 +2632,7 @@ static void CL_ExecuteACSSpecial(const odaproto::svc::ExecuteACSSpecial* msg)
 		break;
 
 	default:
-		Printf(PRINT_HIGH, "Invalid ACS special: %d", special);
+		PrintFmt(PRINT_HIGH, "Invalid ACS special: {}", special);
 		break;
 	}
 }
@@ -3008,6 +3066,7 @@ parseError_e CL_ParseCommand()
 		SV_MSG(svc_spawnplayer, CL_SpawnPlayer, odaproto::svc::SpawnPlayer);
 		SV_MSG(svc_damageplayer, CL_DamagePlayer, odaproto::svc::DamagePlayer);
 		SV_MSG(svc_killmobj, CL_KillMobj, odaproto::svc::KillMobj);
+		SV_MSG(svc_raisemobj, CL_RaiseMobj, odaproto::svc::RaiseMobj);
 		SV_MSG(svc_fireweapon, CL_FireWeapon, odaproto::svc::FireWeapon);
 		SV_MSG(svc_updatesector, CL_UpdateSector, odaproto::svc::UpdateSector);
 		SV_MSG(svc_print, CL_Print, odaproto::svc::Print);
@@ -3062,3 +3121,5 @@ parseError_e CL_ParseCommand()
 	RecordProto(static_cast<svc_t>(cmd), msg);
 	return PERR_OK;
 }
+
+VERSION_CONTROL (cl_parse_cpp, "$Id: fef96509cb8a215aa047a4c0d15bb9b85963632c $")
