@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f7816bf08d47f1afa95eba6520cde7cf990a8088 $
+// $Id: fb9635b18472d03e11027d46f316ac90547e17fc $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -182,7 +182,7 @@ void ClientReplay::itemReplay()
 			continue;
 		}
 
-		std::string weaponname = P_MobjToName(mo->type);
+		std::string weaponname = P_MobjToName(static_cast<mobjtype_t>(mo->type));
 		weapontype_t weapontype = P_NameToWeapon(weaponname);
 		bool weaponSwitch = P_CheckSwitchWeapon(&player, weapontype);
 
