@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 6ec1bac315d481c174127c8b434cd4592cf4af96 $
+// $Id: bd378b377fad82e931e4207dba7e79334a7bc00b $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -35,6 +35,10 @@
 #include "i_net.h"
 #include "i_system.h"
 
+#include "s_sound.h"
+#include "c_cvars.h"
+EXTERN_CVAR(snd_votesfx)
+
 //////// VOTING STATE ////////
 
 // Return a singleton reference for the class.
@@ -43,7 +47,14 @@ VoteState& VoteState::instance() {
 	return singleton;
 }
 
-void VoteState::set(const vote_state_t &vote_state) {
+void VoteState::set(const vote_state_t& vote_state)
+{
+	// capture previous state BEFORE overwriting
+	const bool was_visible = this->visible;
+	const auto prev_result = this->result;
+	const auto prev_votestring = this->votestring;
+
+	// overwrite with new state
 	this->visible = true;
 	this->result = vote_state.result;
 	this->votestring = vote_state.votestring;
@@ -54,6 +65,34 @@ void VoteState::set(const vote_state_t &vote_state) {
 	this->no = vote_state.no;
 	this->no_needed = vote_state.no_needed;
 	this->abs = vote_state.abs;
+
+	// [RV] Play "start" when the vote first appears or the prompt changed
+	const bool votestring_changed = (prev_votestring != vote_state.votestring);
+	if (!was_visible || votestring_changed)
+	{
+		if (snd_votesfx)
+			S_Sound(CHAN_INTERFACE, "ui/vote/start", 1.0f, ATTN_NONE);
+	}
+
+	// [RV] Play "pass/fail" exactly once when result becomes decided
+	if (prev_result == VOTE_UNDEC && vote_state.result != VOTE_UNDEC)
+	{
+		switch (vote_state.result)
+		{
+		case VOTE_YES:
+			if (snd_votesfx)
+				S_Sound(CHAN_INTERFACE, "ui/vote/pass", 1.0f, ATTN_NONE);
+			break;
+		case VOTE_NO:
+		case VOTE_INTERRUPT:
+		case VOTE_ABANDON:
+			if (snd_votesfx)
+				S_Sound(CHAN_INTERFACE, "ui/vote/fail", 1.0f, ATTN_NONE);
+			break;
+		default:
+			break;
+		}
+	}
 }
 
 bool VoteState::get(vote_state_t &vote_state) {
@@ -93,7 +132,7 @@ bool VoteState::get(vote_state_t &vote_state) {
 //////// CALLBACKS & ERRBACKS ////////
 
 void CMD_MapVoteErrback(const std::string &error) {
-	Printf(PRINT_HIGH, "callvote failed: %s\n", error);
+	PrintFmt(PRINT_HIGH, "callvote failed: {}\n", error);
 }
 
 void CMD_MapVoteCallback(const maplist_qrows_t &result) {
@@ -118,7 +157,7 @@ void CMD_MapVoteCallback(const maplist_qrows_t &result) {
 }
 
 void CMD_RandmapVoteErrback(const std::string &error) {
-	Printf(PRINT_HIGH, "callvote failed: %s\n", error);
+	PrintFmt(PRINT_HIGH, "callvote failed: {}\n", error);
 }
 
 void CMD_RandmapVoteCallback(const maplist_qrows_t &result) {
@@ -145,7 +184,7 @@ void CMD_RandmapVoteCallback(const maplist_qrows_t &result) {
 BEGIN_COMMAND(callvote) {
 	// Dumb question, but are we even connected to a server?
 	if (!connected) {
-		Printf(PRINT_HIGH, "callvote failed: You are not connected to a server.\n");
+		PrintFmt(PRINT_HIGH, "callvote failed: You are not connected to a server.\n");
 		return;
 	}
 
@@ -169,7 +208,7 @@ BEGIN_COMMAND(callvote) {
 
 		if (votecmd == VOTE_NONE) {
 			// We passed an argument but it wasn't a valid vote type.
-			Printf(PRINT_HIGH, "callvote failed: Invalid vote \"%s\".\n", votecmd_s);
+			PrintFmt(PRINT_HIGH, "callvote failed: Invalid vote \"{}\".\n", votecmd_s);
 			return;
 		}
 	}
@@ -203,7 +242,7 @@ BEGIN_COMMAND(callvote) {
 	case VOTE_MAP:
 		// If we have no arguments, ask for more.
 		if (arguments.empty()) {
-			Printf(PRINT_HIGH, "callvote failed: \"map\" callvote needs a maplist index or unambiguous map name.\n");
+			PrintFmt(PRINT_HIGH, "callvote failed: \"map\" callvote needs a maplist index or unambiguous map name.\n");
 			return;
 		}
 
@@ -241,7 +280,7 @@ BEGIN_COMMAND(vote_yes)
 {
 	if (!connected)
 	{
-		Printf(PRINT_HIGH, "vote failed: You are not connected to a server.\n");
+		PrintFmt(PRINT_HIGH, "vote failed: You are not connected to a server.\n");
 		return;
 	}
 
@@ -249,6 +288,9 @@ BEGIN_COMMAND(vote_yes)
 	MSG_WriteString(&net_buffer, "vote");
 	MSG_WriteByte(&net_buffer, 1);
 	MSG_WriteString(&net_buffer, "yes");
+
+	if (snd_votesfx)
+		S_Sound(CHAN_INTERFACE, "ui/vote/yes", 1.0f, ATTN_NONE);
 }
 END_COMMAND(vote_yes)
 
@@ -259,7 +301,7 @@ BEGIN_COMMAND(vote_no)
 {
 	if (!connected)
 	{
-		Printf(PRINT_HIGH, "vote failed: You are not connected to a server.\n");
+		PrintFmt(PRINT_HIGH, "vote failed: You are not connected to a server.\n");
 		return;
 	}
 
@@ -267,5 +309,8 @@ BEGIN_COMMAND(vote_no)
 	MSG_WriteString(&net_buffer, "vote");
 	MSG_WriteByte(&net_buffer, 1);
 	MSG_WriteString(&net_buffer, "no");
+
+	if (snd_votesfx)
+		S_Sound(CHAN_INTERFACE, "ui/vote/no", 1.0f, ATTN_NONE);
 }
 END_COMMAND(vote_no)
