@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 070d509f056f35751e5ecc26f304db283504fc4e $
+// $Id: 6f59b285e643d7ae800fba79da62fa669d4b1e34 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -42,7 +42,7 @@ struct finale_options_t
 {
 	OLumpName music;
 	OLumpName flat;
-	const char* text;
+	std::string text;
 	OLumpName pic;
 };
 
