@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d3c8d0a5baa4a09a32c2ce1648e0bd201570afa3 $
+// $Id: 139648f230007994760ba623ca8c15a848c6293c $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -297,19 +297,19 @@ bool HU_Responder(event_t *ev)
 		// send a macro
 		if (ev->data1 >= OKEY_JOY1 && ev->data1 <= OKEY_JOY10)
 		{
-			ShoveChatStr(chat_macros[ev->data1 - OKEY_JOY1]->cstring(), HU_ChatMode()- 1);
+			ShoveChatStr(chat_macros[ev->data1 - OKEY_JOY1]->str(), HU_ChatMode()- 1);
 			HU_UnsetChatMode();
 			return true;
 		}
 		else if (ev->data1 >= '0' && ev->data1 <= '9')
 		{
-			ShoveChatStr(chat_macros[ev->data1 - '0']->cstring(), HU_ChatMode() - 1);
+			ShoveChatStr(chat_macros[ev->data1 - '0']->str(), HU_ChatMode() - 1);
 			HU_UnsetChatMode();
 			return true;
 		}
 		else if (ev->data1 >= OKEYP_1 && ev->data1 <= OKEYP_0 && ev->mod & OMOD_NUM) // Use numpad keys for chat macros if numlock is on
 		{
-			ShoveChatStr(chat_macros[HU_GetMacroForNumpadKey(ev->data1)]->cstring(), HU_ChatMode() - 1);
+			ShoveChatStr(chat_macros[HU_GetMacroForNumpadKey(ev->data1)]->str(), HU_ChatMode() - 1);
 			HU_UnsetChatMode();
 			return true;
 		}
@@ -558,11 +558,11 @@ void HU_Drawer()
 		mousegraph.draw(hud_mousegraph);
 
 	if (idmypos && gamestate == GS_LEVEL)
-		Printf (PRINT_HIGH, "ang=%d;x,y,z=(%d,%d,%d)\n",
-				displayplayer().camera->angle/FRACUNIT,
-				displayplayer().camera->x/FRACUNIT,
-				displayplayer().camera->y/FRACUNIT,
-				displayplayer().camera->z/FRACUNIT);
+		PrintFmt(PRINT_HIGH, "ang={};x,y,z=({},{},{})\n",
+			     displayplayer().camera->angle/FRACUNIT,
+			     displayplayer().camera->x/FRACUNIT,
+			     displayplayer().camera->y/FRACUNIT,
+			     displayplayer().camera->z/FRACUNIT);
 
 	// Draw Netdemo info
 	hud::drawNetdemo();
@@ -666,7 +666,7 @@ BEGIN_COMMAND (say_to)
 		player_t &player = nameplayer(argv[1]);
 		if (!validplayer(player))
 		{
-			Printf(PRINT_HIGH, "%s isn't the name of anybody on the server.\n", argv[1]);
+			PrintFmt(PRINT_HIGH, "{} isn't the name of anybody on the server.\n", argv[1]);
 			return;
 		}
 
@@ -2159,7 +2159,7 @@ void HU_ConsoleScores(player_t *player)
 		}
 	}
 
-	Printf(PRINT_HIGH, "\n");
+	PrintFmt(PRINT_HIGH, "\n");
 
 	C_ToggleConsole();
 }
@@ -2169,8 +2169,8 @@ BEGIN_COMMAND (displayscores)
 	if (multiplayer)
 	    HU_ConsoleScores(&consoleplayer());
 	else
-		Printf(PRINT_HIGH, "This command is only used for multiplayer games.");
+		PrintFmt(PRINT_HIGH, "This command is only used for multiplayer games.");
 }
 END_COMMAND (displayscores)
 
-VERSION_CONTROL (hu_stuff_cpp, "$Id: d3c8d0a5baa4a09a32c2ce1648e0bd201570afa3 $")
+VERSION_CONTROL (hu_stuff_cpp, "$Id: 139648f230007994760ba623ca8c15a848c6293c $")
