@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 3b80c06c9dfe0c3a5c7418d75f896bdd16033949 $
+// $Id: 0e2f980d0f0c27b5ccac8f301fd9ba2a4068c086 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -465,11 +465,11 @@ bool OTransfer::tick()
 			return false;
 		}
 
-		Printf("Saved to fallback location \"%s\".\n", fallback);
+		PrintFmt("Saved to fallback location \"{}\".\n", fallback);
 	}
 	else
 	{
-		Printf("Saved to location \"%s\".\n", m_filename);
+		PrintFmt("Saved to location \"{}\".\n", m_filename);
 	}
 
 	m_shouldCheckAgain = false;
