@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 59b73c5737b56ac8e046cd81abc205e0f14054ff $
+// $Id: 79476a0b46207908e4729d5d8208242313aa6fe9 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -216,6 +216,7 @@ argb_t translationRGB[MAXPLAYERS+1][16];
 byte *Ranges;
 static byte *translationtablesmem = NULL;
 byte bosstable[256];
+byte friendtable[256];
 byte greentable[MAXPLAYERS + 1][256];
 byte redtable[MAXPLAYERS + 1][256];
 
@@ -233,7 +234,7 @@ static void R_BuildFontTranslation(int color_num, argb_t start_color, argb_t end
 
 	palindex_t* dest = (palindex_t*)Ranges + color_num * 256;
 
-	if (gamemode == retail_chex)
+	if (IsChexMission(gamemission))
 	{
 		for (int index = 0; index < chexstart_index; index++)
 			dest[index] = index;
@@ -262,7 +263,7 @@ static void R_BuildFontTranslation(int color_num, argb_t start_color, argb_t end
 	int b_diff = end_color.getb() - start_color.getb();
 	int hacxtrack;
 
-	if (gamemode == retail_chex)
+	if (IsChexMission(gamemission))
 	{
 		for (palindex_t index = chexstart_index; index <= chexend_index; index++)
 		{
@@ -403,6 +404,18 @@ void R_InitTranslationTables()
 		::bosstable[i] = V_BestColor(V_GetDefaultPalette()->basecolors, mul);
 	}
 
+	// Friend translation is a pink tint.
+	const argb_t ptop(0xff, 0x70, 0xB9);
+	for (size_t i = 0; i < ARRAY_LENGTH(::friendtable); i++)
+	{
+		const argb_t bot = V_GetDefaultPalette()->basecolors[i];
+		const argb_t mul(SoftLight(bot.getr(), ptop.getr()),
+		                 SoftLight(bot.getg(), ptop.getg()),
+		                 SoftLight(bot.getb(), ptop.getb()));
+
+		::friendtable[i] = V_BestColor(V_GetDefaultPalette()->basecolors, mul);
+	}
+
 	translationtablesmem = new byte[256*(MAXPLAYERS+3+22)+255]; // denis - fixme - magic numbers?
 
 	// [Toke - fix13]
@@ -622,7 +635,7 @@ static forceinline void R_FillColumnGeneric(PIXEL_T* dest, const drawcolumn_t& d
 #ifdef RANGECHECK
 	if (drawcolumn.x < 0 || drawcolumn.x >= viewwidth || drawcolumn.yl < 0 || drawcolumn.yh >= viewheight)
 	{
-		Printf (PRINT_HIGH, "R_FillColumn: %i to %i at %i\n", drawcolumn.yl, drawcolumn.yh, drawcolumn.x);
+		PrintFmt(PRINT_HIGH, "R_FillColumn: {} to {} at {}\n", drawcolumn.yl, drawcolumn.yh, drawcolumn.x);
 		return;
 	}
 #endif
@@ -661,7 +674,7 @@ static forceinline void R_DrawColumnGeneric(PIXEL_T* dest, const drawcolumn_t& d
 #ifdef RANGECHECK
 	if (drawcolumn.x < 0 || drawcolumn.x >= viewwidth || drawcolumn.yl < 0 || drawcolumn.yh >= viewheight)
 	{
-		Printf (PRINT_HIGH, "R_DrawColumn: %i to %i at %i\n", drawcolumn.yl, drawcolumn.yh, drawcolumn.x);
+		PrintFmt(PRINT_HIGH, "R_DrawColumn: {} to {} at {}\n", drawcolumn.yl, drawcolumn.yh, drawcolumn.x);
 		return;
 	}
 #endif
@@ -769,7 +782,7 @@ static forceinline void R_FillSpanGeneric(PIXEL_T* dest, const drawspan_t& draws
 	if (drawspan.x2 < drawspan.x1 || drawspan.x1 < 0 || drawspan.x2 >= viewwidth ||
 		drawspan.y >= viewheight || drawspan.y < 0)
 	{
-		Printf(PRINT_HIGH, "R_FillSpan: %i to %i at %i", drawspan.x1, drawspan.x2, drawspan.y);
+		PrintFmt(PRINT_HIGH, "R_FillSpan: {} to {} at {}", drawspan.x1, drawspan.x2, drawspan.y);
 		return;
 	}
 #endif
@@ -802,7 +815,7 @@ static forceinline void R_DrawLevelSpanGeneric(PIXEL_T* dest, const drawspan_t&
 	if (drawspan.x2 < drawspan.x1 || drawspan.x1 < 0 || drawspan.x2 >= viewwidth ||
 		drawspan.y >= viewheight || drawspan.y < 0)
 	{
-		Printf(PRINT_HIGH, "R_DrawLevelSpan: %i to %i at %i", drawspan.x1, drawspan.x2, drawspan.y);
+		PrintFmt(PRINT_HIGH, "R_DrawLevelSpan: {} to {} at {}", drawspan.x1, drawspan.x2, drawspan.y);
 		return;
 	}
 #endif
@@ -855,7 +868,7 @@ static forceinline void R_DrawSlopedSpanGeneric(PIXEL_T* dest, const drawspan_t&
 	if (drawspan.x2 < drawspan.x1 || drawspan.x1 < 0 || drawspan.x2 >= viewwidth ||
 		drawspan.y >= viewheight || drawspan.y < 0)
 	{
-		Printf(PRINT_HIGH, "R_DrawSlopedSpan: %i to %i at %i", drawspan.x1, drawspan.x2, drawspan.y);
+		PrintFmt(PRINT_HIGH, "R_DrawSlopedSpan: {} to {} at {}", drawspan.x1, drawspan.x2, drawspan.y);
 		return;
 	}
 #endif
@@ -1765,7 +1778,7 @@ static std::string get_optimization_name_list(const bool includeNone)
 
 static void print_optimizations()
 {
-	Printf(PRINT_HIGH, "r_optimize detected \"%s\"\n", get_optimization_name_list(false));
+	PrintFmt(PRINT_HIGH, "r_optimize detected \"{}\"\n", get_optimization_name_list(false));
 }
 
 static bool detect_optimizations()
@@ -1830,8 +1843,8 @@ CVAR_FUNC_IMPL(r_optimize)
 		optimize_kind = optimizations_available.back();
 	else
 	{
-		Printf(PRINT_HIGH, "Invalid value for r_optimize. Availible options are \"%s, detect\"\n",
-				get_optimization_name_list(true));
+		PrintFmt(PRINT_HIGH, "Invalid value for r_optimize. Availible options are \"{}, detect\"\n",
+		         get_optimization_name_list(true));
 
 		// Restore the original setting:
 		var.Set(get_optimization_name(optimize_kind));
@@ -1843,7 +1856,7 @@ CVAR_FUNC_IMPL(r_optimize)
 	{
 		// update the cvar string
 		// this will trigger the callback to run a second time
-		Printf(PRINT_HIGH, "r_optimize set to \"%s\" based on availability\n", optimize_name);
+		PrintFmt(PRINT_HIGH, "r_optimize set to \"{}\" based on availability\n", optimize_name);
 		var.Set(optimize_name);
 	}
 	else
@@ -1937,4 +1950,4 @@ void R_InitColumnDrawers ()
 	}
 }
 
-VERSION_CONTROL (r_draw_cpp, "$Id: 59b73c5737b56ac8e046cd81abc205e0f14054ff $")
+VERSION_CONTROL (r_draw_cpp, "$Id: 79476a0b46207908e4729d5d8208242313aa6fe9 $")
