@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 23bdf00ec67d1a5171b8a771992e28f261c0607f $
+// $Id: 816eb84ff4233c5b5a4f768913e818b235f0dc22 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -61,7 +61,7 @@ void R_DrawSpanD_SSE2 (void)
 	if (dspan.x2 < dspan.x1 || dspan.x1 < 0 || dspan.x2 >= viewwidth ||
 		dspan.y >= viewheight || dspan.y < 0)
 	{
-		Printf(PRINT_HIGH, "R_DrawLevelSpan: %i to %i at %i", dspan.x1, dspan.x2, dspan.y);
+		PrintFmt(PRINT_HIGH, "R_DrawLevelSpan: {} to {} at {}", dspan.x1, dspan.x2, dspan.y);
 		return;
 	}
 #endif
@@ -393,6 +393,6 @@ void r_dimpatchD_SSE2(IWindowSurface* surface, argb_t color, int alpha, int x1,
 }
 
 
-VERSION_CONTROL (r_drawt_sse2_cpp, "$Id: 23bdf00ec67d1a5171b8a771992e28f261c0607f $")
+VERSION_CONTROL (r_drawt_sse2_cpp, "$Id: 816eb84ff4233c5b5a4f768913e818b235f0dc22 $")
 
 #endif
