@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f94fbd2e331305403991b80d249c96d367702aba $
+// $Id: da5479501460790760b1212d7a53373d15bf5090 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -232,7 +232,7 @@ void OInterpolation::ticGameInterpolation()
 // Functions that assist with the interpolation of certain game objects
 void OInterpolation::interpolateCeilings(fixed_t amount)
 {
-	for (const auto [old_value, secnum] : prev_ceilingheight)
+	for (const auto& [old_value, secnum] : prev_ceilingheight)
 	{
 		sector_t* sector = &sectors[secnum];
 
@@ -265,7 +265,7 @@ void OInterpolation::interpolateCeilings(fixed_t amount)
 
 void OInterpolation::interpolateFloors(fixed_t amount)
 {
-	for (const auto [old_value, secnum] : prev_floorheight)
+	for (const auto& [old_value, secnum] : prev_floorheight)
 	{
 		sector_t* sector = &sectors[secnum];
 
@@ -382,7 +382,7 @@ void OInterpolation::beginGameInterpolation(fixed_t amount)
 void OInterpolation::restoreCeilings(void)
 {
 	// Ceiling heights
-	for (const auto [height, secnum] : saved_ceilingheight)
+	for (const auto& [height, secnum] : saved_ceilingheight)
 	{
 		sector_t* sector = &sectors[secnum];
 		P_SetCeilingHeight(sector, height);
@@ -598,4 +598,4 @@ fixed_t OInterpolation::getInterpolatedConsoleBottom(fixed_t amount)
 	return prev_conbottomstep + FixedMul(amount, saved_conbottomstep - prev_conbottomstep);
 }
 
-VERSION_CONTROL (r_interp_cpp, "$Id: f94fbd2e331305403991b80d249c96d367702aba $")
+VERSION_CONTROL (r_interp_cpp, "$Id: da5479501460790760b1212d7a53373d15bf5090 $")
