@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d0a6d8fa9b6f2dbc5c83d0b95529405303b52cd1 $
+// $Id: 0a21bf58ab5fe2e8c42a8d9d5f49c2074c3c1434 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -644,6 +644,20 @@ subsector_t *R_PointInSubsector (fixed_t x, fixed_t y)
 	return &subsectors[nodenum & ~NF_SUBSECTOR];
 }
 
+//
+//
+// R_SetViewAngle
+//
+//
+
+void R_SetViewAngle(angle_t ang)
+{
+	viewangle = ang;
+
+	viewsin = finesine[ang >> ANGLETOFINESHIFT];
+	viewcos = finecosine[ang >> ANGLETOFINESHIFT];
+}
+
 //
 // R_ViewShear
 //
@@ -990,7 +1004,7 @@ void R_RenderPlayerView(player_t* player)
 	R_ClearClipSegs();
 	R_ClearDrawSegs();
 	R_ClearOpenings();
-	R_ClearPlanes();
+	R_ClearPlanes(true);
 	R_ClearSprites();
 
 	R_ResetDrawFuncs();
@@ -1025,7 +1039,7 @@ void R_RenderPlayerView(player_t* player)
 		R_RenderBSPNode(numnodes - 1);	// The head node is the last node output.
 
 	R_DrawPlanes();
-
+	R_DrawSkyBoxes();
 	R_DrawMasked();
 
 	// NOTE(jsd): Full-screen status color blending:
@@ -1289,4 +1303,4 @@ void R_ExitLevel()
 	r_underwater = false;
 }
 
-VERSION_CONTROL (r_main_cpp, "$Id: d0a6d8fa9b6f2dbc5c83d0b95529405303b52cd1 $")
+VERSION_CONTROL (r_main_cpp, "$Id: 0a21bf58ab5fe2e8c42a8d9d5f49c2074c3c1434 $")
