@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b3b81a839cd668076619952e7eafed0143246dc3 $
+// $Id: 92647e2c760f2079393f6e834295d365bed2977e $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -97,6 +97,7 @@ extern float yfoc;
 
 static tallpost_t** masked_midposts;
 
+EXTERN_CVAR(r_clipmaskedspecial)
 
 //
 // R_TexScaleX
@@ -942,6 +943,9 @@ void R_StoreWallRange(int start, int stop)
 				// killough 4/17/98: draw floors if different light levels
 				|| backsector->floorlightsec != frontsector->floorlightsec
 
+				// [EB] check for special too for DSDA-compatibility on MBF21
+				|| (r_clipmaskedspecial && backsector->special != frontsector->special)
+
 				// [RH] Add checks for colormaps
 				|| backsector->colormap != frontsector->colormap
 
@@ -1135,4 +1139,4 @@ void R_ClearOpenings()
 	sprclip_pool.clear();
 }
 
-VERSION_CONTROL (r_segs_cpp, "$Id: b3b81a839cd668076619952e7eafed0143246dc3 $")
+VERSION_CONTROL (r_segs_cpp, "$Id: 92647e2c760f2079393f6e834295d365bed2977e $")
