@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 1f17e03524ba2494783aef9e65e228f542f16d76 $
+// $Id: 8c282af3897e5e01f521d81acbdb619f41067ab3 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -44,6 +44,7 @@ extern fixed_t freelookviewheight;
 
 EXTERN_CVAR(sv_freelook)
 EXTERN_CVAR(cl_mouselook)
+EXTERN_CVAR(joy_freelook)
 EXTERN_CVAR(r_skypalette)
 EXTERN_CVAR(r_linearsky)
 
@@ -292,8 +293,10 @@ void R_InitSkyMap()
 
 	if (fskyheight <= (128 << FRACBITS))
 	{
-		defaultskytexturemid = 200/2*FRACUNIT;
-		skystretch = (r_stretchsky == 1) || consoleplayer().spectator || (r_stretchsky == 2 && sv_freelook && cl_mouselook);
+		defaultskytexturemid = 200 / 2 * FRACUNIT;
+		skystretch = ((r_stretchsky != 0) && consoleplayer().spectator) ||
+		             (r_stretchsky == 1) ||
+		             (r_stretchsky == 2 && sv_freelook && (cl_mouselook || joy_freelook));
 	}
 	else
 	{
@@ -941,4 +944,4 @@ void R_RenderSkyRange(visplane_t* pl)
 	R_ResetDrawFuncs();
 }
 
-VERSION_CONTROL (r_sky_cpp, "$Id: 1f17e03524ba2494783aef9e65e228f542f16d76 $")
+VERSION_CONTROL (r_sky_cpp, "$Id: 8c282af3897e5e01f521d81acbdb619f41067ab3 $")
