@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: bf4bf8ae07c14c7d62c4c3d53ecb2c5622e7a8bb $
+// $Id: c081083cc7a735e35b7b382b16844103321d9cfc $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -68,7 +68,7 @@ fixed_t bobx;
 fixed_t boby;
 
 #define MAX_SPRITE_FRAMES 29		// [RH] Macro-ized as in BOOM.
-#define SPRITE_NEEDS_INFO	MAXINT
+#define SPRITE_NEEDS_INFO	limits::MAXINT
 
 EXTERN_CVAR (r_drawplayersprites)
 EXTERN_CVAR (r_softinvulneffect)
@@ -88,7 +88,7 @@ extern int				NumParticles;
 extern int				ActiveParticles;
 extern int				InactiveParticles;
 extern particle_t		*Particles;
-TArray<WORD>			ParticlesInSubsec;
+std::vector<WORD>		ParticlesInSubsec;
 
 
 
@@ -106,7 +106,7 @@ int 			newvissprite;
 //
 void R_ClearSprites()
 {
-	vissprite_p = vissprites;
+	vissprite_p = firstvissprite;
 }
 
 
@@ -116,11 +116,13 @@ void R_ClearSprites()
 vissprite_t *R_NewVisSprite()
 {
 	if (vissprite_p == lastvissprite) {
+		int firstvisspritenum = firstvissprite - vissprites;
 		int prevvisspritenum = vissprite_p - vissprites;
 
 		MaxVisSprites *= 2;
 		vissprites = (vissprite_t *)M_Realloc (vissprites, MaxVisSprites * sizeof(vissprite_t));
 		lastvissprite = &vissprites[MaxVisSprites];
+		firstvissprite = &vissprites[firstvisspritenum];
 		vissprite_p = &vissprites[prevvisspritenum];
 		DPrintFmt("MaxVisSprites increased to {}\n", MaxVisSprites);
 	}
@@ -324,8 +326,8 @@ void R_DrawVisSprite (vissprite_t *vis, int x1, int x2)
 #if 0
 	if ((colfrac - vis->xiscale) >> FRACBITS != end)
 	{
-		Printf(PRINT_WARNING, "Bad vissprite bounds check! (pw:%d  ex:%d  act:%d)\n",
-		       patchWidth, end, colfrac >> FRACBITS);
+		PrintFmt(PRINT_WARNING, "Bad vissprite bounds check! (pw:{}  ex:{}  act:{})\n",
+		         patchWidth, end, colfrac >> FRACBITS);
 	}
 #endif
 
@@ -523,8 +525,6 @@ void R_DrawHitBox(AActor* thing)
 //
 void R_ProjectSprite(AActor *thing, int fakeside)
 {
-	spritedef_t*		sprdef;
-	spriteframe_t*		sprframe;
 	int 				lump;
 	unsigned int		rot;
 	bool 				flip;
@@ -563,25 +563,27 @@ void R_ProjectSprite(AActor *thing, int fakeside)
 		thingz = thing->z;
 	}
 
+	auto it = sprites.find(thing->sprite);
+
 #ifdef RANGECHECK
-	if (static_cast<unsigned>(thing->sprite) >= static_cast<unsigned>(numsprites))
+	if (it == sprites.end())
 	{
-		DPrintFmt("R_ProjectSprite: invalid sprite number {}\n", thing->sprite);
+		DPrintFmt("R_ProjectSprite: thing ({}: {}): invalid sprite number {}\n on ", thing->type, thing->info->name, thing->sprite);
 		return;
 	}
 #endif
 
-	sprdef = &sprites[thing->sprite];
+	const spritedef_t* sprdef = &it->second;
 
 #ifdef RANGECHECK
 	if ( (thing->frame & FF_FRAMEMASK) >= sprdef->numframes )
 	{
-		DPrintFmt("R_ProjectSprite: invalid sprite frame {} : {}\n ", thing->sprite, thing->frame);
+		DPrintFmt("R_ProjectSprite: thing ({}: {}): invalid sprite frame {} : {}\n ", thing->type, thing->info->name, thing->sprite, thing->frame);
 		return;
 	}
 #endif
 
-	sprframe = &sprdef->spriteframes[thing->frame & FF_FRAMEMASK];
+	const spriteframe_t* sprframe = &sprdef->spriteframes[thing->frame & FF_FRAMEMASK];
 
 	// decide which patch to use for sprite relative to player
 	if (sprframe->rotate)
@@ -608,8 +610,15 @@ void R_ProjectSprite(AActor *thing, int fakeside)
 		flip = sprframe->flip[0];
 	}
 
+	if (lump == -1) {
+		char frame = (thing->frame & FF_FRAMEMASK) + 'A';
+		I_Error("Frame {} for sprite {} could not be found.", frame, sprnames[thing->sprite]);
+	}
+
 	if (sprframe->width[rot] == SPRITE_NEEDS_INFO)
+	{
 		R_CacheSprite (sprdef);	// [RH] speeds up game startup time
+	}
 
 	sector_t* sector = thing->subsector->sector;
 	fixed_t topoffs = sprframe->topoffset[rot];
@@ -702,65 +711,58 @@ void R_AddSprites (sector_t *sec, int lightlevel, int fakeside)
 //
 void R_DrawPSprite(pspdef_t* psp, unsigned flags)
 {
-	fixed_t 			tx;
-	int 				x1;
-	int 				x2;
-	spritedef_t*		sprdef;
-	spriteframe_t*		sprframe;
-	int 				lump;
-	bool 				flip;
-	vissprite_t*		vis;
 	vissprite_t 		avis;
 
 	// decide which patch to use
+	auto it = sprites.find(psp->state->sprite);
 #ifdef RANGECHECK
-	if ( (unsigned)psp->state->sprite >= (unsigned)numsprites) {
+	if (it == sprites.end()) {
 		DPrintFmt("R_DrawPSprite: invalid sprite number {}\n", psp->state->sprite);
 		return;
 	}
 #endif
-	sprdef = &sprites[psp->state->sprite];
+	const spritedef_t* sprdef = &it->second;
 #ifdef RANGECHECK
 	if ( (psp->state->frame & FF_FRAMEMASK) >= sprdef->numframes) {
 		DPrintFmt("R_DrawPSprite: invalid sprite frame {} : {}\n", psp->state->sprite, psp->state->frame);
 		return;
 	}
 #endif
-	sprframe = &sprdef->spriteframes[ psp->state->frame & FF_FRAMEMASK ];
+	const spriteframe_t* sprframe = &sprdef->spriteframes[ psp->state->frame & FF_FRAMEMASK ];
 
-	lump = sprframe->lump[0];
-	flip = sprframe->flip[0];
+	const int32_t lump = sprframe->lump[0];
+	const bool flip = sprframe->flip[0];
 
 	if (sprframe->width[0] == SPRITE_NEEDS_INFO)
 		R_CacheSprite (sprdef);	// [RH] speeds up game startup time
 
 	// calculate edges of the shape
-	tx = bobx - ((320 / 2) << FRACBITS);
+	fixed_t tx = bobx - ((320 / 2) << FRACBITS);
 
 	tx -= sprframe->offset[0];	// [RH] Moved out of spriteoffset[]
-	x1 = (centerxfrac + FixedMul (tx, pspritexscale)) >>FRACBITS;
+	const int32_t x1 = (centerxfrac + FixedMul (tx, pspritexscale)) >>FRACBITS;
 
 	// off the right side
 	if (x1 > viewwidth)
 		return;
 
 	tx += sprframe->width[0];	// [RH] Moved out of spritewidth[]
-	x2 = ((centerxfrac + FixedMul (tx, pspritexscale)) >>FRACBITS) - 1;
+	const int32_t x2 = ((centerxfrac + FixedMul (tx, pspritexscale)) >>FRACBITS) - 1;
 
 	// off the left side
 	if (x2 < 0)
 		return;
 
 	// store information in a vissprite
-	vis = &avis;
+	vissprite_t* vis = &avis;
 	vis->mobjflags = flags;
 	vis->statusflags = camera->player && camera->player->mo ? camera->player->mo->statusflags : 0;
 
-// [RH] +0x6000 helps it meet the screen bottom
-//		at higher resolutions while still being in
-//		the right spot at 320x200.
-// denis - bump to 0x9000
-#define WEAPONTWEAK				(0x9000)
+	// [RH] +0x6000 helps it meet the screen bottom
+	//		at higher resolutions while still being in
+	//		the right spot at 320x200.
+	// denis - bump to 0x9000
+	static constexpr fixed_t WEAPONTWEAK = 0x9000;
 
 	vis->texturemid = (BASEYCENTER << FRACBITS) + FRACUNIT / 2 -
 		(boby + WEAPONTWEAK - sprframe->topoffset[0]);	// [RH] Moved out of spritetopoffset[]
@@ -924,20 +926,22 @@ static int STACK_ARGS sv_compare(const void *arg1, const void *arg2)
 
 void R_SortVisSprites()
 {
-	vsprcount = vissprite_p - vissprites;
+	vsprcount = vissprite_p - firstvissprite;
 
 	if (!vsprcount)
 		return;
 
 	if (spritesorter_size < MaxVisSprites)
 	{
-		delete [] spritesorter;
+		if (spritesorter != NULL)
+			delete [] spritesorter;
 		spritesorter = new vissprite_t*[MaxVisSprites];
 		spritesorter_size = MaxVisSprites;
 	}
 
-	for (int i = 0; i < vsprcount; i++)
-		spritesorter[i] = vissprites + i;
+	vissprite_t* spr = firstvissprite;
+	for (int i = 0; i < vsprcount; i++, spr++)
+		spritesorter[i] = spr;
 
 	qsort(spritesorter, vsprcount, sizeof(vissprite_t *), sv_compare);
 }
@@ -1021,7 +1025,7 @@ void R_DrawSprite (vissprite_t *spr)
 	// (pointer check was originally nonportable
 	// and buggy, by going past LEFT end of array):
 
-	for (ds = ds_p ; ds-- > drawsegs ; )  // new -- killough
+	for (ds = ds_p ; ds-- > firstdrawseg ; )  // new -- killough
 	{
 		// determine if the drawseg obscures the sprite
 		if (ds->x1 > spr->x2 || ds->x2 < spr->x1 ||
@@ -1038,8 +1042,8 @@ void R_DrawSprite (vissprite_t *spr)
 		segscale2 = MIN<int>(ds->scale1, ds->scale2);
 
 		// check if the seg is in front of the sprite
-		if (segscale1 < spr->yscale ||
-			(segscale2 < spr->yscale && !R_PointOnSegSide(spr->gx, spr->gy, ds->curline)))
+		if (!(!ds->curline) && (segscale1 < spr->yscale ||
+			(segscale2 < spr->yscale && !R_PointOnSegSide(spr->gx, spr->gy, ds->curline))))
 		{
 			// masked mid texture?
 			if (ds->midposts)
@@ -1084,8 +1088,10 @@ void R_DrawMasked (void)
 
 	R_SortVisSprites ();
 
-	while (vsprcount > 0)
-		R_DrawSprite(spritesorter[--vsprcount]);
+	for (int i = vsprcount; i > 0; i--)
+	{
+		R_DrawSprite(spritesorter[i-1]);
+	}
 
 	// render any remaining masked mid textures
 
@@ -1095,7 +1101,7 @@ void R_DrawMasked (void)
 
 	//		for (ds=ds_p-1 ; ds >= drawsegs ; ds--)    old buggy code
 
-	for (ds=ds_p ; ds-- > drawsegs ; )	// new -- killough
+	for (ds=ds_p ; ds-- > firstdrawseg ; )	// new -- killough
 		if (ds->midposts)
 			R_RenderMaskedSegRange(ds, ds->x1, ds->x2);
 
@@ -1136,12 +1142,8 @@ void R_ClearParticles (void)
 
 void R_FindParticleSubsectors ()
 {
-	if (ParticlesInSubsec.Size() < (size_t)numsubsectors)
-		ParticlesInSubsec.Reserve(numsubsectors - ParticlesInSubsec.Size());
-
 	// fill the buffer with NO_PARTICLE
-	for (int i = 0; i < numsubsectors; i++)
-		ParticlesInSubsec[i] = NO_PARTICLE;
+	ParticlesInSubsec.assign(numsubsectors, NO_PARTICLE);
 
 	if (!r_particles)
 		return;
@@ -1164,24 +1166,44 @@ void R_ProjectParticle (particle_t *particle, const sector_t *sector, int fakesi
 	fixed_t x = particle->x;
 	fixed_t y = particle->y;
 	fixed_t z = particle->z;
-	fixed_t height = particle->size*(FRACUNIT/4);
-	fixed_t width = particle->size*(FRACUNIT/4);
+	fixed_t height = particle->size * (FRACUNIT / 4);
+	fixed_t width = particle->size * (FRACUNIT / 4);
 	fixed_t topoffs = height;
 	fixed_t sideoffs = width >> 1;
 
+	if (particle->sprite != NO_PARTICLE)
+	{
+		patch_t* patch = W_CachePatch(particle->sprite);
+		height = patch->height() << FRACBITS;
+		width = patch->width() << FRACBITS;
+		topoffs = patch->topoffset();
+		sideoffs = patch->leftoffset();
+	}
+
 	vissprite_t* vis = R_GenerateVisSprite(sector, fakeside, x, y, z, height, width, topoffs, sideoffs, false);
 
 	if (vis == NULL)
 		return;
 
 	vis->translation = translationref_t();
-	vis->startfrac = particle->color;
-	vis->patch = NO_PARTICLE;
-	vis->mobjflags = particle->trans;
+	vis->translucency = 65535;
 	vis->statusflags = 0;
 	vis->mo = NULL;
 	vis->spectator = false;
 
+	if (particle->sprite == NO_PARTICLE)
+	{
+		vis->startfrac = particle->color;
+		vis->patch = NO_PARTICLE;
+		vis->mobjflags = particle->trans;
+	}
+	else
+	{
+		vis->patch = particle->sprite;
+		vis->translucency = (particle->trans + 1) << 8;
+		vis->mobjflags = 0;
+	}
+
 	// get light level
 	if (fixedcolormap.isValid())
 	{
@@ -1232,4 +1254,4 @@ void R_DrawParticle(vissprite_t* vis)
 		R_FillTranslucentSpan();
 }
 
-VERSION_CONTROL (r_things_cpp, "$Id: bf4bf8ae07c14c7d62c4c3d53ecb2c5622e7a8bb $")
+VERSION_CONTROL (r_things_cpp, "$Id: c081083cc7a735e35b7b382b16844103321d9cfc $")
