@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: db2651544649aad59d412553761fe987f5a31614 $
+// $Id: b411c9ffc0036dab16a23735a08bf1b5050787da $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -647,7 +647,7 @@ BEGIN_COMMAND (idmus)
 				map = CalcMapName(0, l);
 			else
 			{
-				Printf(PRINT_HIGH, "%s\n", GStrings(STSTR_NOMUS));
+				PrintFmt(PRINT_HIGH, "{}\n", GStrings(STSTR_NOMUS));
 				return;
 			}
 		}
@@ -662,12 +662,12 @@ BEGIN_COMMAND (idmus)
 			if (info.music[0])
 			{
 				S_ChangeMusic(std::string(info.music.c_str(), 8), 1);
-				Printf(PRINT_HIGH, "%s\n", GStrings(STSTR_MUS));
+				PrintFmt(PRINT_HIGH, "{}\n", GStrings(STSTR_MUS));
 			}
 		}
 		else
 		{
-			Printf(PRINT_HIGH, "%s\n", GStrings(STSTR_NOMUS));
+			PrintFmt(PRINT_HIGH, "{}\n", GStrings(STSTR_NOMUS));
 		}
 	}
 }
@@ -696,7 +696,7 @@ BEGIN_COMMAND (fov)
 		return;
 
 	if (argc != 2)
-		Printf(PRINT_HIGH, "FOV is %g\n", m_Instigator->player->fov);
+		PrintFmt(PRINT_HIGH, "FOV is {:g}\n", m_Instigator->player->fov);
 	else
 	{
 		m_Instigator->player->fov = clamp((float)atof(argv[1]), 45.0f, 135.0f);
@@ -1394,4 +1394,4 @@ void STACK_ARGS ST_Shutdown()
 }
 
 
-VERSION_CONTROL (st_stuff_cpp, "$Id: db2651544649aad59d412553761fe987f5a31614 $")
+VERSION_CONTROL (st_stuff_cpp, "$Id: b411c9ffc0036dab16a23735a08bf1b5050787da $")
