@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 971f9911fdb77250fae7bbfc9476aa586a5123eb $
+// $Id: dc82e5e5ecf627ef2cc66019a59586dd9a41af33 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -580,7 +580,7 @@ void DCanvas::DrawWrapper(EWrapperCode drawer, const patch_t* patch, int x, int
 	{
 	  // Printf (PRINT_HIGH, "Patch at %d,%d exceeds LFB\n", x,y );
 	  // No I_Error abort - what is up with TNT.WAD?
-	  DPrintFmt("DCanvas::DrawWrapper: bad patch (ignored)\n");
+	  DPrintFmt("DCanvas::DrawWrapper: bad patch dimensions ({} x {}) (ignored)\n", patch->width(), patch->height());
 	  return;
 	}
 #endif
@@ -666,7 +666,7 @@ void DCanvas::DrawSWrapper(EWrapperCode drawer, const patch_t* patch, int x0, in
 #ifdef RANGECHECK
 	if (x0 < 0 || x0 + destwidth > surface_width || y0 < 0 || y0 + destheight > surface_height)
 	{
-		DPrintFmt("DCanvas::DrawSWrapper: bad patch (ignored)\n");
+		DPrintFmt("DCanvas::DrawSWrapper: bad patch dimensions ({} x {}) (ignored)\n", patch->width(), patch->height());
 		return;
 	}
 #endif
@@ -1003,4 +1003,4 @@ void DCanvas::GetTransposedBlock(int x, int y, int width, int height, byte* dest
 				x, y, width, height, mSurface->getPitchInPixels());
 }
 
-VERSION_CONTROL (v_draw_cpp, "$Id: 971f9911fdb77250fae7bbfc9476aa586a5123eb $")
+VERSION_CONTROL (v_draw_cpp, "$Id: dc82e5e5ecf627ef2cc66019a59586dd9a41af33 $")
