@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f2dbad6711f9a84397674dc4807652949cc0aea4 $
+// $Id: 3f9fe71bbc1d89bb09bc33e0865877ec894c77d4 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -87,7 +87,7 @@ EXTERN_CVAR(cl_screenshotdir)
 CVAR_FUNC_IMPL(cl_screenshotname)
 {
 	// No empty format strings allowed.
-	if (strlen(var.cstring()) == 0)
+	if (var.str().empty())
 		var.RestoreDefault();
 }
 
@@ -415,4 +415,4 @@ void V_ScreenShot(std::string filename)
 }
 
 
-VERSION_CONTROL (v_screenshot_cpp, "$Id: f2dbad6711f9a84397674dc4807652949cc0aea4 $")
+VERSION_CONTROL (v_screenshot_cpp, "$Id: 3f9fe71bbc1d89bb09bc33e0865877ec894c77d4 $")
