@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b78da016753f24ce367bb2c0b2fbf1e47be10117 $
+// $Id: 67d5743591fb2b9624a95a352e2f28998b000481 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -117,4 +117,11 @@ inline bool AM_OverlayAutomapVisible() { return automapactive && viewactive; };
 
 void AM_SetBaseColorDoom();
 void AM_SetBaseColorRaven();
-void AM_SetBaseColorStrife();
\ No newline at end of file
+void AM_SetBaseColorStrife();
+
+enum class am_lump_parse_error_t
+{
+	LUMP_NOT_FOUND,
+};
+
+nonstd::expected<std::vector<mline_t>, am_lump_parse_error_t> AM_ParseVectorLump(const OLumpName& name);
