@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 103a608fc65ef07088404f7f78553a54a7718597 $
+// $Id: b537cba4833dd372a36384565bcd50454f7bf3b0 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -26,7 +26,6 @@
 //Uncomment to allow for latency simulation - see sv_latency in sv_cvarlist.cpp
 //Note: When compiling for linux you will have link against pthread manually
 //#define SIMULATE_LATENCY
-#include "tarray.h"
 
 #include <cfloat>
 
@@ -130,7 +129,7 @@ public:
 
 	[[nodiscard]] const char *cstring() const {return m_String.c_str(); }
 	[[nodiscard]] const std::string& str() const { return m_String; }
-	[[nodiscard]] const char *name() const { return m_Name.c_str(); }
+	[[nodiscard]] const std::string& name() const { return m_Name; }
 	[[nodiscard]] const char *helptext() const {return m_HelpText.c_str(); }
 	[[nodiscard]] const char *latched() const { return m_LatchedString.c_str(); }
 	[[nodiscard]] float value() const { return m_Value; }
@@ -183,7 +182,7 @@ public:
 	static void C_RestoreCVars (void);
 
 	// Finds a named cvar
-	static cvar_t *FindCVar (const char *var_name, cvar_t **prev);
+	static cvar_t *FindCVar (std::string_view var_name, cvar_t **prev);
 
 	// Called from G_InitNew()
 	static void UnlatchCVars (void);
@@ -197,9 +196,9 @@ public:
 	// the filtering.
 	static void C_SetCVarsToDefaults (unsigned int bitflag = 0xFFFFFFFF);
 
-	static bool SetServerVar (const char *name, const char *value);
+	static bool SetServerVar (std::string_view name, const char *value);
 
-	static void FilterCompactCVars (TArray<cvar_t *> &cvars, DWORD filter);
+	static void FilterCompactCVars (std::vector<cvar_t *> &cvars, DWORD filter);
 
 	// console variable interaction
 	static cvar_t *cvar_set (const char *var_name, const char *value);
