@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d964bf0e7baca98eb86a8eae6f300fb6bfee2855 $
+// $Id: 0ce3fa13a9171512a1f33a8e99b78cfecaf9a2ea $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -25,6 +25,8 @@
 
 #include "dobject.h"
 
+#include <optional>
+#include <functional>
 
 void C_ExecCmdLineParams (bool onlyset, bool onlylogfile);
 
@@ -32,8 +34,19 @@ void C_ExecCmdLineParams (bool onlyset, bool onlylogfile);
 // for map changing, etc
 void AddCommandString(const std::string &cmd, uint32_t key = 0);
 
+struct parse_string_result_t
+{
+	std::optional<std::string> token;
+	std::string_view rest;
+
+	operator bool() const
+	{
+		return token.has_value();
+	}
+};
+
 // parse a command string
-const char *ParseString (const char *data);
+std::function<parse_string_result_t()> ParseString(std::string_view data, bool expandVars);
 
 // combine many arguments into one valid argument.
 std::string C_ArgCombine(size_t argc, const char **argv);
@@ -53,7 +66,7 @@ public:
 	~DConsoleCommand () override;
 	virtual void Run (uint32_t key = 0) = 0;
 	virtual bool IsAlias () { return false; }
-	void PrintCommand () { Printf (PRINT_HIGH, "%s\n", m_Name); }
+	void PrintCommand () { PrintFmt(PRINT_HIGH, "{}\n", m_Name); }
 
 	std::string m_Name;
 
@@ -63,9 +76,9 @@ protected:
 	AActor *m_Instigator;
 	size_t argc;
 	char **argv;
-	char *args;
+	const char *args;
 
-	friend void C_DoCommand(const char *cmd, uint32_t key);
+	friend void C_DoCommand(std::string_view cmd, uint32_t key);
 };
 
 #define BEGIN_COMMAND(n) \
@@ -87,7 +100,7 @@ public:
 	~DConsoleAlias () override;
 	void Run (uint32_t key = 0) override;
 	bool IsAlias () override { return true; }
-	void PrintAlias () { Printf (PRINT_HIGH, "%s : %s\n", m_Name, m_Command); }
+	void PrintAlias () { PrintFmt(PRINT_HIGH, "{} : {}\n", m_Name, m_Command); }
 	void Archive (FILE *f);
 
 	// Write out alias commands to a file for all current aliases.
