@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: c59b62d64566920f10b52d5589379f1bb594b1d6 $
+// $Id: eda232b8fa050888feddc0de9935cb9c6d6302ed $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -25,6 +25,8 @@
 
 #include <algorithm>
 #include <ctime>
+#include <optional>
+#include <charconv>
 
 #ifdef _MSC_VER
 #pragma warning(disable : 4244)     // MIPS
@@ -54,11 +56,32 @@ struct OTimespan
 int		ParseHex(const char *str);
 int 	ParseNum(const char *str);
 bool	IsNum(const char* str);		// [RH] added
+bool	IsNum(std::string_view str);
 bool	IsRealNum(const char* str);
 
+template<typename T>
+std::optional<T> ParseNum(std::string_view str)
+{
+    T out;
+	int base = 10;
+	while (!str.empty() && std::isspace(static_cast<unsigned char>(str.front())))
+		str.remove_prefix(1);
+	if (str[0] == '$')
+	{
+		str.remove_prefix(1);
+		base = 16;
+	}
+    const std::from_chars_result result = std::from_chars(str.data(), str.data() + str.size(), out, base);
+    if (result.ec != std::errc())
+    {
+        return std::nullopt;
+    }
+    return out;
+}
+
 // [Russell] Returns 0 if strings are the same, optional parameter for case
 // sensitivity
-bool iequals(const std::string &, const std::string &);
+bool iequals(std::string_view, std::string_view);
 
 size_t  StdStringFind(const std::string& haystack, const std::string& needle,
     size_t pos = 0, size_t n = std::string::npos, bool CIS = false);
@@ -78,11 +101,6 @@ std::string &TrimStringEnd(std::string &s);
 bool ValidString(const std::string&);
 bool IsHexString(const std::string& str, const size_t len);
 
-char	*COM_Parse (char *data);
-
-extern	char	com_token[8192];
-extern	bool	com_eof;
-
 char	*copystring(const char *s);
 bool M_StringCopy(char *dest, const char *src, size_t dest_size);
 
@@ -107,7 +125,6 @@ void StripColorCodes(std::string& str);
 double Remap(const double value, const double low1, const double high1, const double low2,
              const double high2);
 uint32_t Log2(uint32_t n);
-float NextAfter(const float from, const float to);
 
 /**
  * @brief Initialize an array with a specific value.
