@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 44d5a4c7dabd35117c5525fe834d9f114af9203e $
+// $Id: 17e80afff4b28ce22cdae4a0c7dc5d75927fe3a4 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -56,7 +56,7 @@ extern	weaponinfo_t	weaponinfo[NUMWEAPONS+1];
 #define WPF_NOTHRUST		BIT(0)
 #define WPF_SILENT			BIT(1)
 #define WPF_NOAUTOFIRE		BIT(2)
-#define WPF_FLEEMELEE		BIT(3)	// Not Implemented yet (Missing MBF code?)...
+#define WPF_FLEEMELEE		BIT(3)
 #define WPF_AUTOSWITCHFROM	BIT(4)
 #define WPF_NOAUTOSWITCHTO	BIT(5)
 
