@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: fb83213af98759f1abbadfce6c5e463589319c82 $
+// $Id: 0d574cf265da5d6d076163d6c6d45c3d738027bd $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -58,14 +58,8 @@
 #include "gi.h"
 #include "w_ident.h"
 #include "m_resfile.h"
-
-#ifdef GEKKO
-#include "i_wii.h"
-#endif
-
-#ifdef _XBOX
-#include "i_xbox.h"
-#endif
+#include "odainfo.h"
+#include "infomap.h"
 
 OResFiles wadfiles;
 OResFiles patchfiles;
@@ -78,8 +72,7 @@ extern bool step_mode;
 bool capfps = true;
 float maxfps = 35.0f;
 
-
-#if defined(_WIN32) && !defined(_XBOX)
+#if defined(_WIN32)
 
 typedef struct
 {
@@ -250,6 +243,44 @@ static char *GetRegistryString(registry_value_t *reg_val)
 
 #endif
 
+//
+// D_InitializeDoomObjectTables()
+// [CMB] Initialize all the doom objects: MobjInfo, SprNames, SoundMap, etc.
+//
+void D_InitializeDoomObjectTables()
+{
+	// [RH] Initialize items. Still only used for the give command. :-(
+	InitItems();
+	// Initialize states
+	states.clear();
+	states.insert({boomstates, ::NUMSTATES}, S_NULL);
+	states.insert(getOdaStates(), S_GIB0);
+	// Initialize mobjinfo
+	mobjinfo.clear();
+	mobjinfo.insert({doom_mobjinfo, ::NUMMOBJTYPES}, MT_PLAYER);
+	mobjinfo.insert(getOdaMobjinfo(), MT_GIB0);
+	// Initialize sprnames
+	sprnames.clear();
+	sprnames.insert({doom_sprnames, ::NUMSPRITES}, SPR_TROO);
+	sprnames.insert(getOdaSprNames(), SPR_GIB0);
+	// Initialize soundmap
+	SoundMap.clear();
+	SoundMap.insert({doom_SoundMap, ARRAY_LENGTH(doom_SoundMap)}, 0);
+	SoundMap.insert({odamex_SoundMap, ARRAY_LENGTH(odamex_SoundMap)}, 0x80000000);
+	// Initialize spawn map
+	D_BuildSpawnMap();
+
+	states.rebuildMap(
+		[](const state_t& lhs, const state_t& rhs){ return lhs.statenum < rhs.statenum; },
+		[](const state_t& s){ return s.statenum; }
+	);
+	mobjinfo.rebuildMap(
+		[](const mobjinfo_t& lhs, const mobjinfo_t& rhs){
+			return lhs.type < rhs.type || (lhs.type == rhs.type && lhs.doomednum < rhs.doomednum);
+		},
+		[](const mobjinfo_t& m){ return m.type; }
+	);
+}
 
 //
 // D_AddSearchDir
@@ -281,7 +312,7 @@ void D_AddSearchDir(std::vector<std::string> &dirs, const char *dir, const char
 // [AM] Add platform-sepcific search directories
 void D_AddPlatformSearchDirs(std::vector<std::string> &dirs)
 {
-	#if defined(_WIN32) && !defined(_XBOX)
+	#if defined(_WIN32)
 
 	const char separator = ';';
 
@@ -444,8 +475,8 @@ static void D_PrintIWADIdentity()
 {
 	if (clientside)
 	{
-		Printf(PRINT_HIGH, "\n\35\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36"
-    	                   "\36\36\36\36\36\36\36\36\36\36\36\36\37\n");
+		PrintFmt(PRINT_HIGH, "\n\35\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36"
+    	                     "\36\36\36\36\36\36\36\36\36\36\36\36\37\n");
 
 		if (gamemode == undetermined)
 			PrintFmt_Bold("Game mode indeterminate, no standard wad found.\n\n");
@@ -455,9 +486,9 @@ static void D_PrintIWADIdentity()
 	else
 	{
 		if (gamemode == undetermined)
-			Printf(PRINT_HIGH, "Game mode indeterminate, no standard wad found.\n");
+			PrintFmt(PRINT_HIGH, "Game mode indeterminate, no standard wad found.\n");
 		else
-			Printf(PRINT_HIGH, "%s\n", D_GetTitleString());
+			PrintFmt(PRINT_HIGH, "{}\n", D_GetTitleString());
 	}
 }
 
@@ -465,31 +496,25 @@ static void D_PrintIWADIdentity()
 /**
  * @brief Load all found DEH patches, as well as all found DEHACKED lumps.
  */
-void D_LoadResolvedPatches()
+void D_LoadResolvedPatches(bool reloadStrings)
 {
+	// Load internal chex.deh if necessary
+	if (::gamemode == retail_chex)
+	{
+		D_DoDehPatch(nullptr, W_GetNumForName("_CHXHACK"), reloadStrings);
+	}
+
 	// Load external patch files first.
-	bool chexLoaded = false;
 	for (const auto& file : ::patchfiles)
 	{
-		if (StdStringToUpper(file.getBasename()) == "CHEX.DEH")
-		{
-			chexLoaded = true;
-		}
-		D_DoDehPatch(&file, -1);
+		D_DoDehPatch(&file, -1, reloadStrings);
 	}
 
 	// Check WAD files for lumps.
 	int lump = -1;
 	while ((lump = W_FindLump("DEHACKED", lump)) != -1)
 	{
-		D_DoDehPatch(NULL, lump);
-	}
-
-	if (::gamemode == retail_chex && !::multiplayer && !chexLoaded)
-	{
-		Printf(
-		    PRINT_WARNING,
-		    "Warning: chex.deh not loaded, experience may differ from the original!\n");
+		D_DoDehPatch(NULL, lump, reloadStrings);
 	}
 
 	// Re-apply spawninv settings with our new DEH settings.
@@ -594,6 +619,8 @@ static void LoadResolvedFiles(const OResFiles& newwadfiles,
 	// might change the strings
 	::GStrings.loadStrings(false);
 
+	P_InitMobjNameMap();
+
 	// Apply DEH patches.
 	D_LoadResolvedPatches();
 }
@@ -628,7 +655,7 @@ static bool CommercialIWADWarning(const OWantFile& wanted)
 		return false;
 	}
 
-	Printf("Odamex attempted to load\n> %s.\n\n", info->mIdName);
+	PrintFmt("Odamex attempted to load\n> {}.\n\n", info->mIdName);
 
 	// Try to find an IWAD file with a matching name in the user's directories.
 	OWantFile sameNameWant;
@@ -637,9 +664,9 @@ static bool CommercialIWADWarning(const OWantFile& wanted)
 	const bool resolved = M_ResolveWantedFile(sameNameRes, sameNameWant);
 	if (!resolved)
 	{
-		Printf(
+		PrintFmt(
 		    "Odamex could not find the data file for this game in any of the locations "
-		    "it searches for WAD files.  If you know you have %s on your hard drive, you "
+		    "it searches for WAD files.  If you know you have {} on your hard drive, you "
 		    "can add that path to the 'waddirs' cvar so Odamex can find it.\n\n",
 		    wanted.getBasename());
 	}
@@ -649,31 +676,31 @@ static bool CommercialIWADWarning(const OWantFile& wanted)
 		if (curInfo)
 		{
 			// Found a file, but it's the wrong version.
-			Printf("Odamex found a possible data file, but it's the wrong version.\n> "
-			       "%s\n> %s\n\n",
-			       curInfo->mIdName, sameNameRes.getFullpath());
+			PrintFmt("Odamex found a possible data file, but it's the wrong version.\n> "
+			         "{}\n> {}\n\n",
+			         curInfo->mIdName, sameNameRes.getFullpath());
 		}
 		else
 		{
 			// Found a file, but it's not recognized at all.
-			Printf("Odamex found a possible data file, but Odamex does not recognize "
-			       "it.\n> %s\n\n",
-			       sameNameRes.getFullpath());
+			PrintFmt("Odamex found a possible data file, but Odamex does not recognize "
+			         "it.\n> {}\n\n",
+			         sameNameRes.getFullpath());
 		}
 
 #ifdef _WIN32
-		Printf("You can use a tool such as Omniscient "
-		       "<https://drinkybird.net/doom/omniscient> to patch your way to the "
-		       "correct version of the data file.\n");
+		PrintFmt("You can use a tool such as Omniscient "
+		         "<https://drinkybird.net/doom/omniscient> to patch your way to the "
+		         "correct version of the data file.\n");
 #else
-		Printf("You can use a tool such as xdelta3 <http://xdelta.org/> paried with IWAD "
-		       "patches located on Github <https://github.com/Doom-Utils/iwad-patches> "
-		       "to patch your way to the correct version of the data file.\n");
+		PrintFmt("You can use a tool such as xdelta3 <http://xdelta.org/> paried with IWAD "
+		         "patches located on Github <https://github.com/Doom-Utils/iwad-patches> "
+		         "to patch your way to the correct version of the data file.\n");
 #endif
 	}
 
-	Printf("If you do not own this game, consider purchasing it on Steam, GOG, or other "
-	       "digital storefront.\n\n");
+	PrintFmt("If you do not own this game, consider purchasing it on Steam, GOG, or other "
+	         "digital storefront.\n\n");
 	return true;
 }
 
@@ -709,8 +736,8 @@ void D_LoadResourceFiles(const OWantFiles& newwadfiles, const OWantFiles& newpat
 			}
 
 			::missingfiles.push_back(wantfile);
-			Printf(PRINT_WARNING, "Could not resolve resource file \"%s\".",
-			       wantfile.getWantedPath());
+			PrintFmt(PRINT_WARNING, "Could not resolve resource file \"{}\".",
+			         wantfile.getWantedPath());
 			continue;
 		}
 		resolved_wads.push_back(file);
@@ -725,8 +752,8 @@ void D_LoadResourceFiles(const OWantFiles& newwadfiles, const OWantFiles& newpat
 		if (!M_ResolveWantedFile(file, wantfile))
 		{
 			::missingfiles.push_back(wantfile);
-			Printf(PRINT_WARNING, "Could not resolve patch file \"%s\".",
-			       wantfile.getWantedPath());
+			PrintFmt(PRINT_WARNING, "Could not resolve patch file \"{}\".",
+			         wantfile.getWantedPath());
 			continue;
 		}
 		resolved_patches.push_back(file);
@@ -866,7 +893,7 @@ bool D_DoomWadReboot(const OWantFiles& newwadfiles, const OWantFiles& newpatchfi
 	if (::lastWadRebootSuccess && CheckWantedMatchesLoaded(newwadfiles, newpatchfiles))
 	{
 		// fast track if files have not been changed
-		Printf("Currently loaded resources match server checksums.\n\n");
+		PrintFmt("Currently loaded resources match server checksums.\n\n");
 		return true;
 	}
 
@@ -898,10 +925,10 @@ bool D_DoomWadReboot(const OWantFiles& newwadfiles, const OWantFiles& newpatchfi
 	if (!failmsg.empty())
 	{
 		// Uh oh, loading the new resource set failed for some reason.
-		Printf(PRINT_WARNING,
-		       "Could not load new resource files.\n%s\nReloading previous resource "
-		       "set...\n",
-		       failmsg);
+		PrintFmt(PRINT_WARNING,
+		         "Could not load new resource files.\n{}\nReloading previous resource "
+		         "set...\n",
+		         failmsg);
 
 		D_Shutdown();
 
@@ -951,8 +978,8 @@ static void AddCommandLineOptionFiles(OWantFiles& out, const std::string& option
 	for (size_t i = 0; i < files.NumArgs(); i++)
 	{
 		OWantFile file;
-		OWantFile::make(file, files.GetArg(i), type);
-		out.push_back(file);
+		if (OWantFile::make(file, files.GetArg(i), type))
+			out.push_back(file);
 	}
 
 	files.FlushArgs();
@@ -1183,4 +1210,4 @@ void D_RunTics(void (*sim_func)(), void(*display_func)())
 	}
 }
 
-VERSION_CONTROL (d_main_cpp, "$Id: fb83213af98759f1abbadfce6c5e463589319c82 $")
+VERSION_CONTROL (d_main_cpp, "$Id: 0d574cf265da5d6d076163d6c6d45c3d738027bd $")
