@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 4a144180172bbc515d20bf385a4f2c685247e488 $
+// $Id: cca2e3eccb2be985ebd5238e3c280abd8433132a $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -30,7 +30,7 @@
 class player_s;
 typedef player_s player_t;
 
-static constexpr short CENTERVIEW = -32768;
+inline constexpr short CENTERVIEW = -32768;
 //
 // NetCommand
 //
