@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 6971f4f0928bac185dccdd83686c6f73af180090 $
+// $Id: dbda6c58cb740dd2666d5dacf36032835152c703 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -28,6 +28,7 @@
 #include "m_alloc.h"		// Ideally, DObjects can be used independant of Doom.
 #include "d_player.h"		// See p_user.cpp to find out why this doesn't work.
 #include "z_zone.h"
+#include "m_stacktrace.h"
 
 ClassInit::ClassInit (TypeInfo *type)
 {
@@ -63,38 +64,20 @@ const TypeInfo *TypeInfo::FindType (const char *name)
 
 TypeInfo DObject::_StaticType("DObject", NULL, sizeof(DObject));
 
-TArray<DObject *> DObject::Objects;
-TArray<size_t> DObject::FreeIndices;
-TArray<DObject *> DObject::ToDestroy;
-bool DObject::Inactive;
-
-DObject::DObject ()
-{
-	ObjectFlags = 0;
-	if (FreeIndices.Pop (Index))
-		Objects[Index] = this;
-	else
-		Index = Objects.Push (this);
-}
-
 DObject::~DObject ()
 {
 	if (!Inactive)
 	{
-		if (!(ObjectFlags & OF_MassDestruction))
-		{
-			RemoveFromArray ();
-		}
-		else if (!(ObjectFlags & OF_Cleanup))
+		if (!(ObjectFlags & OF_Cleanup) && (ObjectFlags & OF_Destroyed))
 		{
 			// object is queued for deletion, but is not being deleted
 			// by the destruction process, so remove it from the
 			// ToDestroy array and do other necessary stuff.
-			for (size_t i = ToDestroy.Size() - 1; i >= 0; i--)
+			for (auto& obj : OUtil::reverse(ToDestroy))
 			{
-				if (ToDestroy[i] == this)
+				if (obj == this)
 				{
-					ToDestroy[i] = NULL;
+					obj = nullptr;
 					break;
 				}
 			}
@@ -106,11 +89,10 @@ void DObject::Destroy ()
 {
 	if (!Inactive)
 	{
-		if (!(ObjectFlags & OF_MassDestruction))
+		if (!(ObjectFlags & OF_Destroyed))
 		{
-			RemoveFromArray ();
-			ObjectFlags |= OF_MassDestruction;
-			ToDestroy.Push (this);
+			ObjectFlags |= OF_Destroyed;
+			ToDestroy.push_back(this);
 		}
 	}
 	else
@@ -123,40 +105,15 @@ void DObject::BeginFrame ()
 
 void DObject::EndFrame ()
 {
-	DObject *obj;
-
-	if (ToDestroy.Size ())
+	for (DObject* obj : ToDestroy)
 	{
-		//Printf (PRINT_HIGH, "Destroyed %d objects\n", ToDestroy.Size());
-
-		while (ToDestroy.Pop (obj))
+		if (obj)
 		{
-			if (obj)
-			{
-				obj->ObjectFlags |= OF_Cleanup;
-				delete obj;
-			}
+			obj->ObjectFlags |= OF_Cleanup;
+			delete obj;
 		}
 	}
-}
-
-void DObject::RemoveFromArray ()
-{
-	// denis - our array is static, so are some of the objects (eg DArgs)
-	// so there's really no telling which is destroyed first, better to bail
-	if(Inactive)
-		return;
-
-	if (Objects.Size () == Index + 1)
-	{
-		DObject *dummy;
-		Objects.Pop (dummy);
-	}
-	else if (Objects.Size() > Index + 1)
-	{
-		Objects[Index] = NULL;
-		FreeIndices.Push (Index);
-	}
+	ToDestroy.clear();
 }
 
 void STACK_ARGS DObject::StaticShutdown ()
@@ -167,5 +124,5 @@ void STACK_ARGS DObject::StaticShutdown ()
 	DThinker::DestroyAllThinkers();
 }
 
-VERSION_CONTROL (dobject_cpp, "$Id: 6971f4f0928bac185dccdd83686c6f73af180090 $")
+VERSION_CONTROL (dobject_cpp, "$Id: dbda6c58cb740dd2666d5dacf36032835152c703 $")
 
