@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b5b9f53b09ead5131755411d1029db9a7819b64e $
+// $Id: 8386cbda93732b62385ed76761be029c3dc4b39a $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -24,7 +24,6 @@
 #pragma once
 
 #include <stdlib.h>
-#include "tarray.h"
 
 class FArchive;
 
@@ -159,8 +158,8 @@ public: \
 
 enum EObjectFlags
 {
-	OF_MassDestruction	= 0x00000001,	// Object is queued for deletion
-	OF_Cleanup			= 0x00000002	// Object is being deconstructed as a result of a queued deletion
+	OF_Destroyed = 0x00000001, // Object has been destroyed but not yet deleted
+	OF_Cleanup   = 0x00000002  // Object is being deconstructed as a result of a queued deletion
 };
 
 class DObject
@@ -172,8 +171,8 @@ private: \
 	typedef DObject ThisClass;
 
 public:
-	DObject ();
-	virtual ~DObject ();
+	DObject () {};
+	virtual ~DObject () = 0;
 
 	[[nodiscard]] inline bool IsKindOf (const TypeInfo *base) const
 	{
@@ -191,19 +190,14 @@ public:
 	static void BeginFrame ();
 	static void EndFrame ();
 
-	DWORD ObjectFlags;
+	DWORD ObjectFlags = 0;
 
 	static void STACK_ARGS StaticShutdown ();
 
 private:
-	static TArray<DObject *> Objects;
-	static TArray<size_t> FreeIndices;
-	static TArray<DObject *> ToDestroy;
+	static inline std::vector<DObject *> ToDestroy{};
 
-	void RemoveFromArray ();
-
-	static bool Inactive;
-	size_t Index;
+	static inline bool Inactive;
 };
 
 #include "farchive.h"
