@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 9115b2343c0e3b7ea91fde6e954f63a3f969df57 $
+// $Id: 7661cfcc63545139e933684a3793e715e4374305 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -48,10 +48,10 @@ CVAR_FUNC_IMPL (language)
 	::GStrings.loadStrings(false);
 
 	// Reapply DeHackEd patches on top of these strings.
-	D_LoadResolvedPatches();
+	D_LoadResolvedPatches(true);
 }
 
 // Set if homebrew PWAD stuff has been added.
 bool			modifiedgame;
 
-VERSION_CONTROL (doomstat_cpp, "$Id: 9115b2343c0e3b7ea91fde6e954f63a3f969df57 $")
+VERSION_CONTROL (doomstat_cpp, "$Id: 7661cfcc63545139e933684a3793e715e4374305 $")
