@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 16636ffa74ebf821133142a10d4358f200cf0201 $
+// $Id: 67f47066b1dcf7498a2198ac4914dd614927d641 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -41,10 +41,6 @@
 // For __BIG_ENDIAN__ macro, requires forceinline
 #include "m_swap.h"
 
-#ifdef GEKKO
-	#include <gctypes.h>
-#endif
-
 typedef unsigned char byte;
 typedef unsigned int uint;
 
@@ -57,7 +53,7 @@ using OByteSpan = nonstd::span<byte>;
 #endif
 
 // Predefined with some OS.
-#if !defined(UNIX) && !defined(_WIN32) && !defined(GEKKO)
+#if !defined(UNIX) && !defined(_WIN32)
 	#include <limits.h>
 	#include <float.h>
 #endif
@@ -70,7 +66,7 @@ using OByteSpan = nonstd::span<byte>;
 	#define __int64 long
 #endif
 
-#if (defined _XBOX || defined _MSC_VER)
+#if defined _MSC_VER
 	#define DBL_EPSILON 2.2204460492503131e-016
 	#define FLT_EPSILON 1.192092896e-07F
 #else
@@ -82,50 +78,27 @@ using OByteSpan = nonstd::span<byte>;
 	#define strnicmp strncasecmp
 #endif
 
-#ifndef MAXCHAR
-	#define MAXCHAR 		((char)0x7f)
-#endif
-#ifndef MAXSHORT
-	#define MAXSHORT		((short)0x7fff)
-#endif
+namespace limits
+{
+	inline constexpr char         MAXCHAR  = std::numeric_limits<char>::max();
+	inline constexpr short        MAXSHORT = std::numeric_limits<short>::max();
+	inline constexpr int          MAXINT   = std::numeric_limits<int>::max();
+	inline constexpr unsigned int MAXUINT  = std::numeric_limits<unsigned int>::max();
+	// todo: do we even want to be using long here instead of int32_t/int64_t
+	// this feels like a remnant from before 64 bit
+	inline constexpr long         MAXLONG  = std::numeric_limits<long>::max();
 
-// Max pos 32-bit int.
-#ifndef MAXINT
-	#define MAXINT			(0x7fffffff)
-#endif
-#ifndef MAXUINT
-	#define MAXUINT			(0xffffffff)
-#endif
+	inline constexpr char         MINCHAR  = std::numeric_limits<char>::min();
+	inline constexpr short        MINSHORT = std::numeric_limits<short>::min();
+	inline constexpr int          MININT   = std::numeric_limits<int>::min();
+	inline constexpr unsigned int MINUINT  = std::numeric_limits<unsigned int>::min();
+	inline constexpr long         MINLONG  = std::numeric_limits<long>::min();
 
-#ifndef MAXLONG
-	#ifndef ALPHA
-		#define MAXLONG 		((long)0x7fffffff)
-	#else
-		#define MAXLONG			((long)0x7fffffffffffffff)
-	#endif
-#endif
-
-#ifndef MINCHAR
-	#define MINCHAR 		((char)0x80)
-#endif
-#ifndef MINSHORT
-	#define MINSHORT		((short)0x8000)
-#endif
-
-// Max negative 32-bit integer.
-#ifndef MININT
-	#define MININT			((int)0x80000000)
-#endif
-#ifndef MINLONG
-	#ifndef ALPHA
-		#define MINLONG 		((long)0x80000000)
-	#else
-		#define MINLONG			((long)0x8000000000000000)
-	#endif
-#endif
-
-#define MINFIXED		(signed)(0x80000000)
-#define MAXFIXED		(signed)(0x7fffffff)
+	inline constexpr int32_t      MAXFIXED = std::numeric_limits<int32_t>::max();
+	inline constexpr int32_t      MINFIXED = std::numeric_limits<int32_t>::min();
+	inline constexpr int64_t      MAXFIXED64 = std::numeric_limits<int64_t>::max();
+	inline constexpr int64_t      MINFIXED64 = std::numeric_limits<int64_t>::min();
+}
 
 typedef unsigned char		BYTE;
 typedef signed char			SBYTE;
@@ -193,6 +166,7 @@ typedef enum {
 	PRINT_NORCON,		// Do NOT send the message to any rcon client.
 
 	PRINT_FILTERCHAT,	// Filter the message to not be displayed ingame, but only in the console (ugly hack)
+	PRINT_FILTERHIGH,	// Filter the message to not be displayed ingame, but only in the console (ugly hack)
 
 	PRINT_MAXPRINT
 } printlevel_t;
@@ -311,7 +285,7 @@ public:
 	{	a_num = _a; r_num = _r; g_num = _g; b_num = _b;	}
 
 private:
-	static uint8_t a_num, r_num, g_num, b_num;
+	static inline uint8_t a_num, r_num, g_num, b_num;
 
 	union
 	{
@@ -434,7 +408,6 @@ class translationref_t
 
 public:
 	translationref_t();
-	translationref_t(const translationref_t &other);
 	translationref_t(const palindex_t *table);
 	translationref_t(const palindex_t *table, const int player_id);
 
@@ -494,7 +467,6 @@ public:
 
 public:
 	shaderef_t();
-	shaderef_t(const shaderef_t &other);
 	shaderef_t(const shademap_t * const colors, const int mapnum);
 
 	// Determines if m_colors is NULL
