@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: eaa6a07ea08f009ea137c6b03537056378f1ce9d $
+// $Id: 57a34139a0c1d5cfb89b5aea8fe6444189fdf691 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -45,13 +45,13 @@ struct GametypeParam
  */
 template <size_t SIZE> static void GametypeHelp(const GametypeParam (&params)[SIZE])
 {
-	Printf("Flags:\n");
-	Printf("  default\n");
-	Printf("    Use default settings.\n");
+	PrintFmt("Flags:\n");
+	PrintFmt("  default\n");
+	PrintFmt("    Use default settings.\n");
 	for (size_t i = 0; i < SIZE; i++)
 	{
-		Printf("  %s <%s>\n", params[i].flag, params[i].flagparam);
-		Printf("    %s\n", params[i].help);
+		PrintFmt("  {} <{}>\n", params[i].flag, params[i].flagparam);
+		PrintFmt("    {}\n", params[i].help);
 	}
 }
 
@@ -90,7 +90,7 @@ static StringList GametypeArgs(const GametypeParam (&params)[SIZE], size_t argc,
 			else if (args.size() == 1)
 			{
 				// All params take a second one.
-				Printf(PRINT_HIGH, "Missing argument for \"%s\"\n", args.front());
+				PrintFmt(PRINT_HIGH, "Missing argument for \"{}\"\n", args.front());
 				return ret;
 			}
 
@@ -121,7 +121,7 @@ static StringList GametypeArgs(const GametypeParam (&params)[SIZE], size_t argc,
 			}
 
 			// Unknown flag.
-			Printf(PRINT_HIGH, "Unknown flag \"%s\"\n", cmd);
+			PrintFmt(PRINT_HIGH, "Unknown flag \"{}\"\n", cmd);
 			return ret;
 		}
 	}
@@ -146,7 +146,7 @@ static GametypeParam coopParams[] = {
 
 static void CoopHelp()
 {
-	Printf("game_coop - Configures some settings for a basic Cooperative game\n");
+	PrintFmt("game_coop - Configures some settings for a basic Cooperative game\n");
 	GametypeHelp(::coopParams);
 }
 
@@ -174,7 +174,7 @@ BEGIN_COMMAND(game_coop)
 	params.push_back("sv_nomonsters 0");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Cooperative...\n%s\n", config);
+	PrintFmt("Configuring Cooperative...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_coop)
@@ -187,7 +187,7 @@ static GametypeParam survivalParams[] = {
 
 static void SurvivalHelp()
 {
-	Printf("game_survival - Configures some settings for a basic game of Survival\n");
+	PrintFmt("game_survival - Configures some settings for a basic game of Survival\n");
 	GametypeHelp(::survivalParams);
 }
 
@@ -214,7 +214,7 @@ BEGIN_COMMAND(game_survival)
 	params.push_back("sv_nomonsters 0");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Survival...\n%s\n", config);
+	PrintFmt("Configuring Survival...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_survival)
@@ -227,7 +227,7 @@ static GametypeParam dmParams[] = {
 
 static void DMHelp()
 {
-	Printf("game_dm - Configures some settings for a basic game of Deathmatch\n");
+	PrintFmt("game_dm - Configures some settings for a basic game of Deathmatch\n");
 	GametypeHelp(::dmParams);
 }
 
@@ -255,7 +255,7 @@ BEGIN_COMMAND(game_dm)
 	params.push_back("sv_skill 5");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Deathmatch...\n%s\n", config);
+	PrintFmt("Configuring Deathmatch...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_dm)
@@ -266,7 +266,7 @@ static GametypeParam duelParams[] = {
 
 static void DuelHelp()
 {
-	Printf("game_duel - Configures some settings for a basic Duel\n");
+	PrintFmt("game_duel - Configures some settings for a basic Duel\n");
 	GametypeHelp(::duelParams);
 }
 
@@ -299,7 +299,7 @@ BEGIN_COMMAND(game_duel)
 	params.push_back("sv_warmup_autostart 1.0");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Duel...\n%s\n", config);
+	PrintFmt("Configuring Duel...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_duel)
@@ -312,7 +312,7 @@ static GametypeParam lmsParams[] = {
 
 static void LMSHelp()
 {
-	Printf(
+	PrintFmt(
 	    "game_lms - Configures some settings for a basic game of Last Marine Standing\n");
 	GametypeHelp(::lmsParams);
 }
@@ -341,7 +341,7 @@ BEGIN_COMMAND(game_lms)
 	params.push_back("sv_skill 5");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Last Marine Standing...\n%s\n", config);
+	PrintFmt("Configuring Last Marine Standing...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_lms)
@@ -354,7 +354,7 @@ static GametypeParam tdmParams[] = {
 
 static void TDMHelp()
 {
-	Printf("game_tdm - Configures some settings for a basic game of Team Deathmatch\n");
+	PrintFmt("game_tdm - Configures some settings for a basic game of Team Deathmatch\n");
 	GametypeHelp(::tdmParams);
 }
 
@@ -383,7 +383,7 @@ BEGIN_COMMAND(game_tdm)
 	params.push_back("sv_skill 5");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Team Deathmatch...\n%s\n", config);
+	PrintFmt("Configuring Team Deathmatch...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_tdm)
@@ -398,8 +398,8 @@ static GametypeParam tlmsParams[] = {
 
 static void TLMSHelp()
 {
-	Printf("game_tlms - Configures some settings for a basic game of Team Last Marine "
-	       "Standing\n");
+	PrintFmt("game_tlms - Configures some settings for a basic game of Team Last Marine "
+	         "Standing\n");
 	GametypeHelp(::tlmsParams);
 }
 
@@ -428,7 +428,7 @@ BEGIN_COMMAND(game_tlms)
 	params.push_back("sv_skill 5");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Team Last Marine Standing...\n%s\n", config);
+	PrintFmt("Configuring Team Last Marine Standing...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_tlms)
@@ -443,7 +443,7 @@ static GametypeParam ctfParams[] = {
 
 static void CTFHelp()
 {
-	Printf("game_ctf - Configures some settings for a basic game of Capture the Flag\n");
+	PrintFmt("game_ctf - Configures some settings for a basic game of Capture the Flag\n");
 	GametypeHelp(::ctfParams);
 }
 
@@ -472,7 +472,7 @@ BEGIN_COMMAND(game_ctf)
 	params.push_back("sv_skill 5");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Capture the Flag...\n%s\n", config);
+	PrintFmt("Configuring Capture the Flag...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_ctf)
@@ -487,7 +487,7 @@ static GametypeParam hordeParams[] = {
 
 static void HordeHelp()
 {
-	Printf("game_horde - Configures some settings for a basic game of Horde\n");
+	PrintFmt("game_horde - Configures some settings for a basic game of Horde\n");
 	GametypeHelp(::hordeParams);
 }
 
@@ -522,7 +522,7 @@ BEGIN_COMMAND(game_horde)
 	params.push_back("sv_nomonsters 0");
 
 	std::string config = JoinStrings(params, "; ");
-	Printf("Configuring Horde...\n%s\n", config);
+	PrintFmt("Configuring Horde...\n{}\n", config);
 	AddCommandString(config);
 }
 END_COMMAND(game_horde)
