@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 906157b2789fc394f6b9c5f1c7737416b4ab90fe $
+// $Id: abfc9dfb6c13794c0aa0506bbcd1f9be8325669a $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -679,14 +679,14 @@ static const char* WinTypeToString(WinInfo::WinType type)
 BEGIN_COMMAND(levelstateinfo)
 {
 	SerializedLevelState sls = ::levelstate.serialize();
-	Printf("Current level time: %d\n", ::level.time);
-	Printf("State: %s\n", StateToString(sls.state));
-	Printf("Countdown done time: %d\n", sls.countdown_done_time);
-	Printf("Ingame start time: %d\n", sls.ingame_start_time);
-	Printf("Round number: %d\n", sls.round_number);
-	Printf("Last WinInfo type: %s\n", WinTypeToString(sls.last_wininfo_type));
-	Printf("Last WinInfo ID: %d\n", sls.last_wininfo_id);
+	PrintFmt("Current level time: {}\n", ::level.time);
+	PrintFmt("State: {}\n", StateToString(sls.state));
+	PrintFmt("Countdown done time: {}\n", sls.countdown_done_time);
+	PrintFmt("Ingame start time: {}\n", sls.ingame_start_time);
+	PrintFmt("Round number: {}\n", sls.round_number);
+	PrintFmt("Last WinInfo type: {}\n", WinTypeToString(sls.last_wininfo_type));
+	PrintFmt("Last WinInfo ID: {}\n", sls.last_wininfo_id);
 }
 END_COMMAND(levelstateinfo)
 
-VERSION_CONTROL(g_levelstate, "$Id: 906157b2789fc394f6b9c5f1c7737416b4ab90fe $")
+VERSION_CONTROL(g_levelstate, "$Id: abfc9dfb6c13794c0aa0506bbcd1f9be8325669a $")
