@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 61c86a3db11ea825267422afb9ac721230135c2e $
+// $Id: 2692f43767c691ef3e70432bb729b55fadc1df58 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -330,10 +330,20 @@ public:
 		copyFromOther(other);
 	}
 
+	OHashTable(std::initializer_list<HashPairType> list)
+	{
+		resize(list.size());
+		for (const HashPairType& pair : list)
+			insert(pair);
+	}
+
 	~OHashTable() = default;
 
 	OHashTable& operator= (const HashTableType& other)
 	{
+		if (this == &other)
+			return *this;
+
 		copyFromOther(other);
 		return *this;
 	}
@@ -527,6 +537,7 @@ private:
 	void copyFromOther(const HashTableType& other)
 	{
 		clear();
+		// FIXME: this fails if other.mSize <= mSize
 		resize(other.mSize);
 		for (size_t i = 0; i < mSize; i++)
 		{
