@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 92e6ab286b9927a3e19f0ca599f552af046fb368 $
+// $Id: f962e496af1a951a6013281949e08603082327fc $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -22,8 +22,8 @@
 //-----------------------------------------------------------------------------
 
 
-#if defined _WIN32 && !defined _XBOX && defined _MSC_VER && !defined _DEBUG
-#elif defined UNIX && defined HAVE_BACKTRACE && !defined GEKKO
+#if defined _WIN32 && defined _MSC_VER && !defined _DEBUG
+#elif defined UNIX && defined HAVE_BACKTRACE
 #else
 
 #include "odamex.h"
