@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 44b77b9a07e05d438682c08998e77ca6f8945da2 $
+// $Id: 3af70dbd24aab44f0cf8d8111ff0dc6c6bc944b6 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -28,7 +28,7 @@
 //-----------------------------------------------------------------------------
 
 
-#if defined _WIN32 && !defined _XBOX && defined _MSC_VER && !defined _DEBUG
+#if defined _WIN32 && defined _MSC_VER && !defined _DEBUG
 
 #include "odamex.h"
 
