@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 3ebaf4bf997b16c153c2b08e46c421a7f4b5ef46 $
+// $Id: a6f54aaecdc955596c19fa1494712bbe7a5c4d3e $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -37,32 +37,24 @@
 /* [Petteri] Use Winsock for Win32: */
 #include "win32inc.h"
 #ifdef _WIN32
-    #ifndef _XBOX
-    	#include <winsock2.h>
-        #include <ws2tcpip.h>
-    #endif // !_XBOX
+    #include <winsock2.h>
+    #include <ws2tcpip.h>
 #else
-#ifdef GEKKO // Wii/GC
-#	include <network.h>
-#else
-#	include <sys/socket.h>
-#	include <netinet/in.h>
-#	include <arpa/inet.h>
-#	include <netdb.h>
-#	include <sys/ioctl.h>
-#endif // GEKKO
-#	include <sys/types.h>
-#	include <errno.h>
-#	include <unistd.h>
-#	include <sys/time.h>
+	#include <sys/socket.h>
+	#include <netinet/in.h>
+	#include <arpa/inet.h>
+	#include <netdb.h>
+	#include <sys/ioctl.h>
+	#include <sys/types.h>
+	#include <errno.h>
+	#include <unistd.h>
+	#include <sys/time.h>
 #endif // WIN32
 
 #ifndef _WIN32
 typedef int SOCKET;
-#ifndef GEKKO
 #define SOCKET_ERROR -1
 #define INVALID_SOCKET -1
-#endif
 #define closesocket close
 #define ioctlsocket ioctl
 #define Sleep(x)	usleep (x * 1000)
@@ -81,14 +73,7 @@ typedef int SOCKET;
 #include "i_net.h"
 #include "svc_map.h"
 #include "d_player.h"
-
-#ifdef _XBOX
-#include "i_xbox.h"
-#endif
-
-#ifdef GEKKO
-#include "i_wii.h"
-#endif
+#include "m_alloc.h"
 
 #include "minilzo.h"
 
@@ -145,7 +130,7 @@ void init_upnp (void)
 	memset(&urls, 0, sizeof(struct UPNPUrls));
 	memset(&data, 0, sizeof(struct IGDdatas));
 
-	Printf(PRINT_HIGH, "UPnP: Discovering router (max 1 unit supported)\n");
+	PrintFmt(PRINT_HIGH, "UPnP: Discovering router (max 1 unit supported)\n");
 
 #if MINIUPNPC_API_VERSION < 14
 	devlist = upnpDiscover(sv_upnp_discovertimeout.asInt(), NULL, NULL, 0, 0, &res);
@@ -156,7 +141,7 @@ void init_upnp (void)
 
 	if (!devlist || res != UPNPDISCOVER_SUCCESS)
     {
-		Printf(PRINT_WARNING, "UPnP: Router not found or timed out, error %d\n",
+		PrintFmt(PRINT_WARNING, "UPnP: Router not found or timed out, error {}\n",
             res);
 
 		is_upnp_ok = false;
@@ -200,14 +185,14 @@ void init_upnp (void)
 
 	if (r != 0)
 	{
-		Printf(PRINT_HIGH,
+		PrintFmt(PRINT_HIGH,
 			"UPnP: Router found but unable to get external IP address\n");
 
 		is_upnp_ok = false;
 	}
 	else
 	{
-		Printf(PRINT_HIGH, "UPnP: Router found, external IP address is: %s\n",
+		PrintFmt(PRINT_HIGH, "UPnP: Router found, external IP address is: {}\n",
 			IPAddress);
 
 		// Store ip address just in case admin wants it
@@ -330,20 +315,20 @@ void BindToLocalPort (SOCKET s, u_short wanted)
     {
         sv_upnp_internalip.Set(ip.c_str());
 
-        Printf(PRINT_HIGH, "UPnP: Internal IP address is: %s\n", ip);
+        PrintFmt(PRINT_HIGH, "UPnP: Internal IP address is: {}\n", ip);
 
         upnp_add_redir(ip.c_str(), next - 1);
     }
     else
     {
-        Printf(PRINT_HIGH, "UPnP: Could not get first internal IP address, "
+        PrintFmt(PRINT_HIGH, "UPnP: Could not get first internal IP address, "
             "UPnP will not function\n");
 
         is_upnp_ok = false;
     }
 #endif
 
-	Printf(PRINT_HIGH, "Bound to local port %d\n", next - 1);
+	PrintFmt(PRINT_HIGH, "Bound to local port {}\n", next - 1);
 }
 
 
@@ -455,12 +440,12 @@ int NET_GetPacket (void)
 
 		if (errno == WSAEMSGSIZE)
 		{
-			 Printf (PRINT_HIGH, "Warning:  Oversize packet from %s\n",
+			 PrintFmt(PRINT_HIGH, "Warning:  Oversize packet from {}\n",
 							 NET_AdrToString (net_from));
 			 return false;
 		}
 
-		Printf (PRINT_HIGH, "NET_GetPacket: %s\n", strerror(errno));
+		PrintFmt(PRINT_HIGH, "NET_GetPacket: {}\n", strerror(errno));
 		return false;
 #else
 		if (errno == EWOULDBLOCK)
@@ -468,7 +453,7 @@ int NET_GetPacket (void)
 		if (errno == ECONNREFUSED)
 			return false;
 
-		Printf (PRINT_HIGH, "NET_GetPacket: %s\n", strerror(errno));
+		PrintFmt(PRINT_HIGH, "NET_GetPacket: {}\n", strerror(errno));
 		return false;
 #endif
 	}
@@ -493,11 +478,7 @@ int NET_SendPacket (buf_t &buf, netadr_t &to)
 
 	NetadrToSockadr (&to, &addr);
 
-#ifdef GEKKO
-	ret = sendto(inet_socket, (const char *)buf.ptr(), buf.size(), 0, (struct sockaddr *)&addr, 8);	// 8 is important for online
-#else
 	ret = sendto(inet_socket, (const char *)buf.ptr(), buf.size(), 0, (struct sockaddr *)&addr, sizeof(addr));
-#endif
 
 	buf.clear();
 
@@ -514,7 +495,7 @@ int NET_SendPacket (buf_t &buf, netadr_t &to)
 			  return 0;
 		  if (errno == ECONNREFUSED)
 			  return 0;
-		  Printf (PRINT_HIGH, "NET_SendPacket: %s\n", strerror(errno));
+		  PrintFmt(PRINT_HIGH, "NET_SendPacket: {}\n", strerror(errno));
 #endif
 	}
 
@@ -543,12 +524,12 @@ std::string NET_GetLocalAddress (void)
         addr.s_addr = *(u_long *)ent->h_addr_list[0];
 
 		std::string ipstr = inet_ntoa(addr);
-		Printf(PRINT_HIGH, "Bound to IP: %s\n", ipstr);
+		PrintFmt(PRINT_HIGH, "Bound to IP: {}\n", ipstr);
 		return ipstr;
     }
 	else
 	{
-		Printf(PRINT_HIGH, "Could not look up host IP address from hostname\n");
+		PrintFmt(PRINT_HIGH, "Could not look up host IP address from hostname\n");
 		return "";
 	}
 }
@@ -620,30 +601,30 @@ void MSG_WriteSVC(buf_t* b, const google::protobuf::Message& msg)
 	static std::string buffer;
 	if (!msg.SerializeToString(&buffer))
 	{
-		Printf(
+		PrintFmt(
 		    PRINT_WARNING,
-		    "WARNING: Could not serialize message \"%s\".  This is most likely a bug.\n",
+		    "WARNING: Could not serialize message \"{}\".  This is most likely a bug.\n",
 		    msg.GetDescriptor()->full_name());
 		return;
 	}
 
 	// Do we actaully have room for this upcoming message?
-	const size_t MAX_HEADER_SIZE = 4; // header + 3 bytes for varint size.
-	if (b->cursize + MAX_HEADER_SIZE + msg.ByteSize() >= MAX_UDP_SIZE)
+	static constexpr size_t MAX_HEADER_SIZE = 4; // header + 3 bytes for varint size.
+	if (b->cursize + MAX_HEADER_SIZE + msg.ByteSizeLong() >= MAX_UDP_SIZE)
 		SV_SendPackets();
 
 	svc_t header = SVC_ResolveDescriptor(msg.GetDescriptor());
 	if (header == svc_noop)
 	{
-		Printf(PRINT_WARNING,
-		       "WARNING: Could not find svc header for message \"%s\".  This is most "
-		       "likely a bug.\n",
-		       msg.GetDescriptor()->full_name());
+		PrintFmt(PRINT_WARNING,
+		         "WARNING: Could not find svc header for message \"{}\".  This is most "
+		         "likely a bug.\n",
+		         msg.GetDescriptor()->full_name());
 		return;
 	}
 
 #if 0
-	Printf("%s (%d)\n, %s\n",
+	PrintFmt("{} ({})\n, {}\n",
 		::svc_info[header].getName(), msg.ByteSize(),
 		msg.ShortDebugString());
 #endif
@@ -669,9 +650,9 @@ void MSG_BroadcastSVC(const clientBuf_e buf, const google::protobuf::Message& ms
 	static std::string buffer;
 	if (!msg.SerializeToString(&buffer))
 	{
-		Printf(
+		PrintFmt(
 		    PRINT_WARNING,
-		    "WARNING: Could not serialize message \"%s\".  This is most likely a bug.\n",
+		    "WARNING: Could not serialize message \"{}\".  This is most likely a bug.\n",
 		    msg.GetDescriptor()->full_name());
 		return;
 	}
@@ -679,10 +660,10 @@ void MSG_BroadcastSVC(const clientBuf_e buf, const google::protobuf::Message& ms
 	svc_t header = SVC_ResolveDescriptor(msg.GetDescriptor());
 	if (header == svc_noop)
 	{
-		Printf(PRINT_WARNING,
-		       "WARNING: Could not find svc header for message \"%s\".  This is most "
-		       "likely a bug.\n",
-		       msg.GetDescriptor()->full_name());
+		PrintFmt(PRINT_WARNING,
+		         "WARNING: Could not find svc header for message \"{}\".  This is most "
+		         "likely a bug.\n",
+		         msg.GetDescriptor()->full_name());
 		return;
 	}
 
@@ -698,8 +679,8 @@ void MSG_BroadcastSVC(const clientBuf_e buf, const google::protobuf::Message& ms
 		buf_t* b = buf == CLBUF_RELIABLE ? &player.client.reliablebuf : &player.client.netbuf;
 
 		// Do we actaully have room for this upcoming message?
-		const size_t MAX_HEADER_SIZE = 4; // header + 3 bytes for varint size.
-		if (b->cursize + MAX_HEADER_SIZE + msg.ByteSize() >= MAX_UDP_SIZE)
+		static constexpr size_t MAX_HEADER_SIZE = 4; // header + 3 bytes for varint size.
+		if (b->cursize + MAX_HEADER_SIZE + msg.ByteSizeLong() >= MAX_UDP_SIZE)
 			SV_SendPackets();
 
 		b->WriteByte(header);
@@ -802,7 +783,7 @@ void MSG_WriteHexString(buf_t *b, const char *s)
 
     if (numdigits > ARRAY_LENGTH(output))
     {
-        Printf (PRINT_HIGH, "MSG_WriteHexString: too many digits\n");
+        PrintFmt(PRINT_HIGH, "MSG_WriteHexString: too many digits\n");
         return;
     }
 
@@ -864,7 +845,7 @@ bool MSG_DecompressMinilzo ()
 
 	if(r != LZO_E_OK)
 	{
-		Printf(PRINT_HIGH, "Error: minilzo packet decompression failed with error %X\n", r);
+		PrintFmt(PRINT_HIGH, "Error: minilzo packet decompression failed with error {:X}\n", r);
 		return false;
 	}
 
@@ -908,60 +889,6 @@ bool MSG_CompressMinilzo (buf_t &buf, size_t start_offset, size_t write_gap)
 	return true;
 }
 
-//
-// MSG_DecompressAdaptive
-//
-bool MSG_DecompressAdaptive (huffman &huff)
-{
-	// decompress back onto the receive buffer
-	size_t left = MSG_BytesLeft();
-
-	if(decompressed.maxsize() < net_message.maxsize())
-		decompressed.resize(net_message.maxsize());
-
-	size_t newlen = net_message.maxsize();
-
-	bool r = huff.decompress (net_message.ptr() + net_message.BytesRead(), left, decompressed.ptr(), newlen);
-
-	if(!r)
-		return false;
-
-	net_message.clear();
-	memcpy(net_message.ptr(), decompressed.ptr(), newlen);
-
-	net_message.cursize = newlen;
-
-	return true;
-}
-
-//
-// MSG_CompressAdaptive
-//
-bool MSG_CompressAdaptive (huffman &huff, buf_t &buf, size_t start_offset, size_t write_gap)
-{
-	size_t outlen = OUT_LEN(buf.maxsize() - start_offset - write_gap);
-	size_t total_len = outlen + start_offset + write_gap;
-
-	if(compressed.maxsize() < total_len)
-		compressed.resize(total_len);
-
-	bool r = huff.compress (buf.ptr() + start_offset,
-							  buf.size() - start_offset,
-							  compressed.ptr() + start_offset + write_gap,
-							  outlen);
-
-	// worth the effort?
-	if(!r || outlen >= (buf.size() - start_offset - write_gap))
-		return false;
-
-	memcpy(compressed.ptr(), buf.ptr(), start_offset);
-
-	SZ_Clear(&buf);
-	MSG_WriteChunk(&buf, compressed.ptr(), outlen + start_offset + write_gap);
-
-	return true;
-}
-
 int MSG_ReadShort (void)
 {
     return net_message.ReadShort();
@@ -1076,6 +1003,7 @@ static void InitNetMessageFormats()
 	SVC_INFO(svc_spawnplayer);
 	SVC_INFO(svc_damageplayer);
 	SVC_INFO(svc_killmobj);
+	SVC_INFO(svc_raisemobj);
 	SVC_INFO(svc_fireweapon);
 	SVC_INFO(svc_updatesector);
 	SVC_INFO(svc_print);
@@ -1160,9 +1088,9 @@ CVAR_FUNC_IMPL(net_rcvbuf)
 {
 	int n = var.asInt();
 	if (setsockopt(inet_socket, SOL_SOCKET, SO_RCVBUF, SETSOCKOPTCAST(&n), (int) sizeof(n)) == -1) {
-		Printf(PRINT_HIGH, "setsockopt SO_RCVBUF: %s", strerror(errno));
+		PrintFmt(PRINT_HIGH, "setsockopt SO_RCVBUF: {}", strerror(errno));
 	} else {
-		Printf(PRINT_HIGH, "net_rcvbuf set to %d\n", n);
+		PrintFmt(PRINT_HIGH, "net_rcvbuf set to {}\n", n);
 	}
 }
 
@@ -1170,9 +1098,9 @@ CVAR_FUNC_IMPL(net_sndbuf)
 {
 	int n = var.asInt();
 	if (setsockopt(inet_socket, SOL_SOCKET, SO_SNDBUF, SETSOCKOPTCAST(&n), (int) sizeof(n)) == -1) {
-		Printf (PRINT_HIGH, "setsockopt SO_SNDBUF: %s", strerror(errno));
+		PrintFmt(PRINT_HIGH, "setsockopt SO_SNDBUF: {}", strerror(errno));
 	} else {
-		Printf(PRINT_HIGH, "net_sndbuf set to %d\n", n);
+		PrintFmt(PRINT_HIGH, "net_sndbuf set to {}\n", n);
 	}
 }
 
@@ -1226,11 +1154,11 @@ bool NetWaitOrTimeout(size_t ms)
 	#ifdef _WIN32
 		// handle SOCKET_ERROR
 		if(ret == SOCKET_ERROR)
-			Printf(PRINT_HIGH, "select returned SOCKET_ERROR: %d\n", WSAGetLastError());
+			PrintFmt(PRINT_HIGH, "select returned SOCKET_ERROR: {}\n", WSAGetLastError());
 	#else
 		// handle -1
 		if(ret == -1 && ret != EINTR)
-			Printf(PRINT_HIGH, "select returned -1: %s\n", strerror(errno));
+			PrintFmt(PRINT_HIGH, "select returned -1: {}\n", strerror(errno));
 	#endif
 
 	return false;
@@ -1241,4 +1169,4 @@ void I_SetPort(netadr_t &addr, int port)
    addr.port = htons(port);
 }
 
-VERSION_CONTROL (i_net_cpp, "$Id: 3ebaf4bf997b16c153c2b08e46c421a7f4b5ef46 $")
+VERSION_CONTROL (i_net_cpp, "$Id: a6f54aaecdc955596c19fa1494712bbe7a5c4d3e $")
