@@ -1,7 +1,7 @@
-// Emacs style mode select   -*- C++ -*- 
+// Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b1b555c3977ea57c682e9f4360ad783c4384ae77 $
+// $Id: 88603bbe8f55e5c581121d10f6c18190f40e77b2 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -23,9 +23,6 @@
 
 #pragma once
 
-#include "huffman.h"
-
-
 // Default buffer size for a UDP packet.
 // This constant seems to be used as a default buffer size and should
 // probably not be considered a reasonable MTU.
@@ -114,6 +111,11 @@ enum clientBuf_e
  */
 #define SVC_SM_OFLAGS BIT(2)
 
+/**
+ * @brief svc_spawnmobj: ZDoom/Heretic flags.
+ */
+#define SVC_SM_FLAGS2 BIT(3)
+
 /**
  * @brief svc_updatemobj: Supply mobj position and random index.
  */
@@ -146,7 +148,7 @@ enum clientBuf_e
 
 /**
  * @brief svc_playermembers: Ready status.
- */ 
+ */
 #define SVC_PM_READY BIT(1)
 
 /**
@@ -250,12 +252,13 @@ enum svc_t
 	svc_maplist_index,     // [AM] - Send the current and next map index to the client.
 	svc_toast,
 	svc_hordeinfo,
+	svc_raisemobj,
 	svc_netdemocap = 100,  // netdemos - NullPoint
 	svc_netdemostop = 101, // netdemos - NullPoint
 	svc_netdemoloadsnap = 102, // netdemos - NullPoint
 };
 
-static constexpr size_t svc_max = 255;
+inline constexpr size_t svc_max = 255;
 
 enum ThinkerType
 {
@@ -299,7 +302,12 @@ enum clc_t
 	clc_privmsg, // [AM] Targeted chat to a specific player.
 };
 
-static constexpr size_t clc_max = 255;
+inline auto format_as(clc_t clc)
+{
+	return fmt::underlying(clc);
+}
+
+inline constexpr size_t clc_max = 255;
 
 extern msg_info_t clc_info[clc_max + 1];
 extern msg_info_t svc_info[svc_max + 1];
@@ -342,7 +350,7 @@ public:
 	void WriteByte(byte b)
 	{
 		byte *buf = SZ_GetSpace(sizeof(b));
-		
+
 		if(!overflowed)
 		{
 			*buf = b;
@@ -352,7 +360,7 @@ public:
 	void WriteShort(short s)
 	{
 		byte *buf = SZ_GetSpace(sizeof(s));
-		
+
 		if(!overflowed)
 		{
 			buf[0] = s&0xff;
@@ -363,7 +371,7 @@ public:
 	void WriteLong(int l)
 	{
 		byte *buf = SZ_GetSpace(sizeof(l));
-		
+
 		if(!overflowed)
 		{
 			buf[0] = l&0xff;
@@ -588,10 +596,11 @@ public:
 
                 readpos += offset;
             }
+			break;
 
             case BT_SEND:
             {
-                if ((int)(readpos-offset) < 0)
+                if (offset > readpos)
                 {
                     // lies, an underflow occured
                     overflowed = true;
@@ -600,6 +609,7 @@ public:
 
                 readpos -= offset;
             }
+			break;
         }
 
         return readpos;
@@ -624,7 +634,7 @@ public:
 	{
 		return cursize;
 	}
-	
+
 	size_t maxsize() const
 	{
 		return allocsize;
@@ -647,7 +657,7 @@ public:
 		byte *olddata = data;
 		data = new byte[len];
 		allocsize = len;
-		
+
 		if (!clearbuf)
 		{
 			if (cursize < allocsize)
@@ -658,7 +668,7 @@ public:
 			{
 				clear();
 				overflowed = true;
-				Printf (PRINT_HIGH, "buf_t::resize(): overflow\n");
+				PrintFmt(PRINT_HIGH, "buf_t::resize(): overflow\n");
 			}
 		}
 		else
@@ -676,7 +686,7 @@ public:
 			clear();
 			overflowed = true;
 #if defined(ODAMEX_DEBUG)
-			Printf (PRINT_HIGH, "SZ_GetSpace: overflow\n");
+			PrintFmt(PRINT_HIGH, "SZ_GetSpace: overflow\n");
 #endif
 		}
 
@@ -693,7 +703,7 @@ public:
             return *this;
 
 		delete[] data;
-		
+
 		data = new byte[other.allocsize];
 		allocsize = other.allocsize;
 		cursize = other.cursize;
@@ -706,7 +716,7 @@ public:
 
 		return *this;
 	}
-	
+
 	buf_t()
 		: data(0), allocsize(0), cursize(0), readpos(0), overflowed(false)
 	{
@@ -717,7 +727,7 @@ public:
 	}
 	buf_t(const buf_t &other)
 		: data(new byte[other.allocsize]), allocsize(other.allocsize), cursize(other.cursize), readpos(other.readpos), overflowed(other.overflowed)
-		
+
 	{
 		if(!overflowed)
 			for(size_t i = 0; i < cursize; i++)
@@ -793,6 +803,3 @@ size_t MSG_SetOffset (const size_t &offset, const buf_t::seek_loc_t &loc);
 
 bool MSG_DecompressMinilzo ();
 bool MSG_CompressMinilzo (buf_t &buf, size_t start_offset, size_t write_gap);
-
-bool MSG_DecompressAdaptive (huffman &huff);
-bool MSG_CompressAdaptive (huffman &huff, buf_t &buf, size_t start_offset, size_t write_gap);
