@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: fdb7aab87138874641b186dd33bebadbfbdbfbe1 $
+// $Id: 90d46b1553dd56cd912d613a0b1b4e7de380640b $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -50,8 +50,9 @@ static void MapMobj(const mobjtype_t type, const std::string& name, const uint32
 	::g_MonsterMap.emplace(name, type);
 }
 
-static void InitMap()
+void P_InitMobjNameMap()
 {
+	::g_MonsterMap.clear();
 	MapMobj(MT_PLAYER, "DoomPlayer", MC_NONE);
 	MapMobj(MT_POSSESSED, "ZombieMan", MC_NONE);
 	MapMobj(MT_SHOTGUY, "ShotgunGuy", MC_NONE);
@@ -200,6 +201,8 @@ static void InitMap()
 	MapMobj(MT_AVATAR, "PlayerAvatar", MC_NONE);
 	MapMobj(MT_HORDESPAWN, "HordeSpawn", MC_NONE);
 	MapMobj(MT_CAREPACK, "CarePackage", MC_NONE);
+	MapMobj(MT_EXTRALIFE, "ExtraLifePowerUp", MC_NONE);
+	MapMobj(MT_RESTEAMMATE, "ResurrectTeammatePowerUp", MC_NONE);
 	// [AM] Deh_Actor_145-149 are reserved.
 	MapMobj(MT_EXTRA00, "Deh_Actor_150", MC_NONE);
 	MapMobj(MT_EXTRA01, "Deh_Actor_151", MC_NONE);
@@ -303,6 +306,19 @@ static void InitMap()
 	MapMobj(MT_EXTRA99, "Deh_Actor_249", MC_NONE);
 }
 
+/**
+ * @brief Add a new DeHackEd thing to the map (for ID24 DEHTHING_x strings)
+ */
+void P_MapDehThing(const mobjtype_t type, const std::string& name)
+{
+	if (::g_MonsterMap.empty())
+	{
+		P_InitMobjNameMap();
+	}
+
+	MapMobj(type, name, MC_NONE);
+}
+
 /**
  * @brief Convert a UMAPINFO/ZDoom class name to a MT Mobj index.
  */
@@ -310,12 +326,12 @@ mobjtype_t P_NameToMobj(const std::string& name)
 {
 	if (::g_MonsterMap.empty())
 	{
-		InitMap();
+		P_InitMobjNameMap();
 	}
 
 	MobjMap::iterator it = ::g_MonsterMap.find(name);
 
-	if (it == ::g_MonsterMap.end())
+	if (it == ::g_MonsterMap.end() || mobjinfo.find(it->second) == mobjinfo.end())
 	{
 		return MT_NULL;
 	}
@@ -330,12 +346,12 @@ mobjtype_t P_INameToMobj(const std::string& name)
 {
 	if (::g_MonsterMap.empty())
 	{
-		InitMap();
+		P_InitMobjNameMap();
 	}
 
 	for (const auto& [mapname, type] : ::g_MonsterMap)
 	{
-		if (iequals(mapname, name))
+		if (iequals(mapname, name) && mobjinfo.find(type) != mobjinfo.end())
 		{
 			return type;
 		}
@@ -347,7 +363,7 @@ std::string P_MobjToName(const mobjtype_t type)
 {
 	if (::g_MonsterMap.empty())
 	{
-		InitMap();
+		P_InitMobjNameMap();
 	}
 
 	for (const auto& [name, maptype] : ::g_MonsterMap)
@@ -429,7 +445,7 @@ BEGIN_COMMAND(dumpactors)
 {
 	if (::g_MonsterMap.empty())
 	{
-		InitMap();
+		P_InitMobjNameMap();
 	}
 
 	std::vector<MobjPair> infomap = OrderedMobjMap();
