@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: e3669678d9ac43d08cc653f733f201b08e1190ef $
+// $Id: ce9f6de9336f3d215ace4755955f787a739aab01 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -29,3 +29,5 @@ mobjtype_t P_NameToMobj(const std::string& name);
 mobjtype_t P_INameToMobj(const std::string& name);
 weapontype_t P_NameToWeapon(const std::string& name);
 std::string P_MobjToName(const mobjtype_t type);
+void P_MapDehThing(const mobjtype_t type, const std::string& name);
+void P_InitMobjNameMap();
