@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 08f2cfbdde9b0be0a73e929501267804042a7871 $
+// $Id: 8b8330296fe2f7f7ac3565018edb8dcc0b799260 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -73,18 +73,18 @@ void *Realloc (void *memblock, size_t size)
 }
 
 //
-// M_Free
+// M_Free2
 //
 // Wraps around the standard free() memory function. This variation is slightly
 // more safer, as it only frees a block if its not NULL and will NULL it on
 // exiting.
 void M_Free2 (void **memblock)
 {
-    if (*memblock != NULL)
+    if (*memblock != nullptr)
     {
         free(*memblock);
-        *memblock = NULL;
+        *memblock = nullptr;
     }
 }
 
-VERSION_CONTROL (m_alloc_cpp, "$Id: 08f2cfbdde9b0be0a73e929501267804042a7871 $")
+VERSION_CONTROL (m_alloc_cpp, "$Id: 8b8330296fe2f7f7ac3565018edb8dcc0b799260 $")
