@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: a836320069c413366c611361a8b7e735d19a0b45 $
+// $Id: 63aa16950dda6bad3ef5cd8a2bcf3862d273c871 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -29,6 +29,7 @@
 #include "cmdlib.h"
 #include "m_fileio.h"
 #include "m_argv.h"
+#include "m_alloc.h"
 
 IMPLEMENT_CLASS (DArgs, DObject)
 
@@ -364,11 +365,11 @@ void M_FindResponseFile (void)
 			handle = fopen (Args.GetArg(i) + 1,"rb");
 			if (!handle)
 			{ // [RH] Make this a warning, not an error.
-				Printf (PRINT_WARNING,"No such response file (%s)!", Args.GetArg(i) + 1);
+				PrintFmt(PRINT_WARNING,"No such response file ({})!", Args.GetArg(i) + 1);
 				continue;
 			}
 
-			Printf (PRINT_HIGH,"Found response file %s!\n", Args.GetArg(i) + 1);
+			PrintFmt(PRINT_HIGH,"Found response file {}!\n", Args.GetArg(i) + 1);
 			fseek (handle, 0, SEEK_END);
 			size = ftell (handle);
 			fseek (handle, 0, SEEK_SET);
@@ -376,7 +377,7 @@ void M_FindResponseFile (void)
 			size_t readlen = fread (file, size, 1, handle);
 			if (readlen < 1)
 			{
-				Printf (PRINT_HIGH,"Failed to read response file %s.\n", Args.GetArg(i) + 1);
+				PrintFmt(PRINT_HIGH,"Failed to read response file {}.\n", Args.GetArg(i) + 1);
 			}
 			file[size] = 0;
 			fclose (handle);
@@ -405,9 +406,9 @@ void M_FindResponseFile (void)
 			delete[] file;
 
 			// DISPLAY ARGS
-			Printf("%zu command-line args:\n", Args.NumArgs());
+			PrintFmt("{} command-line args:\n", Args.NumArgs());
 			for (size_t k = 1; k < Args.NumArgs (); k++)
-				Printf (PRINT_HIGH,"%s\n", Args.GetArg (k));
+				PrintFmt(PRINT_HIGH,"{}\n", Args.GetArg (k));
 
 			break;
 		}
@@ -514,4 +515,4 @@ int M_GetParmValue(const char* name)
 	return 0;
 }
 
-VERSION_CONTROL (m_argv_cpp, "$Id: a836320069c413366c611361a8b7e735d19a0b45 $")
+VERSION_CONTROL (m_argv_cpp, "$Id: 63aa16950dda6bad3ef5cd8a2bcf3862d273c871 $")
