@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 519524dde1b5d971800633773589e78fdd17911e $
+// $Id: 82e00825c4ad027aa000d36ecd14098a503ca980 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -211,7 +211,7 @@ bool M_WriteFile(std::string filename, void *source, QWORD length)
 
     if (handle == NULL)
 	{
-		Printf(PRINT_HIGH, "Could not open file %s for writing\n", filename);
+		PrintFmt(PRINT_HIGH, "Could not open file {} for writing\n", filename);
 		return false;
 	}
 
@@ -220,7 +220,7 @@ bool M_WriteFile(std::string filename, void *source, QWORD length)
 
 	if (count != length)
 	{
-		Printf(PRINT_HIGH, "Failed while writing to file %s\n", filename);
+		PrintFmt(PRINT_HIGH, "Failed while writing to file {}\n", filename);
 		return false;
 	}
 
@@ -243,7 +243,7 @@ QWORD M_ReadFile(std::string filename, BYTE **buffer)
 
 	if (handle == NULL)
 	{
-		Printf(PRINT_HIGH, "Could not open file %s for reading\n", filename);
+		PrintFmt(PRINT_HIGH, "Could not open file {} for reading\n", filename);
 		return false;
 	}
 
@@ -255,7 +255,7 @@ QWORD M_ReadFile(std::string filename, BYTE **buffer)
 
     if (count != length)
 	{
-		Printf(PRINT_HIGH, "Failed while reading from file %s\n", filename);
+		PrintFmt(PRINT_HIGH, "Failed while reading from file {}\n", filename);
 		return false;
 	}
 
@@ -377,7 +377,7 @@ bool M_IsPathSep(const char ch)
 		return true;
 	}
 
-#if defined(_WIN32) && !defined(_XBOX)
+#if defined(_WIN32)
 	// This is not the canonical path separator, but it is valid.
 	if (ch == '/')
 	{
@@ -404,13 +404,6 @@ std::string M_GetUserFileName(const std::string& file)
 {
 #ifdef __SWITCH__
 	std::string path = file;
-	return M_CleanPath(path);
-#elif defined(_XBOX)
-	std::string path = "T:";
-
-	path += PATHSEP;
-	path += file;
-
 	return M_CleanPath(path);
 #else
 	fs::path path(file);
@@ -440,9 +433,6 @@ std::string M_GetUserFileName(const std::string& file)
 
 std::string M_GetWriteSubDir(std::string_view folder)
 {
-#if defined(_XBOX)
-	return "T:" PATHSEP;
-#else
 	// Does the folder exist?
 	fs::path path = M_GetWriteDir();
 	path /= folder;
@@ -455,7 +445,6 @@ std::string M_GetWriteSubDir(std::string_view folder)
 	{
 		I_FatalError("Failed to create directory {}: {}\n", path.string(), e.what());
 	}
-#endif
 }
 
 std::string M_GetDownloadDir()
@@ -475,10 +464,7 @@ std::string M_GetNetDemoDir()
 
 std::string M_GetScreenshotFileName(const std::string& file, const std::string& altpath)
 {
-#if defined(_XBOX)
-	fs::path path = "T:";
-	path /= file;
-#elif defined __SWITCH__
+#ifdef __SWITCH__
 	fs::path path = file;
 #else
 	fs::path path;
@@ -509,10 +495,7 @@ std::string M_GetScreenshotFileName(const std::string& file, const std::string&
 
 std::string M_GetNetDemoFileName(const std::string& file, const std::string& altpath)
 {
-#if defined(_XBOX)
-	fs::path path = "T:";
-	path /= file;
-#elif defined __SWITCH__
+#ifdef __SWITCH__
 	fs::path path = file;
 #else
 	fs::path path;
@@ -700,4 +683,4 @@ bool M_GetAbsPath(const std::string& path, std::string& out)
 #endif
 }
 
-VERSION_CONTROL(m_fileio_cpp, "$Id: 519524dde1b5d971800633773589e78fdd17911e $")
+VERSION_CONTROL(m_fileio_cpp, "$Id: 82e00825c4ad027aa000d36ecd14098a503ca980 $")
