@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 0856429fd4a48557e8f522430078ec22ab5b4510 $
+// $Id: 3f6bd97aa62a063e6ae29244f75c5af425f73b62 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -56,9 +56,7 @@ namespace fs = std::filesystem;
 
 std::string M_GetBinaryDir()
 {
-#if defined(GEKKO)
-	ret = "sd:/";
-#elif defined(__SWITCH__)
+#if defined(__SWITCH__)
 	return "./";
 #else
 	std::string ret;
