@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 0884e246053db63b5ee7fd722107aea5f345fd20 $
+// $Id: 73e7b4f136e94a323412922e8b8ef66cbe879d7c $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -104,6 +104,13 @@ OString::OString(const std::string& str) :
 	assign(str);
 }
 
+OString::OString(std::string_view str) :
+	mId(mEmptyStringId)
+{
+	startup();
+	assign(str.data(), str.length());
+}
+
 OString::OString(const OString& other, size_t pos, size_t len) :
 	mId(mEmptyStringId)
 {
@@ -118,6 +125,14 @@ OString::OString(const std::string& str, size_t pos, size_t len) :
 	assign(std::string(str, pos, len));
 }
 
+OString::OString(std::string_view str, size_t pos, size_t len) :
+	mId(mEmptyStringId)
+{
+	startup();
+	str = str.substr(pos, len);
+	assign(str.data(), str.length());
+}
+
 OString::OString(const char* s, size_t n) :
 	mId(mEmptyStringId)
 {
@@ -822,4 +837,4 @@ OString OStringToLower(const OString& str)
 	return OStringConverter<LowerFunctor>(str.c_str(), str.length());
 }
 
-VERSION_CONTROL (m_ostring_cpp, "$Id: 0884e246053db63b5ee7fd722107aea5f345fd20 $")
+VERSION_CONTROL (m_ostring_cpp, "$Id: 73e7b4f136e94a323412922e8b8ef66cbe879d7c $")
