@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 1270418e2cc972a3f3654d4eaa5d1d63bd73d1a4 $
+// $Id: 2f2013357c2dbb6a8491d0fcb623a6a8af950986 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -111,8 +111,10 @@ public:
 	OString();
 	OString(const OString& other);
 	OString(const std::string& str);
+	OString(std::string_view str);
 	OString(const OString& other, size_t pos, size_t len = npos);
 	OString(const std::string& str, size_t pos, size_t len = npos);
+	OString(std::string_view str, size_t pos, size_t len = npos);
 	OString(const char* s, size_t n = npos);
 	OString(size_t n, char c);
 
