@@ -1,7 +1,7 @@
-// Emacs style mode select   -*- C++ -*- 
+// Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 8e0fb38b25704c398e462005e83c648344e017c5 $
+// $Id: 4c40f97afdb9e12e1b1375550b839e2ca04c93fe $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -30,7 +30,9 @@
 #include <string.h>
 
 #include <string>
+#include <string_view>
 #include <vector>
+#include <map>
 
 #include <nonstd/span.hpp>
 #include "fmt/format.h"
@@ -40,3 +42,5 @@
 #include "doomdef.h"
 #include "doomstat.h"
 #include "doomfunc.h"
+
+using namespace std::string_view_literals;
