@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 26d60c498e409f5b746c932fe128129ae6188ee5 $
+// $Id: 61b025f192d7d3d3bb8625f44db147eb9aa28255 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -27,8 +27,9 @@
 struct OScannerConfig
 {
 	OLumpName lumpName;
-	bool semiComments;
-	bool cComments;
+	bool semiComments = false;
+	bool cComments    = false;
+	bool hashComments = false;
 };
 
 class OScanner
@@ -76,25 +77,25 @@ class OScanner
 	[[nodiscard]] float getTokenFloat() const;
 	[[nodiscard]] bool getTokenBool() const;
 
-	[[nodiscard]] bool &crossed();
+	bool &crossed();
 	[[nodiscard]] bool isQuotedString() const;
 	[[nodiscard]] bool isIdentifier() const;
-	void assertTokenIs(const char* string) const;
-	void assertTokenNoCaseIs(const char* string) const;
-	[[nodiscard]] bool compareToken(const char* string) const;
-	[[nodiscard]] bool compareTokenNoCase(const char* string) const;
+	void assertTokenIs(std::string_view string) const;
+	void assertTokenNoCaseIs(std::string_view string) const;
+	[[nodiscard]] bool compareToken(std::string_view string) const;
+	[[nodiscard]] bool compareTokenNoCase(std::string_view string) const;
 
 	template <typename... ARGS>
-	void warning(const fmt::string_view format, const ARGS&... args) const
+	void warning(fmt::format_string<ARGS...> format, ARGS&&... args) const
 	{
 		PrintFmt(PRINT_WARNING, "Parse Warning: {}:{}: {}\n", m_config.lumpName,
-		       m_lineNumber, fmt::format(format, args...));
+		       m_lineNumber, fmt::format(format, std::forward<ARGS>(args)...));
 	}
 
 	template <typename... ARGS>
-	void error(const fmt::string_view format, const ARGS&... args) const
+	void error(fmt::format_string<ARGS...> format, ARGS&&... args) const
 	{
 		I_Error("Parse Error: {}:{}: {}", m_config.lumpName, m_lineNumber,
-		        fmt::format(format, args...));
+		        fmt::format(format, std::forward<ARGS>(args)...));
 	}
 };
