@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 87973b23130eca266795b45e89248055f8564d15 $
+// $Id: 25ca2bb689fb90944c4d3a3ac397a1333a5dbc02 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -213,6 +213,7 @@ void DCeiling::RunThink ()
 			case silentCrushAndRaise:
 			case crushAndRaise:
 				m_Speed = CEILSPEED;
+				[[fallthrough]];
 			case fastCrushAndRaise:
 				m_Speed = m_Speed2;
 				m_Direction = 1;
@@ -528,9 +529,10 @@ DCeiling* DCeiling::Clone(sector_t* sec) const
 // Restart a ceiling that's in-stasis
 // [RH] Passed a tag instead of a line and rewritten to use list
 //
-void P_ActivateInStasisCeiling (int tag)
+bool P_ActivateInStasisCeiling (int tag)
 {
 	DCeiling *scan;
+	bool rtn = false;
 	TThinkerIterator<DCeiling> iterator;
 
 	while ( (scan = iterator.Next ()) )
@@ -539,8 +541,11 @@ void P_ActivateInStasisCeiling (int tag)
 		{
 			scan->m_Direction = scan->m_OldDirection;
 			scan->PlayCeilingSound ();
+			rtn = true;
 		}
 	}
+
+	return rtn;
 }
 
 bool EV_ZDoomCeilingCrushStop(int tag, bool remove)
@@ -610,7 +615,7 @@ bool P_SpawnZDoomCeiling(DCeiling::ECeiling type, line_t* line, int tag, fixed_t
 		manual = true;
 		// [RH] Hack to let manual crushers be retriggerable, too
 		tag ^= secnum | 0x1000000;
-		P_ActivateInStasisCeiling(tag);
+		rtn |= P_ActivateInStasisCeiling(tag);
 		goto manual_ceiling;
 	}
 
@@ -618,7 +623,7 @@ bool P_SpawnZDoomCeiling(DCeiling::ECeiling type, line_t* line, int tag, fixed_t
 	// This restarts a crusher after it has been stopped
 	if (type == DCeiling::ceilCrushAndRaise)
 	{
-		P_ActivateInStasisCeiling(tag);
+		rtn |= P_ActivateInStasisCeiling(tag);
 	}
 
 	secnum = -1;
@@ -871,7 +876,7 @@ bool EV_DoCeiling (DCeiling::ECeiling type, line_t *line,
 		manual = true;
 		// [RH] Hack to let manual crushers be retriggerable, too
 		tag ^= secnum | 0x1000000;
-		P_ActivateInStasisCeiling (tag);
+		rtn |= P_ActivateInStasisCeiling (tag);
 		goto manual_ceiling;
 	}
 
@@ -879,7 +884,7 @@ bool EV_DoCeiling (DCeiling::ECeiling type, line_t *line,
 	// This restarts a crusher after it has been stopped
 	if (type == DCeiling::crushAndRaise)
 	{
-		P_ActivateInStasisCeiling (tag);
+		rtn |= P_ActivateInStasisCeiling (tag);
 	}
 
 	secnum = -1;
@@ -1250,4 +1255,4 @@ bool EV_CeilingCrushStop (int tag)
 	return rtn;
 }
 
-VERSION_CONTROL (p_ceiling_cpp, "$Id: 87973b23130eca266795b45e89248055f8564d15 $")
+VERSION_CONTROL (p_ceiling_cpp, "$Id: 25ca2bb689fb90944c4d3a3ac397a1333a5dbc02 $")
