@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 09da65b9fad4849fed006fb1cf742de756ee13bb $
+// $Id: a0f17f0b8d49972611284db7648b19ad698d6611 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -396,7 +396,7 @@ DDoor::DDoor(sector_t* sec, line_t* ln, int kind, int trigger, int speed)
     : DMovingCeiling(sec), m_Status(init)
 {
 	m_Line = ln;
-	m_TopWait = VDOORWAIT;
+	m_TopWait = doors::WAIT;
 	m_TopHeight = P_FindLowestCeilingSurrounding(sec) - 4 * FRACUNIT;
 	m_Status = opening;
 	m_TopCountdown = -1;
@@ -408,19 +408,19 @@ DDoor::DDoor(sector_t* sec, line_t* ln, int kind, int trigger, int speed)
 	default:
 	case SpeedSlow:
 		m_Type = kind ? genOpen : genRaise;
-		m_Speed = VDOORSPEED;
+		m_Speed = doors::SPEED;
 		break;
 	case SpeedNormal:
 		m_Type = kind ? genOpen : genRaise;
-		m_Speed = VDOORSPEED * 2;
+		m_Speed = doors::SPEED * 2;
 		break;
 	case SpeedFast:
 		m_Type = kind ? genBlazeOpen : genBlazeRaise;
-		m_Speed = VDOORSPEED * 4;
+		m_Speed = doors::SPEED * 4;
 		break;
 	case SpeedTurbo:
 		m_Type = kind ? genBlazeOpen : genBlazeRaise;
-		m_Speed = VDOORSPEED * 8;
+		m_Speed = doors::SPEED * 8;
 		break;
 	}
 	/* killough 10/98: implement gradual lighting */
@@ -445,13 +445,13 @@ DDoor::DDoor(sector_t* sec, line_t* ln, int delay, int kind, int trigger, int sp
 		m_TopWait = 35;
 		break;
 	case 1:
-		m_TopWait = VDOORWAIT;
+		m_TopWait = doors::WAIT;
 		break;
 	case 2:
-		m_TopWait = 2 * VDOORWAIT;
+		m_TopWait = 2 * doors::WAIT;
 		break;
 	case 3:
-		m_TopWait = 7 * VDOORWAIT;
+		m_TopWait = 7 * doors::WAIT;
 		break;
 	}
 
@@ -460,16 +460,16 @@ DDoor::DDoor(sector_t* sec, line_t* ln, int delay, int kind, int trigger, int sp
 	{
 	default:
 	case SpeedSlow:
-		m_Speed = VDOORSPEED;
+		m_Speed = doors::SPEED;
 		break;
 	case SpeedNormal:
-		m_Speed = VDOORSPEED * 2;
+		m_Speed = doors::SPEED * 2;
 		break;
 	case SpeedFast:
-		m_Speed = VDOORSPEED * 4;
+		m_Speed = doors::SPEED * 4;
 		break;
 	case SpeedTurbo:
-		m_Speed = VDOORSPEED * 8;
+		m_Speed = doors::SPEED * 8;
 		break;
 	}
 	/* killough 10/98: implement gradual lighting */
@@ -968,4 +968,4 @@ manual_genlocked:
 }
 
 
-VERSION_CONTROL (p_doors_cpp, "$Id: 09da65b9fad4849fed006fb1cf742de756ee13bb $")
+VERSION_CONTROL (p_doors_cpp, "$Id: a0f17f0b8d49972611284db7648b19ad698d6611 $")
