@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b5f2dd9e62ea63118966b3a27ec977e2a6781032 $
+// $Id: 5256af6a41b324a32ca97c8a943049d9dcd76d18 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -32,6 +32,7 @@
 
 void P_ResetTransferSpecial(newspecial_s* newspecial);
 unsigned int P_ResetSectorTransferFlags(const unsigned int flags);
+void SV_BroadcastSectorProperties(int sectornum);
 
 EXTERN_CVAR(co_boomphys)
 
@@ -745,8 +746,6 @@ DFloor::DFloor(sector_t *sec, DFloor::EFloor floortype, line_t *line,
 		break;
 
 	case DFloor::floorRaiseAndCrush:
-		m_Crush = crush;
-		[[fallthrough]];
 	case DFloor::floorRaiseToLowestCeiling:
 		m_Direction = 1;
 		m_FloorDestHeight =
@@ -942,13 +941,13 @@ DFloor* DFloor::Clone(sector_t* sec) const
 // HANDLE FLOOR TYPES
 // [RH] Added tag, speed, height, crush, change params.
 //
-BOOL EV_DoFloor (DFloor::EFloor floortype, line_t *line, int tag,
+bool EV_DoFloor (DFloor::EFloor floortype, line_t *line, int tag,
 				 fixed_t speed, fixed_t height, bool crush, int change)
 {
 	int 				secnum;
-	BOOL 				rtn = false;
+	bool 				rtn = false;
 	sector_t*			sec;
-	BOOL				manual = false;
+	bool				manual = false;
 
 	// check if a manual trigger; if so do just the sector on the backside
 	if (co_boomphys && tag == 0)
@@ -997,10 +996,10 @@ manual_floor:
 // jff 02/04/98 Added this routine (and file) to handle generalized
 // floor movers using bit fields in the line special type.
 //
-BOOL EV_DoGenFloor(line_t* line)
+bool EV_DoGenFloor(line_t* line)
 {
 	int secnum;
-	BOOL rtn;
+	bool rtn;
 	bool manual;
 	sector_t* sec;
 	unsigned value = (unsigned)line->special - GenFloorBase;
@@ -1053,11 +1052,11 @@ BOOL EV_DoGenFloor(line_t* line)
 	return rtn;
 }
 
-BOOL EV_DoZDoomFloor(DFloor::EFloor floortype, line_t* line, int tag, fixed_t speed,
+bool EV_DoZDoomFloor(DFloor::EFloor floortype, line_t* line, int tag, fixed_t speed,
                 fixed_t height, int crush, int change, bool hexencrush, bool hereticlower)
 {
 	int secnum;
-	BOOL rtn = false;
+	bool rtn = false;
 	sector_t* sec;
 	bool manual = false;
 
@@ -1111,10 +1110,10 @@ BOOL EV_DoZDoomFloor(DFloor::EFloor floortype, line_t* line, int tag, fixed_t sp
 // jff 3/15/98 added to better support generalized sector types
 // [RH] Added tag parameter.
 //
-BOOL EV_DoChange (line_t *line, EChange changetype, int tag)
+bool EV_DoChange (line_t *line, EChange changetype, int tag)
 {
 	int			secnum;
-	BOOL		rtn;
+	bool		rtn;
 	sector_t	*sec;
 	sector_t	*secm;
 
@@ -1134,6 +1133,10 @@ BOOL EV_DoChange (line_t *line, EChange changetype, int tag)
 			if (line) { // [RH] if no line, no change
 				sec->floorpic = line->frontsector->floorpic;
 				sec->special = line->frontsector->special;
+				sec->SectorChanges |= SPC_FlatPic | SPC_Special;
+				SERVER_ONLY(
+					SV_BroadcastSectorProperties(secnum);
+				)
 			}
 			break;
 		case numChangeOnly:
@@ -1142,6 +1145,10 @@ BOOL EV_DoChange (line_t *line, EChange changetype, int tag)
 			{
 				sec->floorpic = secm->floorpic;
 				sec->special = secm->special;
+				sec->SectorChanges |= SPC_FlatPic | SPC_Special;
+				SERVER_ONLY(
+					SV_BroadcastSectorProperties(secnum);
+				)
 			}
 			break;
 		default:
@@ -1154,7 +1161,7 @@ BOOL EV_DoChange (line_t *line, EChange changetype, int tag)
 //
 // [Blair] Generic staircase building
 //
-BOOL EV_DoGenStairs(line_t* line)
+bool EV_DoGenStairs(line_t* line)
 {
 	int secnum;
 	int osecnum; // jff 3/4/98 save old loop index
@@ -1368,7 +1375,7 @@ BOOL EV_DoGenStairs(line_t* line)
 //		by its special. If usespecials is 2, each sector stays in "sync" with
 //		the others.
 //
-BOOL EV_BuildStairs (int tag, DFloor::EStair type, line_t *line,
+bool EV_BuildStairs (int tag, DFloor::EStair type, line_t *line,
 					 fixed_t stairsize, fixed_t speed, int delay, int reset, int igntxt,
 					 int usespecials)
 {
@@ -1380,14 +1387,14 @@ BOOL EV_BuildStairs (int tag, DFloor::EStair type, line_t *line,
 	int 				texture;
 	int 				ok;
 	int					persteptime;
-	BOOL 				rtn = false;
+	bool 				rtn = false;
 
 	sector_t*			sec = NULL;
 	sector_t*			tsec = NULL;
 	sector_t*			prev = NULL;
 
 	DFloor*				floor = NULL;
-	BOOL				manual = false;
+	bool				manual = false;
 
 	if (speed == 0)
 		return false;
@@ -1562,7 +1569,7 @@ manual_stair:
 
 int P_SpawnDonut(int, line_t*, fixed_t, fixed_t);
 
-BOOL EV_DoZDoomDonut(int tag, line_t* line, fixed_t pillarspeed, fixed_t slimespeed)
+bool EV_DoZDoomDonut(int tag, line_t* line, fixed_t pillarspeed, fixed_t slimespeed)
 {
 	int rtn = 0;
 
@@ -1794,7 +1801,7 @@ bool SpawnCommonElevator(line_t*, DElevator::EElevator, fixed_t,
 // jff 2/22/98 new type to move floor and ceiling in parallel
 // [RH] Added speed, tag, and height parameters and new types.
 //
-BOOL EV_DoElevator (line_t *line, DElevator::EElevator elevtype,
+bool EV_DoElevator (line_t *line, DElevator::EElevator elevtype,
 					fixed_t speed, fixed_t height, int tag)
 {
 	bool rtn = SpawnCommonElevator(line, elevtype, speed, height, tag);
@@ -1805,7 +1812,7 @@ bool SpawnCommonElevator(line_t* line, DElevator::EElevator type, fixed_t speed,
                        fixed_t height, int tag)
 {
 	int secnum;
-	BOOL rtn;
+	bool rtn;
 	sector_t* sec;
 	DElevator* elevator;
 
@@ -1923,7 +1930,7 @@ static constexpr fixed_t FloatBobOffsets[64] = {
     -524288, -521764, -514214, -501713, -484379, -462381, -435930, -405280,
     -370728, -332605, -291279, -247148, -200637, -152193, -102284, -51389};
 /*
-BOOL EV_StartPlaneWaggle(int tag, line_t* line, int height, int speed, int offset,
+bool EV_StartPlaneWaggle(int tag, line_t* line, int height, int speed, int offset,
                              int timer, bool ceiling)
 {
 	int sectorIndex;
@@ -2094,4 +2101,4 @@ DWaggle* DWaggle::Clone(sector_t* sec) const
 	return ele;
 }
 */
-VERSION_CONTROL (p_floor_cpp, "$Id: b5f2dd9e62ea63118966b3a27ec977e2a6781032 $")
+VERSION_CONTROL (p_floor_cpp, "$Id: 5256af6a41b324a32ca97c8a943049d9dcd76d18 $")
