@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: c9f6e330bae3aa231cd03193abc4a4d5450b4ecf $
+// $Id: 36b9e7ef21f9b5f25584cff91689eb023a9dcb30 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -50,6 +50,8 @@ EXTERN_CVAR(g_horde_spawnempty_min)
 EXTERN_CVAR(g_horde_spawnempty_max)
 EXTERN_CVAR(g_horde_spawnfull_min)
 EXTERN_CVAR(g_horde_spawnfull_max)
+EXTERN_CVAR(g_horde_extralife)
+EXTERN_CVAR(g_horde_resurrect)
 EXTERN_CVAR(sv_nomonsters)
 
 void A_PainDie(AActor* actor);
@@ -91,10 +93,7 @@ class corpseCollector_t
 		m_corpses.push(ptr->ptr());
 		m_added += 1;
 	}
-	void startWave()
-	{
-		m_waveStart = m_added;
-	}
+	void startWave() { m_waveStart = m_added; }
 	void tick()
 	{
 		if (m_removed >= m_waveStart)
@@ -201,6 +200,15 @@ class HordeState
 	int m_nextSpawn;
 	int m_nextPowerup;
 	corpseCollector_t m_corpses;
+	mobjCounts_t m_monsterCounts;
+	mobjCounts_t m_bossCounts;
+
+	/**
+	 * @brief Returns number of bosses currently alive.
+	 */
+	size_t countLivingBosses() {
+		return std::count_if(m_bosses.begin(), m_bosses.end(), [](const auto& boss){ return boss && boss->health > 0; });
+	}
 
 	/**
 	 * @brief Set the given state.
@@ -209,7 +217,7 @@ class HordeState
 	{
 		m_state = state;
 
-		if (m_state == HS_WANTBOSS)
+		if (m_state == HS_WANTBOSS && m_bossTime == m_waveTime)
 		{
 			// Do the boss intro fanfare.
 			SV_BroadcastPrintFmt("The floor trembles as the boss of the wave arrives.\n");
@@ -223,7 +231,7 @@ class HordeState
 	    : m_state(HS_STARTING), m_wave(0), m_waveTime(0), m_bossTime(0), m_defineID(0),
 	      m_spawnedHealth(0), m_killedHealth(0), m_bossHealth(0), m_bossDamage(0),
 	      m_waveStartHealth(0), m_bossRecipe(hordeRecipe_t()), m_nextSpawn(0),
-	      m_nextPowerup(0)
+	      m_nextPowerup(0), m_monsterCounts(), m_bossCounts()
 	{
 	}
 
@@ -247,6 +255,8 @@ class HordeState
 		m_nextSpawn = ::level.time;
 		m_nextPowerup = ::level.time + (30 * TICRATE);
 		m_corpses.clear();
+		m_monsterCounts.clear();
+		m_bossCounts.clear();
 
 		// Avoid printing wave name on boot and map switch.
 		if (printWave)
@@ -345,6 +355,7 @@ class HordeState
 		m_bosses.clear();
 		m_bossRecipe.clear();
 		m_corpses.startWave();
+		m_bossCounts.clear();
 
 		SV_BroadcastPrintFmt("Wave {}: \"{}\"\n", m_wave,
 		                     G_HordeDefine(m_defineID).name);
@@ -372,6 +383,7 @@ class HordeState
 		m_bosses.clear();
 		m_bossRecipe.clear();
 		m_corpses.startWave();
+		m_bossCounts.clear();
 
 		SV_BroadcastPrintFmt("Wave {}: \"{}\"\n", m_wave,
 		                     G_HordeDefine(m_defineID).name);
@@ -450,35 +462,83 @@ class HordeState
 		}
 	}
 
-	void addSpawnHealth(const int health)
+	/**
+	 * @brief Re-count all monsters helper
+	 *
+	 * @detail Used for loading savegames.
+	 *
+	 * @param monsterCounts map to update the counts off (m_bossCounts or m_monsterCounts)
+	 * @param type Type of monster to increment count of
+	 */
+	void recountMonstersHelper(mobjCounts_t& monsterCounts, int32_t type)
 	{
-		m_spawnedHealth += health;
+		if (monsterCounts.count(type))
+		{
+			monsterCounts[type] += 1;
+		}
+		else
+		{
+			monsterCounts[type] = 1;
+		}
 	}
 
-	void addKilledHealth(const int health)
+	/**
+	 * @brief Re-count all monsters
+	 *
+	 * @detail Used for loading savegames.
+	 */
+	void recountMonsters()
 	{
-		m_killedHealth += health;
+		AActor* mo;
+		TThinkerIterator<AActor> iterator;
+
+		m_monsterCounts.clear();
+		m_bossCounts.clear();
+		while ((mo = iterator.Next()))
+		{
+			if (mo->health > 0)
+			{
+				if (mo->oflags & MFO_BOSSPOOL)
+				{
+					recountMonstersHelper(m_bossCounts, mo->type);
+				}
+				else
+				{
+					recountMonstersHelper(m_monsterCounts, mo->type);
+				}
+			}
+		}
 	}
 
-	void addBossHealth(const int health)
+	void addSpawnHealth(const int health) { m_spawnedHealth += health; }
+
+	void addKilledHealth(const int health) { m_killedHealth += health; }
+
+	void addBossHealth(const int health) { m_bossHealth += health; }
+
+	void addBossDamage(const int health) { m_bossDamage += health; }
+
+	void addCorpse(AActor* mo) { m_corpses.pushCorpse(mo); }
+
+	void decrementCount(AActor* mo)
 	{
-		m_bossHealth += health;
+		if (mo->oflags & MFO_BOSSPOOL)
+		{
+			if (m_bossCounts.count(mo->type))
+			{
+				m_bossCounts[mo->type] -= 1;
+			}
+		}
+		else
+		{
+			if (m_monsterCounts.count(mo->type))
+			{
+				m_monsterCounts[mo->type] -= 1;
+			}
+		}
 	}
 
-	void addBossDamage(const int health)
-	{
-		m_bossDamage += health;
-	}
-
-	void addCorpse(AActor* mo)
-	{
-		m_corpses.pushCorpse(mo);
-	}
-
-	size_t getDefineID() const
-	{
-		return m_defineID;
-	}
+	size_t getDefineID() const { return m_defineID; }
 
 	int getAliveHealth() const { return m_spawnedHealth - m_killedHealth; }
 	void changeState();
@@ -506,7 +566,8 @@ void HordeState::changeState()
 		return;
 	}
 	case HS_PRESSURE: {
-		if (m_killedHealth > goalHealth && m_bosses.empty())
+		size_t alive = countLivingBosses();
+		if (m_killedHealth > goalHealth && (m_bosses.empty() || alive < m_bossRecipe.limit))
 		{
 			// We reached the goal, spawn the boss.
 			setState(HS_WANTBOSS);
@@ -514,7 +575,8 @@ void HordeState::changeState()
 		return;
 	}
 	case HS_RELAX: {
-		if (m_killedHealth > goalHealth && m_bosses.empty())
+		size_t alive = countLivingBosses();
+		if (m_killedHealth > goalHealth && (m_bosses.empty() || alive < m_bossRecipe.limit))
 		{
 			// We reached the goal, spawn the boss.
 			setState(HS_WANTBOSS);
@@ -525,6 +587,7 @@ void HordeState::changeState()
 			setState(HS_PRESSURE);
 		}
 		return;
+	}
 	case HS_WANTBOSS: {
 		if (m_bossRecipe.isValid() && static_cast<int>(m_bosses.size()) >= m_bossRecipe.count)
 		{
@@ -534,7 +597,6 @@ void HordeState::changeState()
 		}
 		return;
 	}
-	}
 	default:
 		return;
 	}
@@ -564,10 +626,10 @@ void HordeState::getNextSpawnTime(int& min, int& max)
 		alive += (define.maxTotalHealth() - alive) / 2;
 	}
 
-	double minf = Remap(alive, define.minTotalHealth(),
-	                    define.maxTotalHealth(), EMPTY_MIN_SPAWN, EMPTY_MAX_SPAWN);
-	double maxf = Remap(alive, define.minTotalHealth(),
-	                    define.maxTotalHealth(), FULL_MIN_SPAWN, FULL_MAX_SPAWN);
+	double minf = Remap(alive, define.minTotalHealth(), define.maxTotalHealth(),
+	                    EMPTY_MIN_SPAWN, EMPTY_MAX_SPAWN);
+	double maxf = Remap(alive, define.minTotalHealth(), define.maxTotalHealth(),
+	                    FULL_MIN_SPAWN, FULL_MAX_SPAWN);
 
 	// Don't absolutely pound the players in the first minute.
 	const int FALLOFF_TIME = m_waveTime + ::HORDE_STARTING_TICS + TICRATE * 60;
@@ -599,13 +661,8 @@ void HordeState::tick()
 	// Are the bosses taken care of?
 	if (m_state != HS_WANTBOSS && m_bossRecipe.isValid())
 	{
-		size_t alive = 0;
-		for (auto& boss : m_bosses)
-		{
-			if (boss && boss->health > 0)
-				alive += 1;
-		}
-		if (!alive)
+		size_t alive = countLivingBosses();
+		if (!alive && m_bossRecipe.limit <= 0)
 		{
 			// Start the next wave.
 			nextWave();
@@ -631,10 +688,11 @@ void HordeState::tick()
 
 			// Pick a recipe for some monsters.
 			hordeRecipe_t recipe;
-			const bool ok = P_HordeSpawnRecipe(recipe, define, false);
+			const bool ok = P_HordeSpawnRecipe(recipe, define, false, m_monsterCounts);
 			if (!ok)
 			{
-				Printf(PRINT_WARNING, "%s: No spawn recipe for monster.\n", __FUNCTION__);
+				if (recipe.count >= 0)
+					PrintFmt(PRINT_WARNING, "{}: No spawn recipe for monster.\n", __FUNCTION__);
 				return;
 			}
 
@@ -642,7 +700,7 @@ void HordeState::tick()
 			hordeSpawn_t* spawn = P_HordeSpawnPoint(recipe);
 			if (spawn == NULL)
 			{
-				Printf(PRINT_WARNING, "%s: Can't find a place to spawn %s.\n",
+				PrintFmt(PRINT_WARNING, "{}: Can't find a place to spawn {}.\n",
 				       __FUNCTION__, ::mobjinfo[recipe.type].name);
 				return;
 			}
@@ -651,7 +709,7 @@ void HordeState::tick()
 			DPrintFmt("Spawning {} {} ({} hp) at a {} spawn\n", recipe.count,
 			          ::mobjinfo[recipe.type].name, hp, HordeThingStr(spawn->type));
 
-			AActors mobjs = P_HordeSpawn(*spawn, recipe);
+			AActors mobjs = P_HordeSpawn(*spawn, recipe, m_monsterCounts);
 			ActivateMonsters(mobjs);
 			break;
 		}
@@ -669,10 +727,10 @@ void HordeState::tick()
 			if (!m_bossRecipe.isValid())
 			{
 				// Pick a recipe for the boss.
-				const bool ok = P_HordeSpawnRecipe(recipe, define, true);
+				const bool ok = P_HordeSpawnRecipe(recipe, define, true, m_bossCounts);
 				if (!ok)
 				{
-					Printf(PRINT_WARNING, "%s: No spawn recipe for boss monster.\n",
+					PrintFmt(PRINT_WARNING, "{}: No spawn recipe for boss monster.\n",
 					       __FUNCTION__);
 					break;
 				}
@@ -682,21 +740,32 @@ void HordeState::tick()
 			}
 			else
 			{
-				// Adjust the count based on how many bosses we've spawned.
+				// Adjust the count based on how many bosses we've spawned and current boss limit.
 				recipe = m_bossRecipe;
-				recipe.count = m_bossRecipe.count - int(m_bosses.size());
+				recipe.count = m_bossRecipe.totalCount - int(m_bosses.size());
+				int alive = int(countLivingBosses());
+				if (recipe.limit)
+				{
+					if (recipe.count <= 0)
+					{
+						m_bossRecipe.limit = 0;
+						recipe.count = 0;
+					}
+					else
+						recipe.count = clamp(recipe.limit - alive, 0, recipe.count);
+				}
 			}
 
 			// Spawn a boss if we don't have one.
 			hordeSpawn_t* spawn = P_HordeSpawnPoint(recipe);
 			if (spawn == NULL)
 			{
-				Printf(PRINT_WARNING, "%s: Can't find a place to spawn %s.\n",
+				PrintFmt(PRINT_WARNING, "{}: Can't find a place to spawn {}.\n",
 				       __FUNCTION__, ::mobjinfo[recipe.type].name);
 				break;
 			}
 
-			AActors mobjs = P_HordeSpawn(*spawn, recipe);
+			AActors mobjs = P_HordeSpawn(*spawn, recipe, m_bossCounts);
 			m_bosses.insert(m_bosses.end(), mobjs.begin(), mobjs.end());
 			ActivateMonsters(mobjs);
 			break;
@@ -709,14 +778,40 @@ void HordeState::tick()
 	// Always try to spawn an item.
 	P_HordeSpawnItem();
 
-	// Always try to spawn a powerup between 30-45 seconds.
-	if (!define.powerups.empty() && ::level.time >= m_nextPowerup)
+	if (::level.time >= m_nextPowerup)
 	{
-		const int offset = P_RandomInt(16) + 30;
-		m_nextPowerup = ::level.time + (offset * TICRATE);
+		// Inject horde powerups
+		hordeDefine_t def = G_HordeDefine(m_defineID);
 
-		const mobjtype_t pw = define.randomPowerup().mobj;
-		P_HordeSpawnPowerup(pw);
+		if (G_IsLivesGame())
+		{
+			// Add extra life/resurrect powerups when
+			if (g_horde_extralife.value() > 0.0f)
+			{
+				hordeDefine_t::powConfig_t config;
+				config.chance = g_horde_extralife.value();
+				def.addPowerup(MT_EXTRALIFE, config);
+			}
+
+
+
+			if (g_horde_resurrect.value() > 0.0f && PlayerQuery().notHasLives().execute().count > 0)
+			{
+				hordeDefine_t::powConfig_t config;
+				config.chance = g_horde_resurrect.value();
+				def.addPowerup(MT_RESTEAMMATE, config);
+			}
+		}
+
+		// Always try to spawn a powerup between 30-45 seconds.
+		if (!def.powerups.empty())
+		{
+			const int offset = P_RandomInt(16) + 30;
+			m_nextPowerup = ::level.time + (offset * TICRATE);
+
+			const mobjtype_t pw = def.randomPowerup().mobj;
+			P_HordeSpawnPowerup(pw);
+		}
 	}
 }
 
@@ -771,6 +866,8 @@ void P_RemoveHealthPool(AActor* mo)
 	// Unset the flag - we only get one try.
 	mo->oflags &= ~MFO_HEALTHPOOL;
 
+	::g_HordeDirector.decrementCount(mo);
+
 	::g_HordeDirector.addKilledHealth(::mobjinfo[mo->type].spawnhealth);
 }
 
@@ -818,7 +915,7 @@ void P_RunHordeTics()
 		{
 			if (::level.time == 0)
 			{
-				Printf(
+				PrintFmt(
 				    PRINT_WARNING,
 				    "WARNING: This map is missing Horde Monster, Horde Boss, Horde Supply Cache, "
 				    "or Horde Powerup spawns.  At least one of each must be present.\n");
@@ -935,13 +1032,14 @@ void P_HordePostLoad()
 		return;
 
 	::g_HordeDirector.rescanBosses();
+	::g_HordeDirector.recountMonsters();
 }
 
 BEGIN_COMMAND(hordewave)
 {
 	if (argc < 2)
 	{
-		Printf("hordewave - Restarts the current wave with a new definition\n"
+		PrintFmt("hordewave - Restarts the current wave with a new definition\n"
 		       "Usage:\n"
 		       "  ] hordewave <DEF NAME>\n"
 		       "  Starts the wave named DEF NAME.  The name can be partial.\n");
@@ -950,13 +1048,13 @@ BEGIN_COMMAND(hordewave)
 
 	if (!G_IsHordeMode())
 	{
-		Printf("Can't change the wave define outside of horde mode.\n");
+		PrintFmt("Can't change the wave define outside of horde mode.\n");
 		return;
 	}
 
 	if (!::g_HordeDirector.forceWave(argv[1]))
 	{
-		Printf("Could not find wave define starting with \"%s\"\n", argv[1]);
+		PrintFmt("Could not find wave define starting with \"{}\"\n", argv[1]);
 	}
 }
 END_COMMAND(hordewave)
@@ -965,7 +1063,7 @@ BEGIN_COMMAND(hordenextwave)
 {
 	if (!G_IsHordeMode())
 	{
-		Printf("Can't advance the wave outside of horde mode.\n");
+		PrintFmt("Can't advance the wave outside of horde mode.\n");
 		return;
 	}
 
@@ -977,17 +1075,17 @@ BEGIN_COMMAND(hordeboss)
 {
 	if (!G_IsHordeMode())
 	{
-		Printf("Can't spawn a horde boss outside of horde mode.\n");
+		PrintFmt("Can't spawn a horde boss outside of horde mode.\n");
 		return;
 	}
 
 	if (::g_HordeDirector.forceBoss())
 	{
-		Printf("Spawned the boss.\n");
+		PrintFmt("Spawned the boss.\n");
 	}
 	else
 	{
-		Printf("Could not spawn a boss.\n");
+		PrintFmt("Could not spawn a boss.\n");
 	}
 }
 END_COMMAND(hordeboss)
@@ -1000,7 +1098,7 @@ BEGIN_COMMAND(hordeinfo)
 {
 	if (!G_IsHordeMode())
 	{
-		Printf("Can't obtain horde info outside of horde mode.\n");
+		PrintFmt("Can't obtain horde info outside of horde mode.\n");
 		return;
 	}
 
@@ -1012,22 +1110,22 @@ BEGIN_COMMAND(hordeinfo)
 
 	const hordeDefine_t& define = G_HordeDefine(::g_HordeDirector.getDefineID());
 
-	Printf("[Define: %s]\n", define.name);
-	Printf("Weapons: %s\n", JoinStrings(define.weaponStrings(NULL), " "));
-	Printf("Min Group Health: %d\n", define.minGroupHealth);
-	Printf("Max Group Health: %d (Difficulty: %s)\n", define.maxGroupHealth,
-	       define.difficulty(false));
-	Printf("Min Total Health: %d = waveMaxGroup:%d * g_horde_mintotalhp:%s * "
-	       "skillLevel:%0.2f\n",
-	       define.minTotalHealth(), define.maxGroupHealth, ::g_horde_mintotalhp.str(),
-	       skillScaler);
-	Printf("Max Total Health: %d = waveMaxGroup:%d * g_horde_maxtotalhp:%s * "
-	       "skillLevel:%0.2f\n",
-	       define.maxTotalHealth(), define.maxGroupHealth, ::g_horde_maxtotalhp.str(),
-	       skillScaler);
-	Printf("Goal Health: %d = waveMaxGroup:%d * g_horde_goalhp:%s * skillLevel:%0.2f\n",
-	       define.goalHealth(), define.maxGroupHealth, ::g_horde_goalhp.str(),
-	       skillScaler);
+	PrintFmt("[Define: {}]\n", define.name);
+	PrintFmt("Weapons: {}\n", JoinStrings(define.weaponStrings(NULL), " "));
+	PrintFmt("Min Group Health: {}\n", define.minGroupHealth);
+	PrintFmt("Max Group Health: {} (Difficulty: {})\n", define.maxGroupHealth,
+	         define.difficulty(false));
+	PrintFmt("Min Total Health: {} = waveMaxGroup:{} * g_horde_mintotalhp:{} * "
+	         "skillLevel:{:0.2f}\n",
+	         define.minTotalHealth(), define.maxGroupHealth, ::g_horde_mintotalhp.str(),
+	         skillScaler);
+	PrintFmt("Max Total Health: {} = waveMaxGroup:{} * g_horde_maxtotalhp:{} * "
+	         "skillLevel:{:0.2f}\n",
+	         define.maxTotalHealth(), define.maxGroupHealth, ::g_horde_maxtotalhp.str(),
+	         skillScaler);
+	PrintFmt("Goal Health: {} = waveMaxGroup:{} * g_horde_goalhp:{} * skillLevel:{:0.2f}\n",
+	         define.goalHealth(), define.maxGroupHealth, ::g_horde_goalhp.str(),
+	         skillScaler);
 
 	const char* stateStr = NULL;
 	switch (::g_HordeDirector.serialize().state)
@@ -1049,23 +1147,23 @@ BEGIN_COMMAND(hordeinfo)
 	int min, max;
 	::g_HordeDirector.getNextSpawnTime(min, max);
 
-	Printf("[Wave: %d]\n", ::g_HordeDirector.serialize().wave);
-	Printf("State: %s\n", stateStr);
+	PrintFmt("[Wave:{}d]\n", ::g_HordeDirector.serialize().wave);
+	PrintFmt("State: {}\n", stateStr);
 
 	if (::g_HordeDirector.getAliveHealth() <= define.maxTotalHealth())
 	{
-		Printf("Current Spawn Rate: %d-%dsec\n", min, max);
+		PrintFmt("Current Spawn Rate: {}-{}sec\n", min, max);
 	}
 	else
 	{
-		Printf("Current Spawn Rate: PAUSED (Above Max Health)\n");
+		PrintFmt("Current Spawn Rate: PAUSED (Above Max Health)\n");
 	}
-	Printf("Empty/Full Spawn Rate: %d-%dsec, %d-%dsec\n", g_horde_spawnempty_min.asInt(),
-	       g_horde_spawnempty_max.asInt(), g_horde_spawnfull_min.asInt(),
-	       g_horde_spawnfull_max.asInt());
-	Printf("Alive Health: %d\n", ::g_HordeDirector.serialize().alive());
-	Printf("Killed Health: %d\n", ::g_HordeDirector.serialize().killed());
-	Printf("Boss Health: %d\n", ::g_HordeDirector.serialize().bossHealth);
-	Printf("Boss Damage: %d\n", ::g_HordeDirector.serialize().bossDamage);
+	PrintFmt("Empty/Full Spawn Rate: {}-{}sec, {}-{}sec\n", g_horde_spawnempty_min.asInt(),
+	         g_horde_spawnempty_max.asInt(), g_horde_spawnfull_min.asInt(),
+	         g_horde_spawnfull_max.asInt());
+	PrintFmt("Alive Health: {}\n", ::g_HordeDirector.serialize().alive());
+	PrintFmt("Killed Health: {}\n", ::g_HordeDirector.serialize().killed());
+	PrintFmt("Boss Health: {}\n", ::g_HordeDirector.serialize().bossHealth);
+	PrintFmt("Boss Damage: {}\n", ::g_HordeDirector.serialize().bossDamage);
 }
 END_COMMAND(hordeinfo)
