@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: f49b9453e314b327a8e8e10b34fa0c59ad1c5b62 $
+// $Id: 714df117d013cd7ba6e6513d38797b84fc5c4874 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -25,16 +25,18 @@
 
 #include <vector>
 
-#include "info.h"
 #include "d_player.h"
+#include "info.h"
 
 struct hordeRecipe_t
 {
 	mobjtype_t type;
 	int count;
+	int limit;
+	int totalCount;
 	bool isBoss;
 
-	hordeRecipe_t() : type(MT_NULL), count(0), isBoss(false) { }
+	hordeRecipe_t() : type(MT_NULL), count(0), limit(0), totalCount(0), isBoss(false) { }
 
 	hordeRecipe_t& operator=(const hordeRecipe_t& other)
 	{
@@ -43,6 +45,8 @@ struct hordeRecipe_t
 
 		type = other.type;
 		count = other.count;
+		limit = other.limit;
+		totalCount = other.totalCount;
 		isBoss = other.isBoss;
 
 		return *this;
@@ -52,13 +56,12 @@ struct hordeRecipe_t
 	{
 		type = MT_NULL;
 		count = 0;
+		limit = 0;
+		totalCount = 0;
 		isBoss = false;
 	}
 
-	bool isValid() const
-	{
-		return type != MT_NULL && count > 0;
-	}
+	bool isValid() const { return type != MT_NULL && count > 0; }
 };
 
 struct hordeDefine_t
@@ -86,8 +89,10 @@ struct hordeDefine_t
 	{
 		int minGroupHealth;
 		int maxGroupHealth;
+		int limit;
 		float chance;
-		monConfig_t() : minGroupHealth(-1), maxGroupHealth(-1), chance(1.0f) { }
+		monConfig_t()
+		    : minGroupHealth(-1), maxGroupHealth(-1), limit(-1), chance(1.0f) { }
 	};
 
 	struct monster_t
@@ -109,8 +114,8 @@ struct hordeDefine_t
 	powerups_t powerups; // Powerups we can spawn this wave.
 	int minGroupHealth;  // Minimum health of a group of monsters to spawn.
 	int maxGroupHealth;  // Maximum health of a group of monsters to spawn.
-	int minBossHealth;  // Minimum health of a group of bosses to spawn.
-	int maxBossHealth;  // Maximum health of a group of bosses to spawn.
+	int minBossHealth;   // Minimum health of a group of bosses to spawn.
+	int maxBossHealth;   // Maximum health of a group of bosses to spawn.
 
 	hordeDefine_t()
 	    : minGroupHealth(-1), maxGroupHealth(-1), minBossHealth(-1),
@@ -129,10 +134,25 @@ struct hordeDefine_t
 	StringTokens weaponStrings(player_t* player) const;
 };
 
+template <>
+struct hashfunc<mobjtype_t>
+{
+	unsigned int operator()(mobjtype_t val) const
+	{
+		if (sizeof(mobjtype_t) == 8)
+			return __hash_jenkins_64bit(val);
+		else
+			return __hash_jenkins_32bit(val);
+	}
+};
+
+typedef OHashTable<int32_t, int> mobjCounts_t;
+
 void G_ParseHordeDefs();
 const hordeDefine_t& G_HordeDefine(size_t id);
 
+int P_HordeMobjCount(const mobjCounts_t& counts, const mobjtype_t type);
 size_t P_HordePickDefine(const int current, const int total);
 bool P_HordeSpawnRecipe(hordeRecipe_t& out, const hordeDefine_t& define,
-                        const bool wantBoss);
+                        const bool wantBoss, const mobjCounts_t& monsterCounts);
 bool P_HordeDefineNamed(size_t& out, const std::string& name);
