@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: ef9b92eda3a03b8f3ffacb1ca921500fd3cbc1c7 $
+// $Id: 08410776c4caa654f11f6a1fb507c979797196f8 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -71,14 +71,18 @@ static bool CmpDist(const SpawnPointWeight& a, const SpawnPointWeight& b)
  * @return Actor pointer we just spawned, or NULL if the spawn failed.
  */
 static AActor::AActorPtr SpawnMonster(hordeSpawn_t& spawn, const hordeRecipe_t& recipe,
-                                      const v2fixed_t offset)
+                                      const v2fixed_t offset, mobjCounts_t& monsterCounts)
 {
+	int count = monsterCounts[recipe.type];
 	AActor* mo = new AActor(spawn.mo->x + offset.x, spawn.mo->y + offset.y, spawn.mo->z,
 	                        recipe.type);
 	if (mo)
 	{
 		if (P_TestMobjLocation(mo))
 		{
+			// update current count
+			monsterCounts[recipe.type] = count + 1;
+
 			if (recipe.isBoss)
 			{
 				// Heavy is the head that wears the crown.
@@ -121,42 +125,43 @@ static AActor::AActorPtr SpawnMonster(hordeSpawn_t& spawn, const hordeRecipe_t&
  * @return Actors spawned by this function.  Can be discarded.
  */
 static AActors SpawnMonsterGroup(hordeSpawn_t& spawn, const hordeRecipe_t& recipe,
-                                 const int count)
+                                 const int count, mobjCounts_t& monsterCounts)
 {
 	AActors ok;
 
-	const fixed_t rad = ::mobjinfo[recipe.type].radius;
-	const char* name = ::mobjinfo[recipe.type].name;
+	const mobjinfo_t& mobj = ::mobjinfo[recipe.type];
+	const fixed_t rad = mobj.radius;
+	const char* name = mobj.name;
 
 	if (count == 4)
 	{
 		// A big square.
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, -rad)));
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, -rad)));
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, rad)));
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, rad)));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, -rad), monsterCounts));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, -rad), monsterCounts));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, rad), monsterCounts));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, rad), monsterCounts));
 	}
 	else if (count == 3)
 	{
 		// A wedge.
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, -rad)));
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, -rad)));
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(0, rad)));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, -rad), monsterCounts));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, -rad), monsterCounts));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(0, rad), monsterCounts));
 	}
 	else if (count == 2)
 	{
 		// Next to each other.
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, 0)));
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, 0)));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(-rad, 0), monsterCounts));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(rad, 0), monsterCounts));
 	}
 	else if (count == 1)
 	{
 		// All by themselves :(
-		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(0, 0)));
+		ok.push_back(SpawnMonster(spawn, recipe, v2fixed_t(0, 0), monsterCounts));
 	}
 	else
 	{
-		Printf(PRINT_WARNING, "Invalid spawn count %d of %s.\n", count, name);
+		PrintFmt(PRINT_WARNING, "Invalid spawn count {} of {}.\n", count, name);
 	}
 
 	// Remove unspawned actors - probably spawnblocked.
@@ -268,7 +273,7 @@ hordeSpawn_t* P_HordeSpawnPoint(const hordeRecipe_t& recipe)
 	SpawnPointWeights weights;
 	for (auto& spawn : monsterSpawns)
 	{
-		mobjinfo_t& info = ::mobjinfo[recipe.type];
+		const mobjinfo_t& info = ::mobjinfo[recipe.type];
 		const bool isFlying = info.flags & (MF_NOGRAVITY | MF_FLOAT);
 
 		if (recipe.isBoss && spawn.type != TTYPE_HORDE_BOSS &&
@@ -398,7 +403,8 @@ hordeSpawn_t* P_HordeSpawnPoint(const hordeRecipe_t& recipe)
  * @param recipe Recipe of a monster to spawn.
  * @return Actors spawned by this function.  Can be discarded.
  */
-AActors P_HordeSpawn(hordeSpawn_t& spawn, const hordeRecipe_t& recipe)
+AActors P_HordeSpawn(hordeSpawn_t& spawn, const hordeRecipe_t& recipe,
+                     mobjCounts_t& monsterCounts)
 {
 	AActors ok;
 
@@ -444,7 +450,7 @@ AActors P_HordeSpawn(hordeSpawn_t& spawn, const hordeRecipe_t& recipe)
 
 		int groupIter = clamp(left, 1, maxGroupSize);
 
-		AActors okIter = SpawnMonsterGroup(*weight.spawn, recipe, groupIter);
+		AActors okIter = SpawnMonsterGroup(*weight.spawn, recipe, groupIter, monsterCounts);
 		ok.insert(ok.end(), okIter.begin(), okIter.end());
 	}
 
