@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: cd7a468d3a2be7ab4bd597a92e10995d114270be $
+// $Id: b39e87dcaa3bad85558e94c3c0373b634d5d88f3 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -30,7 +30,9 @@
 #include "m_bbox.h"
 
 #include "p_local.h"
+#include "p_mobj.h"
 #include "r_data.h"
+#include "m_random.h"
 
 // State.
 #include "r_state.h"
@@ -488,7 +490,7 @@ void P_LineOpening (const line_t *linedef, fixed_t x, fixed_t y, fixed_t refx, f
 			usefront = true;
 		else if (bflevel)
 			usefront = false;
-		else if (refx != MINFIXED)
+		else if (refx != limits::MINFIXED)
 			usefront = !P_PointOnLineSide(refx, refy, linedef);
 	}
 
@@ -735,7 +737,7 @@ bool P_BlockThingsIterator (int x, int y, bool(*func)(AActor*), AActor *actor)
 // INTERCEPT ROUTINES
 //
 // denis - make intercepts array resizeable
-TArray<intercept_t> intercepts;
+std::vector<intercept_t> intercepts;
 
 divline_t		trace;
 bool 			earlyout;
@@ -796,7 +798,7 @@ bool PIT_AddLineIntercepts (line_t *ld)
 	intercept.frac = frac;
 	intercept.isaline = true;
 	intercept.d.line = ld;
-	intercepts.Push(intercept);
+	intercepts.push_back(intercept);
 
 	return true;		// continue
 }
@@ -862,7 +864,7 @@ bool PIT_AddThingIntercepts (AActor* thing)
 	intercept.frac = frac;
 	intercept.isaline = false;
 	intercept.d.thing = thing;
-	intercepts.Push(intercept);
+	intercepts.push_back(intercept);
 
 	return true;				// keep going
 }
@@ -875,20 +877,19 @@ bool PIT_AddThingIntercepts (AActor* thing)
 //
 bool P_TraverseIntercepts (traverser_t func, fixed_t maxfrac)
 {
-	size_t 				count = intercepts.Size();
+	size_t 				count = intercepts.size();
 	fixed_t 			dist;
-	size_t		scan;
 	intercept_t*		in = 0;
 
 	while (count--)
 	{
-		dist = MAXINT;
-		for (scan = 0 ; scan < intercepts.Size(); scan++)
+		dist = limits::MAXFIXED;
+		for (intercept_t& intercept : intercepts)
 		{
-			if (intercepts[scan].frac < dist)
+			if (intercept.frac < dist)
 			{
-				dist = intercepts[scan].frac;
-				in = &intercepts[scan];
+				dist = intercept.frac;
+				in = &intercept;
 			}
 		}
 
@@ -899,7 +900,7 @@ bool P_TraverseIntercepts (traverser_t func, fixed_t maxfrac)
 		if ( !func (in) )
 			return false;		// don't bother going farther
 
-		in->frac = MAXINT;
+		in->frac = limits::MAXFIXED;
 	}
 
 	return true;				// everything was traversed
@@ -942,7 +943,7 @@ bool P_PathTraverse (fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2, int flags,
 
 	validcount++;
 
-	intercepts.Clear();
+	intercepts.clear();
 
 	if ( ((x1-bmaporgx)&(MAPBLOCKSIZE-1)) == 0)
 		x1 += FRACUNIT; // don't side exactly on a line
@@ -1195,70 +1196,48 @@ bool P_ActorInFOV(const AActor* origin, const AActor* mo , float f, fixed_t dist
 	return true;
 }
 
-
 //
-// P_RoughTargetSearch
+// RoughMonsterCheck
 // Searches though the surrounding mapblocks for monsters/players
 // based on Hexen's P_RoughMonsterSearch
 //
+// This allows friendlies (and hostiles) to target each other
+//
 // distance is in MAPBLOCKUNITS
 
-static AActor* RoughBlockCheck(AActor* mo, int index, angle_t fov)
+AActor* RoughMonsterCheck(AActor* mo, int index, angle_t fov)
 {
-	AActor* link;
-
-	link = blocklinks[index];
-	while (link)
+	const int bx = index % bmapwidth;
+	const int by = index / bmapwidth;
+	for (AActor* link = blocklinks[index]; link != nullptr; link = link->bmapnode.Next(bx, by))
 	{
 		// skip non-shootable actors
 		if (!(link->flags & MF_SHOOTABLE))
-		{
-			link = link->snext;
 			continue;
-		}
 
-		// skip the projectile's owner
-		if (link == mo->target)
-		{
-			link = link->snext;
+		// skip yourself
+		if (link == mo)
 			continue;
-		}
 
-		// [Blair] Don't target friendlies
-		if (P_IsFriendlyThing(mo->target, link))
-		{
-			link = link->snext;
+		// skip barrels and other shootable but not alive things
+		if (!sentient(link))
 			continue;
-		}
 
-		// [Blair] Don't target spectators
-		if (link->player && link->player->spectator)
-		{
-			link = link->snext;
+		// Don't target things friendly to you.
+		if (P_IsFriendlyThing(mo, link))
 			continue;
-		}
 
-		// [Blair] Don't target teammates
-		if (mo->target->player && link->player &&
-			P_AreTeammates((player_t&)mo->target->player, (player_t&)link->player))
-		{
-			link = link->snext;
+		// Don't target players or spectators (done elsewhere)
+		if (link->player || (link->player && link->player->spectator))
 			continue;
-		}
 
 		// skip actors outside of specified FOV
-		 if (fov > 0 && !P_CheckFov(mo, link, fov))
-		{
-			link = link->snext;
+		if (fov > 0 && !P_CheckFov(mo, link, fov))
 			continue;
-		}
 
 		// skip actors not in line of sight
 		if (!P_CheckSight(mo, link))
-		{
-			link = link->snext;
 			continue;
-		}
 
 		// all good! return it.
 		return link;
@@ -1268,7 +1247,59 @@ static AActor* RoughBlockCheck(AActor* mo, int index, angle_t fov)
 	return NULL;
 }
 
-AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance)
+//
+// RoughTracerCheck
+// Searches though the surrounding mapblocks for monsters/players
+// based on Hexen's P_RoughMonsterSearch
+//
+// Special logic to handle tracers (actor->target is owner of tracer)
+//
+// distance is in MAPBLOCKUNITS
+
+AActor* RoughTracerCheck(AActor* mo, int index, angle_t fov)
+{
+	const int bx = index % bmapwidth;
+	const int by = index / bmapwidth;
+	for (AActor* link = blocklinks[index]; link != nullptr; link = link->bmapnode.Next(bx, by))
+	{
+		// skip non-shootable actors
+		if (!(link->flags & MF_SHOOTABLE))
+			continue;
+
+		// skip the projectile's owner
+		if (link == mo->target)
+			continue;
+
+		// [Blair] Don't target friendlies
+		if (P_IsFriendlyThing(mo->target, link))
+			continue;
+
+		// [Blair] Don't target spectators
+		if (link->player && link->player->spectator)
+			continue;
+
+		// [Blair] Don't target teammates
+		if (mo->target->player && link->player &&
+			P_AreTeammates(*mo->target->player, *link->player))
+			continue;
+
+		// skip actors outside of specified FOV
+		if (fov > 0 && !P_CheckFov(mo, link, fov))
+			continue;
+
+		// skip actors not in line of sight
+		if (!P_CheckSight(mo, link))
+			continue;
+
+		// all good! return it.
+		return link;
+	}
+
+	// couldn't find a valid target
+	return NULL;
+}
+
+AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance, AActor* (*searchFunc)(AActor*, int, angle_t))
 {
 	int blockX;
 	int blockY;
@@ -1286,7 +1317,7 @@ AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance)
 
 	if (startX >= 0 && startX < bmapwidth && startY >= 0 && startY < bmapheight)
 	{
-		if ((target = RoughBlockCheck(mo, startY * bmapwidth + startX, fov)))
+		if ((target = searchFunc(mo, startY * bmapwidth + startX, fov)))
 		{ // found a target right away
 			return target;
 		}
@@ -1339,7 +1370,7 @@ AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance)
 		// Trace the first block section (along the top)
 		for (; blockIndex <= firstStop; blockIndex++)
 		{
-			if ((target = RoughBlockCheck(mo, blockIndex, fov)))
+			if ((target = searchFunc(mo, blockIndex, fov)))
 			{
 				return target;
 			}
@@ -1347,7 +1378,7 @@ AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance)
 		// Trace the second block section (right edge)
 		for (blockIndex--; blockIndex <= secondStop; blockIndex += bmapwidth)
 		{
-			if ((target = RoughBlockCheck(mo, blockIndex, fov)))
+			if ((target = searchFunc(mo, blockIndex, fov)))
 			{
 				return target;
 			}
@@ -1355,7 +1386,7 @@ AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance)
 		// Trace the third block section (bottom edge)
 		for (blockIndex -= bmapwidth; blockIndex >= thirdStop; blockIndex--)
 		{
-			if ((target = RoughBlockCheck(mo, blockIndex, fov)))
+			if ((target = searchFunc(mo, blockIndex, fov)))
 			{
 				return target;
 			}
@@ -1363,7 +1394,7 @@ AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance)
 		// Trace the final block section (left edge)
 		for (blockIndex++; blockIndex > finalStop; blockIndex -= bmapwidth)
 		{
-			if ((target = RoughBlockCheck(mo, blockIndex, fov)))
+			if ((target = searchFunc(mo, blockIndex, fov)))
 			{
 				return target;
 			}
@@ -1372,4 +1403,4 @@ AActor* P_RoughTargetSearch(AActor* mo, angle_t fov, int distance)
 	return NULL;
 }
 
-VERSION_CONTROL (p_maputl_cpp, "$Id: cd7a468d3a2be7ab4bd597a92e10995d114270be $")
+VERSION_CONTROL (p_maputl_cpp, "$Id: b39e87dcaa3bad85558e94c3c0373b634d5d88f3 $")
