@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 198bb98e8834b439899453a72dc5514885eecb97 $
+// $Id: 00154d823217db7ee789e1605aa198f968a471d3 $
 //
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -31,8 +31,7 @@
 class AActor;
 class player_s;
 typedef player_s player_t;
-struct sector_s;
-typedef sector_s sector_t;
+struct sector_t;
 struct line_s;
 typedef line_s line_t;
 
