@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 74844a362d6a93b3d69434d2257bb8999faf0809 $
+// $Id: c57359b2a2590cd86dceae63fe1c7ea70ca3d15b $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -1007,7 +1007,7 @@ private:
 		int tag, fixed_t speed, fixed_t speed2, fixed_t height,
 		bool crush, int silent, int change);
 	friend bool EV_CeilingCrushStop (int tag);
-	friend void P_ActivateInStasisCeiling (int tag);
+	friend bool P_ActivateInStasisCeiling (int tag);
 	friend bool EV_ZDoomCeilingCrushStop(int tag, bool remove);
 };
 
