@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 9f0ec6ae3e4d1a11f6b873219fee4e79b0dd01c4 $
+// $Id: 6ad2ccbbaeb857ebb53c9e612d2a9b5f7e849b7c $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -934,7 +934,7 @@ void P_SetPlayerPowerupStatuses(player_t* player, int powers[NUMPOWERS])
 	else
 		player->mo->statusflags &= ~SF_IRONFEET;
 
-		if (powers[pw_allmap])
+	if (powers[pw_allmap])
 		player->mo->statusflags |= SF_ALLMAP;
 	else
 		player->mo->statusflags &= ~SF_ALLMAP;
@@ -1206,11 +1206,11 @@ const char* PlayerState(size_t state)
 	}
 }
 
-#define STATE_NUM(mo) (mo -> state - states)
+#define STATE_NUM(mo) (mo->state->statenum)
 
 BEGIN_COMMAND(cheat_players)
 {
-	Printf("== PLAYERS ==");
+	PrintFmt("== PLAYERS ==");
 
 	int dead = 0;
 
@@ -1229,20 +1229,20 @@ BEGIN_COMMAND(cheat_players)
 
 			if (mo->player)
 			{
-				Printf("%.3u: %s\n", mo->player->id,
-				       mo->player->userinfo.netname);
+				PrintFmt("{:03d}: {}\n", mo->player->id,
+				         mo->player->userinfo.netname);
 			}
 			else
 			{
-				Printf("???: ???\n");
+				PrintFmt("???: ???\n");
 			}
-			Printf("State: %s\n", PlayerState(mo->state - states));
-			Printf("%f, %f, %f\n", FIXED2FLOAT(mo->x), FIXED2FLOAT(mo->y),
-			       FIXED2FLOAT(mo->z));
+			PrintFmt("State: {}\n", PlayerState(mo->state->statenum));
+			PrintFmt("{}, {}, {}\n", FIXED2FLOAT(mo->x), FIXED2FLOAT(mo->y),
+			         FIXED2FLOAT(mo->z));
 		}
 	}
 
-	Printf("== Skipped %d dead players ==\n", dead);
+	PrintFmt("== Skipped {} dead players ==\n", dead);
 }
 END_COMMAND(cheat_players)
 
@@ -1432,9 +1432,9 @@ player_s::player_s() :
 	ArrayInit(powers, 0);
 	ArrayInit(cards, false);
 	ArrayInit(flags, false);
-	ArrayInit(weaponowned, false);
-	ArrayInit(ammo, false);
-	ArrayInit(maxammo, false);
+	weaponowned.fill(false);
+	ammo.fill(false);
+	maxammo.fill(false);
 
 	// Can't put this in initializer list?
 	attacker = AActor::AActorPtr();
@@ -1452,6 +1452,9 @@ player_s::player_s() :
 
 player_s &player_s::operator =(const player_s &other)
 {
+	if (this == &other)
+		return *this;
+
 	id = other.id;
 	playerstate = other.playerstate;
 	mo = other.mo;
@@ -1489,9 +1492,9 @@ player_s &player_s::operator =(const player_s &other)
 	pendingweapon = other.pendingweapon;
 	readyweapon = other.readyweapon;
 
-	ArrayCopy(weaponowned, other.weaponowned);
-	ArrayCopy(ammo, other.ammo);
-	ArrayCopy(maxammo, other.maxammo);
+	weaponowned = other.weaponowned;
+	ammo = other.ammo;
+	maxammo = other.maxammo;
 
 	attackdown = other.attackdown;
 	usedown = other.usedown;
@@ -1562,4 +1565,4 @@ player_s::~player_s()
 {
 }
 
-VERSION_CONTROL (p_user_cpp, "$Id: 9f0ec6ae3e4d1a11f6b873219fee4e79b0dd01c4 $")
+VERSION_CONTROL (p_user_cpp, "$Id: 6ad2ccbbaeb857ebb53c9e612d2a9b5f7e849b7c $")
