@@ -1,7 +1,7 @@
-// Emacs style mode select   -*- C++ -*- 
+// Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 8ef404a198e7008c8ab8d00a7948511360190625 $
+// $Id: 04af2d197c661ee684ed590307219406e6bfa6be $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -42,8 +42,8 @@
 
 // EXTERNAL FUNCTION PROTOTYPES --------------------------------------------
 
-BOOL PO_MovePolyobj (int num, int x, int y);
-BOOL PO_RotatePolyobj (int num, angle_t angle);
+bool PO_MovePolyobj (int num, int x, int y);
+bool PO_RotatePolyobj (int num, angle_t angle);
 void PO_Init (void);
 
 // PRIVATE FUNCTION PROTOTYPES ---------------------------------------------
@@ -55,10 +55,10 @@ static void RotatePt (int an, fixed_t *x, fixed_t *y, fixed_t startSpotX,
 	fixed_t startSpotY);
 static void UnLinkPolyobj (polyobj_t *po);
 static void LinkPolyobj (polyobj_t *po);
-static BOOL CheckMobjBlocking (seg_t *seg, polyobj_t *po);
+static bool CheckMobjBlocking (seg_t *seg, polyobj_t *po);
 static void InitBlockMap (void);
 static void IterFindPolySegs (int x, int y, seg_t **segList);
-static void SpawnPolyobj (int index, int tag, BOOL crush);
+static void SpawnPolyobj (int index, int tag, bool crush);
 static void TranslateToStartSpot (int tag, int originX, int originY);
 static void DoMovePolyobj (polyobj_t *po, int x, int y);
 
@@ -202,8 +202,8 @@ void DRotatePoly::RunThink ()
 //
 // EV_RotatePoly
 //
-BOOL EV_RotatePoly (line_t *line, int polyNum, int speed, int byteAngle,
-					int direction, BOOL overRide)
+bool EV_RotatePoly (line_t *line, int polyNum, int speed, int byteAngle,
+					int direction, bool overRide)
 {
 	int mirror;
 	DRotatePoly *pe;
@@ -218,7 +218,7 @@ BOOL EV_RotatePoly (line_t *line, int polyNum, int speed, int byteAngle,
 	}
 	else
 	{
-		I_Error("EV_RotatePoly: Invalid polyobj num: %d\n", polyNum);
+		I_Error("EV_RotatePoly: Invalid polyobj num: {}\n", polyNum);
 	}
 	pe = new DRotatePoly (polyNum);
 	if (byteAngle)
@@ -239,7 +239,7 @@ BOOL EV_RotatePoly (line_t *line, int polyNum, int speed, int byteAngle,
 	pe->m_Speed = (speed*direction*(ANG90/64))>>3;
 	poly->specialdata = pe;
 	SN_StartSequence (poly, poly->seqType, SEQ_DOOR);
-	
+
 	while ( (mirror = GetPolyobjMirror( polyNum)) )
 	{
 		poly = GetPolyobj(mirror);
@@ -270,7 +270,7 @@ BOOL EV_RotatePoly (line_t *line, int polyNum, int speed, int byteAngle,
 		}
 		else
 		{
-			I_Error ("EV_RotatePoly: Invalid polyobj num: %d\n", polyNum);
+			I_Error("EV_RotatePoly: Invalid polyobj num: {}\n", polyNum);
 		}
 		direction = -direction;
 		pe->m_Speed = (speed*direction*(ANG90/64))>>3;
@@ -313,8 +313,8 @@ void DMovePoly::RunThink ()
 //
 // EV_MovePoly
 //
-BOOL EV_MovePoly (line_t *line, int polyNum, int speed, angle_t angle,
-				  fixed_t dist, BOOL overRide)
+bool EV_MovePoly (line_t *line, int polyNum, int speed, angle_t angle,
+				  fixed_t dist, bool overRide)
 {
 	int mirror;
 	DMovePoly *pe;
@@ -330,7 +330,7 @@ BOOL EV_MovePoly (line_t *line, int polyNum, int speed, angle_t angle,
 	}
 	else
 	{
-		I_Error("EV_MovePoly: Invalid polyobj num: %d\n", polyNum);
+		I_Error("EV_MovePoly: Invalid polyobj num: {}\n", polyNum);
 	}
 	pe = new DMovePoly (polyNum);
 	pe->m_Dist = dist; // Distance
@@ -402,7 +402,7 @@ void DPolyDoor::RunThink ()
 					m_Direction = (ANG360>>ANGLETOFINESHIFT)-
 						m_Direction;
 					m_xSpeed = -m_xSpeed;
-					m_ySpeed = -m_ySpeed;					
+					m_ySpeed = -m_ySpeed;
 				}
 				else
 				{
@@ -477,7 +477,7 @@ void DPolyDoor::RunThink ()
 				m_Close = false;
 				SN_StartSequence (poly, poly->seqType, SEQ_DOOR);
 			}
-		}			
+		}
 		break;
 	default:
 		break;
@@ -487,7 +487,7 @@ void DPolyDoor::RunThink ()
 //
 // EV_OpenPolyDoor
 //
-BOOL EV_OpenPolyDoor (line_t *line, int polyNum, int speed, angle_t angle,
+bool EV_OpenPolyDoor (line_t *line, int polyNum, int speed, angle_t angle,
 					  int delay, int distance, podoortype_t type)
 {
 	int mirror;
@@ -503,7 +503,7 @@ BOOL EV_OpenPolyDoor (line_t *line, int polyNum, int speed, angle_t angle,
 	}
 	else
 	{
-		I_Error("EV_OpenPolyDoor: Invalid polyobj num: %d\n", polyNum);
+		I_Error("EV_OpenPolyDoor: Invalid polyobj num: {}\n", polyNum);
 	}
 	pd = new DPolyDoor (polyNum, type);
 	if (type == PODOOR_SLIDE)
@@ -558,7 +558,7 @@ BOOL EV_OpenPolyDoor (line_t *line, int polyNum, int speed, angle_t angle,
 	}
 	return true;
 }
-	
+
 // ===== Higher Level Poly Interface code =====
 
 
@@ -711,7 +711,7 @@ static void UpdateSegBBox (seg_t *seg)
 //
 // PO_MovePolyobj
 //
-BOOL PO_MovePolyobj (int num, int x, int y)
+bool PO_MovePolyobj (int num, int x, int y)
 {
 	int count;
 	seg_t **segList;
@@ -720,7 +720,7 @@ BOOL PO_MovePolyobj (int num, int x, int y)
 
 	if (!(po = GetPolyobj (num)))
 	{
-		I_Error ("PO_MovePolyobj: Invalid polyobj number: %d\n", num);
+		I_Error("PO_MovePolyobj: Invalid polyobj number: {}\n", num);
 	}
 
 	UnLinkPolyobj (po);
@@ -818,7 +818,7 @@ static void RotatePt (int an, fixed_t *x, fixed_t *y, fixed_t startSpotX, fixed_
 //
 // PO_RotatePolyobj
 //
-BOOL PO_RotatePolyobj (int num, angle_t angle)
+bool PO_RotatePolyobj (int num, angle_t angle)
 {
 	int count;
 	seg_t **segList;
@@ -826,11 +826,11 @@ BOOL PO_RotatePolyobj (int num, angle_t angle)
 	vertex_t *prevPts;
 	int an;
 	polyobj_t *po;
-	BOOL blocked;
+	bool blocked;
 
 	if(!(po = GetPolyobj(num)))
 	{
-		I_Error("PO_RotatePolyobj: Invalid polyobj number: %d\n", num);
+		I_Error("PO_RotatePolyobj: Invalid polyobj number: {}\n", num);
 	}
 	an = (po->angle+angle)>>ANGLETOFINESHIFT;
 
@@ -1008,7 +1008,7 @@ static void LinkPolyobj (polyobj_t *po)
 				}
 				else
 				{
-					tempLink->next = (polyblock_t *)Z_Malloc (sizeof(polyblock_t), 
+					tempLink->next = (polyblock_t *)Z_Malloc (sizeof(polyblock_t),
 						PU_LEVEL, 0);
 					tempLink->next->next = NULL;
 					tempLink->next->prev = tempLink;
@@ -1023,14 +1023,14 @@ static void LinkPolyobj (polyobj_t *po)
 //
 // CheckMobjBlocking
 //
-static BOOL CheckMobjBlocking (seg_t *seg, polyobj_t *po)
+static bool CheckMobjBlocking (seg_t *seg, polyobj_t *po)
 {
 	AActor *mobj;
 	int i, j;
 	int left, right, top, bottom;
 	fixed_t tmbbox[4];
 	line_t *ld;
-	BOOL blocked;
+	bool blocked;
 
 	ld = seg->linedef;
 
@@ -1129,13 +1129,13 @@ static void IterFindPolySegs (int x, int y, seg_t **segList)
 			return;
 		}
 	}
-	I_Error ("IterFindPolySegs: Non-closed Polyobj located.\n");
+	I_Error("IterFindPolySegs: Non-closed Polyobj located.\n");
 }
 
 //
 // SpawnPolyobj
 //
-static void SpawnPolyobj (int index, int tag, BOOL crush)
+static void SpawnPolyobj (int index, int tag, bool crush)
 {
 	int i;
 	int j;
@@ -1150,7 +1150,7 @@ static void SpawnPolyobj (int index, int tag, BOOL crush)
 		{
 			if (polyobjs[index].segs)
 			{
-				I_Error ("SpawnPolyobj: Polyobj %d already spawned.\n", tag);
+				I_Error("SpawnPolyobj: Polyobj {} already spawned.\n", tag);
 			}
 			segs[i].linedef->special = 0;
 			segs[i].linedef->args[0] = 0;
@@ -1189,7 +1189,7 @@ static void SpawnPolyobj (int index, int tag, BOOL crush)
 				{
 					if (!segs[i].linedef->args[1])
 					{
-						I_Error ("SpawnPolyobj: Explicit line missing order number (probably %d) in poly %d.\n",
+						I_Error("SpawnPolyobj: Explicit line missing order number (probably {}) in poly {}.\n",
 							j+1, tag);
 					}
 					if (segs[i].linedef->args[1] == j)
@@ -1199,7 +1199,7 @@ static void SpawnPolyobj (int index, int tag, BOOL crush)
 						psIndex++;
 						if (psIndex > PO_MAXPOLYSEGS)
 						{
-							I_Error ("SpawnPolyobj: psIndex > PO_MAXPOLYSEGS\n");
+							I_Error("SpawnPolyobj: psIndex > PO_MAXPOLYSEGS\n");
 						}
 					}
 				}
@@ -1225,7 +1225,7 @@ static void SpawnPolyobj (int index, int tag, BOOL crush)
 					if(segs[i].linedef->special == PO_LINE_EXPLICIT &&
 						segs[i].linedef->args[0] == tag)
 					{
-						I_Error ("SpawnPolyobj: Missing explicit line %d for poly %d\n",
+						I_Error("SpawnPolyobj: Missing explicit line {} for poly {}\n",
 							j, tag);
 					}
 				}
@@ -1249,7 +1249,7 @@ static void SpawnPolyobj (int index, int tag, BOOL crush)
 				(*polyobjs[index].segs)->linedef->args[2];
 		}
 		else
-			I_Error ("SpawnPolyobj: Poly %d does not exist\n", tag);
+			I_Error("SpawnPolyobj: Poly {} does not exist\n", tag);
 	}
 }
 
@@ -1279,12 +1279,11 @@ static void TranslateToStartSpot (int tag, int originX, int originY)
 	}
 	if (po == NULL)
 	{ // didn't match the tag with a polyobj tag
-		I_Error("TranslateToStartSpot: Unable to match polyobj tag: %d\n",
-			tag);
+		I_Error("TranslateToStartSpot: Unable to match polyobj tag: {}\n", tag);
 	}
 	if (po->segs == NULL)
 	{
-		I_Error ("TranslateToStartSpot: Anchor point located without a StartSpot point: %d\n", tag);
+		I_Error("TranslateToStartSpot: Anchor point located without a StartSpot point: {}\n", tag);
 	}
 	po->originalPts = (vertex_t *)Z_Malloc(po->numsegs*sizeof(vertex_t), PU_LEVEL, 0);
 	po->prevPts = (vertex_t *)Z_Malloc(po->numsegs*sizeof(vertex_t), PU_LEVEL, 0);
@@ -1331,7 +1330,7 @@ static void TranslateToStartSpot (int tag, int originX, int originY)
 	sub = P_PointInSubsector (avg.x<<FRACBITS, avg.y<<FRACBITS);
 	if (sub->poly != NULL)
 	{
-		I_Error ("PO_TranslateToStartSpot: Multiple polyobjs in a single subsector.\n");
+		I_Error("PO_TranslateToStartSpot: Multiple polyobjs in a single subsector.\n");
 	}
 	sub->poly = po;
 }
@@ -1387,7 +1386,7 @@ void PO_Init (void)
 	{
 		if (!polyobjs[polyIndex].originalPts)
 		{
-			I_Error ("PO_Init: StartSpot located without an Anchor point: %d\n",
+			I_Error("PO_Init: StartSpot located without an Anchor point: {}\n",
 				polyobjs[polyIndex].tag);
 		}
 	}
@@ -1397,7 +1396,7 @@ void PO_Init (void)
 //
 // PO_Busy
 //
-BOOL PO_Busy (int polyobj)
+bool PO_Busy (int polyobj)
 {
 	polyobj_t *poly;
 
@@ -1412,4 +1411,4 @@ BOOL PO_Busy (int polyobj)
 	}
 }
 
-VERSION_CONTROL (po_man_cpp, "$Id: 8ef404a198e7008c8ab8d00a7948511360190625 $")
+VERSION_CONTROL (po_man_cpp, "$Id: 04af2d197c661ee684ed590307219406e6bfa6be $")
