@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: db98d44ca0c05359d298e0c4d47421ab6a9712fd $
+// $Id: cda48c7773cf6076d34ab2ef34598242c72a91b4 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -48,6 +48,7 @@
 #include <cmath>
 
 #include <algorithm>
+#include <unordered_set>
 
 //
 // Graphics.
@@ -610,6 +611,11 @@ void R_InitTextures()
 		for (int i = 0; i < nummappatches; i++)
 		{
 			patchlookup[i] = W_CheckNumForName (name_p + i*8);
+
+			// [EB] some wads use the texture namespace but then still use those in pnames
+			if (patchlookup[i] == -1)
+				patchlookup[i] = W_CheckNumForName (name_p + i*8, ns_textures);
+
 			if (patchlookup[i] == -1)
 			{
 				// killough 4/17/98:
@@ -730,8 +736,6 @@ void R_InitTextures()
 //
 void R_InitFlats (void)
 {
-	int i;
-
 	firstflat = W_GetNumForName ("F_START") + 1;
 	lastflat = W_GetNumForName ("F_END") - 1;
 
@@ -745,7 +749,7 @@ void R_InitFlats (void)
 	// Create translation table for global animation.
 	flattranslation = new int[numflats+1];
 
-	for (i = 0; i < numflats; i++)
+	for (int i = 0; i < numflats; i++)
 		flattranslation[i] = i;
 
 	delete[] flatwarp;
@@ -1145,24 +1149,28 @@ void R_PrecacheLevel (void)
 		}
 	}
 
-	// Precache sprites.
-	memset (hitlist, 0, numsprites);
+	delete[] hitlist;
 
+	// Precache sprites.
 	{
 		AActor *actor;
 		TThinkerIterator<AActor> iterator;
+		std::unordered_set<int32_t> spriteHitlist;
 
+		// generate a unique list of all the sprites we hit in this level
 		while ( (actor = iterator.Next ()) )
-			hitlist[actor->sprite] = 1;
-	}
+		{
+			// [CMB] spritenum_t can now be negative so a new structure is needed
+			// [CMB] sprites is a pointer in order by index
+			spriteHitlist.insert(actor->sprite);
+		}
 
-	for (i = numsprites - 1; i >= 0; i--)
-	{
-		if (hitlist[i])
-			R_CacheSprite (sprites + i);
+		// cache each of the sprites
+		for (auto sprite : spriteHitlist)
+		{
+			R_CacheSprite (&sprites[sprite]);
+		}
 	}
-
-	delete[] hitlist;
 }
 
 // Utility function,
@@ -1179,4 +1187,4 @@ unsigned int SlopeDiv (unsigned int num, unsigned int den)
 	return ans <= SLOPERANGE ? ans : SLOPERANGE;
 }
 
-VERSION_CONTROL (r_data_cpp, "$Id: db98d44ca0c05359d298e0c4d47421ab6a9712fd $")
+VERSION_CONTROL (r_data_cpp, "$Id: cda48c7773cf6076d34ab2ef34598242c72a91b4 $")
