@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 75198ecc3c5effea6f2aca37b98ac76607e9011d $
+// $Id: b7581a3a8b03ef695c456d37bd0fbb58390e83b4 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -21,14 +21,13 @@
 //
 //-----------------------------------------------------------------------------
 
-
 #pragma once
 
 extern int MaxVisSprites;
 
-extern vissprite_t *vissprites;
+extern vissprite_t *vissprites, *firstvissprite;
 
-extern spritedef_t* sprites;
+extern OHashTable<int32_t, spritedef_t> sprites;
 extern int numsprites;
 
 #define MAX_SPRITE_FRAMES 29 // [RH] Macro-ized as in BOOM.
@@ -40,5 +39,5 @@ extern int maxframe;
 
 extern vissprite_t* lastvissprite;
 
-void R_CacheSprite(spritedef_t *sprite);
-void R_InitSprites(const char** namelist);
+void R_CacheSprite(const spritedef_t *sprite);
+void R_InitSprites(std::vector<spriteinfo_t*>& sprites);
