@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: c77ebc923d57c54d0d72f28468bbc68977ba7b55 $
+// $Id: d76d23d305f4ccfe61f46ccd22b5c0dde5c423ba $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -65,7 +65,7 @@ extern int				numspritelumps;
 extern bool				g_ValidLevel;
 
 extern int				numsprites;
-extern spritedef_t* 	sprites;
+extern OHashTable<int32_t, spritedef_t> sprites;
 
 extern int				numvertexes;
 extern vertex_t*		vertexes;
@@ -88,6 +88,20 @@ extern line_t*			lines;
 extern int				numsides;
 extern side_t*			sides;
 
+inline nonstd::span<vertex_t>    R_GetVertices() { return nonstd::span(vertexes, numvertexes); }
+
+inline nonstd::span<seg_t>       R_GetSegs() { return nonstd::span(segs, numsegs); }
+
+inline nonstd::span<sector_t>    R_GetSectors() { return nonstd::span(sectors, numsectors); }
+
+inline nonstd::span<subsector_t> R_GetSubsectors() { return nonstd::span(subsectors, numsubsectors); }
+
+inline nonstd::span<node_t>      R_GetNodes() { return nonstd::span(nodes, numnodes); }
+
+inline nonstd::span<line_t>      R_GetLines() { return nonstd::span(lines, numlines); }
+
+inline nonstd::span<side_t>      R_GetSides() { return nonstd::span(sides, numsides); }
+
 extern std::vector<int> originalLightLevels;
 
 inline FArchive &operator<< (FArchive &arc, sector_t *sec)
