@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 1bf2474da20e3fc00f2e9e7b398732c31cf5b932 $
+// $Id: 4f93274536ac6326f8d7063bb711f5f1a2f408f0 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -929,7 +929,7 @@ void TextureManager::addTextureDirectory(const char* lumpname)
 				patch->originy = LESHORT(mpatch->originy);
 				patch->patch = mPNameLookup[LESHORT(mpatch->patch)];
 				if (patch->patch == -1)
-					Printf(PRINT_WARNING, "Res_InitTextures: Missing patch in texture %s\n", uname.c_str());
+					PrintFmt(PRINT_WARNING, "Res_InitTextures: Missing patch in texture {}\n", uname);
 			}
 
 			mTextureDefinitions.push_back(texdef);
@@ -1407,7 +1407,7 @@ void TextureManager::cachePNGTexture(texhandle_t handle)
 
 	if (!png_check_sig(lumpdata, 8))
 	{
-		Printf(PRINT_WARNING, "Bad PNG header in %s.\n", lumpname);
+		PrintFmt(PRINT_WARNING, "Bad PNG header in {}.\n", lumpname);
 		Res_PNGCleanup(&png_ptr, &info_ptr, &lumpdata, &row_data, &mfp);
 		return;
 	}
@@ -1415,7 +1415,7 @@ void TextureManager::cachePNGTexture(texhandle_t handle)
 	png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
 	if (!png_ptr)
 	{
-		Printf(PRINT_WARNING, "PNG out of memory reading %s.\n", lumpname);
+		PrintFmt(PRINT_WARNING, "PNG out of memory reading {}.\n", lumpname);
 		Res_PNGCleanup(&png_ptr, &info_ptr, &lumpdata, &row_data, &mfp);
 		return;
 	}
@@ -1423,7 +1423,7 @@ void TextureManager::cachePNGTexture(texhandle_t handle)
 	info_ptr = png_create_info_struct(png_ptr);
 	if (!info_ptr)
 	{
-		Printf(PRINT_WARNING, "PNG out of memory reading %s.\n", lumpname);
+		PrintFmt(PRINT_WARNING, "PNG out of memory reading {}.\n", lumpname);
 		Res_PNGCleanup(&png_ptr, &info_ptr, &lumpdata, &row_data, &mfp);
 		return;
     }
@@ -1441,7 +1441,7 @@ void TextureManager::cachePNGTexture(texhandle_t handle)
 
 	if (ret != 1)
 	{
-		Printf(PRINT_WARNING, "Bad PNG header in %s.\n", lumpname);
+		PrintFmt(PRINT_WARNING, "Bad PNG header in {}.\n", lumpname);
 		Res_PNGCleanup(&png_ptr, &info_ptr, &lumpdata, &row_data, &mfp);
 		return;
 	}
@@ -1615,4 +1615,4 @@ const Texture* TextureManager::getTexture(texhandle_t handle)
 }
 
 
-VERSION_CONTROL (res_texture_cpp, "$Id: 1bf2474da20e3fc00f2e9e7b398732c31cf5b932 $")
+VERSION_CONTROL (res_texture_cpp, "$Id: 4f93274536ac6326f8d7063bb711f5f1a2f408f0 $")
