@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 7263bab05baac89328218de259f90c8cff6dc903 $
+// $Id: 187e7ed23121ea93d302f50889ee8d4441ada1ec $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -699,9 +699,7 @@ void SN_StartSequence (polyobj_t *poly, int sequence, seqtype_t type)
 
 void SN_StartSequence (AActor *actor, const char *name)
 {
-	int i;
-
-	for (i = 0; i < NumSequences; i++)
+	for (int i = 0; i < NumSequences; i++)
 	{
 		if (!stricmp (name, Sequences[i]->name))
 		{
@@ -713,9 +711,7 @@ void SN_StartSequence (AActor *actor, const char *name)
 
 void SN_StartSequence (sector_t *sec, const char *name)
 {
-	int i;
-
-	for (i = 0; i < NumSequences; i++)
+	for (int i = 0; i < NumSequences; i++)
 	{
 		if (!stricmp (name, Sequences[i]->name))
 		{
@@ -727,9 +723,7 @@ void SN_StartSequence (sector_t *sec, const char *name)
 
 void SN_StartSequence (polyobj_t *poly, const char *name)
 {
-	int i;
-
-	for (i = 0; i < NumSequences; i++)
+	for (int i = 0; i < NumSequences; i++)
 	{
 		if (!stricmp (name, Sequences[i]->name))
 		{
@@ -944,11 +938,8 @@ ptrdiff_t SN_GetSequenceOffset (int sequence, unsigned int *sequencePtr)
 void SN_ChangeNodeData (int nodeNum, int seqOffset, int delayTics, float volume,
 	int currentSoundID)
 {
-	int i;
-	DSeqNode *node;
-
-	i = 0;
-	node = DSeqNode::FirstSequence();
+	int i = 0;
+	DSeqNode* node = DSeqNode::FirstSequence();
 	while (node && i < nodeNum)
 	{
 		node = node->NextSequence();
@@ -969,4 +960,4 @@ void DSeqNode::ChangeData (int seqOffset, int delayTics, float volume, int curre
 	m_CurrentSoundID = currentSoundID;
 }
 
-VERSION_CONTROL (s_sndseq_cpp, "$Id: 7263bab05baac89328218de259f90c8cff6dc903 $")
+VERSION_CONTROL (s_sndseq_cpp, "$Id: 187e7ed23121ea93d302f50889ee8d4441ada1ec $")
