@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 7ff2eb2457cc7850e25483cf23bcb8b1e38fb848 $
+// $Id: 2d04325c5b49b62901aa250f776d8c3ea4fdd4d5 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -25,8 +25,6 @@
 
 #include "m_fixed.h"
 
-#include <map>
-
 #define MAX_SNDNAME 63
 
 class AActor;
@@ -56,6 +54,31 @@ struct sfxinfo_struct
 	bool israndom;            // [DE] Whether or not this is an alias for a set of random sounds
 };
 
+enum class amb_type_t
+{
+	NONE,
+    POINT,
+    WORLD,
+};
+
+enum class amb_mode_t
+{
+	NONE,
+    CONTINUOUS,
+    RANDOM,
+    PERIODIC,
+};
+
+inline struct AmbientSound {
+	amb_type_t	type;		// Ambient sound type
+	amb_mode_t	mode;		// Ambient sound mode
+	int			periodmin;	// # of tics between repeats
+	int			periodmax;	// max # of tics for random ambients
+	float		volume;		// relative volume of sound
+	float		attenuation; // Used for distance scaling
+	char		sound[MAX_SNDNAME+1]; // Logical name of sound to play
+} Ambients[256];
+
 // the complete set of sound effects
 inline std::vector<sfxinfo_t> S_sfx;
 
@@ -142,8 +165,8 @@ void S_RelinkSound(AActor* from, AActor* to);
 // Start music using <music_name>
 void S_StartMusic(const char* music_name);
 
-// Start music using <music_name>, and set whether looping
-void S_ChangeMusic(std::string music_name, bool looping);
+// Start music using <music_name>, and set whether looping, and what MOD order to start from
+void S_ChangeMusic(std::string music_name, bool looping, int order = 0);
 
 // Stops the music fer sure.
 void S_StopMusic();
