@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 22957f32ae2b852025f625ae61878eb171b83736 $
+// $Id: 7771f1ca9f93659586d0bd3addf07bf87a11ee34 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -69,7 +69,7 @@ const char *FStat::getname()
 void FStat::dumpstat()
 {
 	for(size_t i = 0; i < stats.size(); i++)
-		Printf(PRINT_HIGH, "%s\n", stats[i]->getname());
+		PrintFmt(PRINT_HIGH, "{}\n", stats[i]->getname());
 }
 
 void FStat::dumpstat(std::string which)
@@ -81,14 +81,14 @@ void FStat::dumpstat(std::string which)
 
 void FStat::dump()
 {
-	Printf(PRINT_HIGH, "%s: %llums\n", name, last_elapsed);
+	PrintFmt(PRINT_HIGH, "{}: {}ms\n", name, last_elapsed);
 }
 
 BEGIN_COMMAND (stat)
 {
 	if (argc != 2)
 	{
-		Printf (PRINT_HIGH, "Usage: stat <statistics>\n");
+		PrintFmt(PRINT_HIGH, "Usage: stat <statistics>\n");
 		FStat::dumpstat ();
 	}
 	else
@@ -99,4 +99,4 @@ BEGIN_COMMAND (stat)
 END_COMMAND (stat)
 
 
-VERSION_CONTROL (stats_cpp, "$Id: 22957f32ae2b852025f625ae61878eb171b83736 $")
+VERSION_CONTROL (stats_cpp, "$Id: 7771f1ca9f93659586d0bd3addf07bf87a11ee34 $")
