@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 5e4144c9eef5e9ab934757cc7dd8cc26ccb8c6aa $
+// $Id: 728369765bc741f14e0e9b1f8f674a756b759dab $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -42,13 +42,20 @@
  */
 static bool IfGameZDoom(const std::string& str)
 {
-	if (!stricmp(str.c_str(), "doom") && ::gamemode != retail_chex &&
-	    ::gamemode != undetermined)
+	// TODO: should this account for rekkr too? uzdoom seems to just have
+	// doom, strife, heretic, hexen, and chex here
+	if (!stricmp(str.c_str(), "doom") && !IsChexMission(::gamemission) &&
+	    ::gamemode != undetermined && ::gamemission != commercial_hacx)
 	{
 		return true;
 	}
 
-	if (!stricmp(str.c_str(), "chex") && ::gamemode == retail_chex)
+	if (!stricmp(str.c_str(), "chex") && IsChexMission(::gamemission))
+	{
+		return true;
+	}
+
+	if (!stricmp(str.c_str(), "hacx") && ::gamemission == commercial_hacx)
 	{
 		return true;
 	}
@@ -378,7 +385,7 @@ void StringTable::setString(const OString& name, const OString& string)
 	StringHash::iterator it = _stringHash.find(name);
 	if (it == _stringHash.end())
 	{
-		// Stringtable entry does nto exist, insert it.
+		// Stringtable entry does not exist, insert it.
 		TableEntry entry = {std::make_pair(true, string), 0, -1};
 		_stringHash.emplace(name, entry);
 	}
@@ -421,4 +428,4 @@ size_t StringTable::size() const
 	return _stringHash.size();
 }
 
-VERSION_CONTROL(stringtable_cpp, "$Id: 5e4144c9eef5e9ab934757cc7dd8cc26ccb8c6aa $")
+VERSION_CONTROL(stringtable_cpp, "$Id: 728369765bc741f14e0e9b1f8f674a756b759dab $")
