@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 63a357048322fa481a6041b9c9a0ec507103b4d5 $
+// $Id: 58d7c54742d6b91c19efc46cba22e82265d8878d $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -24,50 +24,34 @@
 #include "odamex.h"
 #include "am_map.h"
 
-am_default_colors_t AutomapDefaultColors;
-am_colors_t AutomapDefaultCurrentColors;
-int am_cheating = 0;
-
-bool automapactive = false;
-
-bool AM_ClassicAutomapVisible()
-{
-	return automapactive && !viewactive;
-}
-
-bool AM_OverlayAutomapVisible()
-{
-	return automapactive && viewactive;
-}
-
 void AM_SetBaseColorDoom()
 {
-	
+
 }
 
 void AM_SetBaseColorRaven()
 {
-	
+
 }
 
 void AM_SetBaseColorStrife()
 {
-	
+
 }
 
 void AM_Start()
 {
-	
+
 }
 
-BOOL AM_Responder(event_t* ev)
+bool AM_Responder(event_t* ev)
 {
 	return false;
 }
 
 void AM_Drawer()
 {
-	
+
 }
 
-VERSION_CONTROL(am_map_cpp, "$Id: 63a357048322fa481a6041b9c9a0ec507103b4d5 $")
+VERSION_CONTROL(am_map_cpp, "$Id: 58d7c54742d6b91c19efc46cba22e82265d8878d $")
