@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 6f2b4417172514941a2a6d51c2335dc8016888cf $
+// $Id: 3a1cd939cd030bb9b8d096854b5679422c00522a $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom 1.22).
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
@@ -30,17 +30,7 @@
 #include "sv_main.h"
 #include "v_textcolors.h"
 
-int D_GenderToInt (const char *gender)
-{
-	if (!stricmp (gender, "female"))
-		return GENDER_FEMALE;
-	else if (!stricmp (gender, "cyborg"))
-		return GENDER_NEUTER;
-	else
-		return GENDER_MALE;
-}
-
-bool SetServerVar (const char *name, const char *value)
+bool SetServerVar (std::string_view name, const char *value)
 {
 	cvar_t *dummy;
 	cvar_t *var = cvar_t::FindCVar (name, &dummy);
@@ -59,7 +49,7 @@ bool SetServerVar (const char *name, const char *value)
 
 void D_SendServerInfoChange (const cvar_t *cvar, const char *value)
 {
-	SetServerVar(cvar->name(), value);
+	SetServerVar(cvar->name().c_str(), value);
 	SV_BroadcastPrintFmt("{}{} has been modified to {}!\n", TEXTCOLOR_YELLOW, cvar->name(), value);
 	SV_ServerSettingChange ();
 }
@@ -74,4 +64,4 @@ FArchive &operator>> (FArchive &arc, UserInfo &info) // removeme
 	return arc;
 }
 
-VERSION_CONTROL (d_netinfo_cpp, "$Id: 6f2b4417172514941a2a6d51c2335dc8016888cf $")
+VERSION_CONTROL (d_netinfo_cpp, "$Id: 3a1cd939cd030bb9b8d096854b5679422c00522a $")
