@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 4e1c5b6baba1b468b4f418214c58a2aba6460699 $
+// $Id: 64ec1c15d8c664c1c70aafca929c8dd8634f6078 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -194,7 +194,7 @@ void daemon_init(void)
     FILE   *fpid;
     string  pidfile;
 
-    Printf(PRINT_HIGH, "Launched into the background\n");
+    PrintFmt(PRINT_HIGH, "Launched into the background\n");
 
     if ((pid = fork()) != 0)
     {
@@ -307,4 +307,4 @@ int main (int argc, char **argv)
 
 #endif
 
-VERSION_CONTROL (i_main_cpp, "$Id: 4e1c5b6baba1b468b4f418214c58a2aba6460699 $")
+VERSION_CONTROL (i_main_cpp, "$Id: 64ec1c15d8c664c1c70aafca929c8dd8634f6078 $")
