@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: cf8ec973a67272c3bce66762134d88b65d660f79 $
+// $Id: fe8e3d224cdc8437532e33c1af995444ba34611d $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -42,9 +42,7 @@
     #include <process.h>
     #include <mmsystem.h>
     #include <direct.h> // SoM: I don't know HOW this has been overlooked until now...
-	#ifndef _XBOX
-		#include <winsock2.h>
-	#endif  // !_XBOX
+	#include <winsock2.h>
 #endif
 
 #ifdef UNIX
@@ -181,7 +179,7 @@ dtime_t I_GetTime()
 	clock_gettime(CLOCK_MONOTONIC, &ts);
 	return ts.tv_sec * 1000LL * 1000LL * 1000LL + ts.tv_nsec;
 
-#elif defined WIN32 && !defined _XBOX
+#elif defined WIN32
 	static bool initialized = false;
 	static LARGE_INTEGER initial_count;
 	static double nanoseconds_per_count;
@@ -250,7 +248,7 @@ void I_Sleep(dtime_t sleep_time)
 #if defined UNIX
 	usleep(sleep_time / 1000LL);
 
-#elif defined(WIN32) && !defined(_XBOX)
+#elif defined(WIN32)
 	Sleep(sleep_time / 1000000LL);
 
 #else
@@ -569,4 +567,4 @@ std::string I_ConsoleInput (void)
 }
 #endif
 
-VERSION_CONTROL (i_system_cpp, "$Id: cf8ec973a67272c3bce66762134d88b65d660f79 $")
+VERSION_CONTROL (i_system_cpp, "$Id: fe8e3d224cdc8437532e33c1af995444ba34611d $")
