@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 9aca37deef410ce703359d499d12dfa1dd9a5afb $
+// $Id: 13153fe400bb1f0d01ceb4cdacf9d22304717c84 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -82,15 +82,15 @@ void I_BaseError(const std::string& errortext);
 [[noreturn]] void I_BaseFatalError(const std::string& errortext);
 
 template <typename... ARGS>
-void I_Error(const fmt::string_view format, const ARGS&... args)
+void I_Error(fmt::format_string<ARGS...>format, ARGS&&... args)
 {
-	I_BaseError(fmt::format(format, args...));
+	I_BaseError(fmt::format(format, std::forward<ARGS>(args)...));
 }
 
 template <typename... ARGS>
-[[noreturn]] void I_FatalError(const fmt::string_view format, const ARGS&... args)
+[[noreturn]] void I_FatalError(fmt::format_string<ARGS...> format, ARGS&&... args)
 {
-	I_BaseFatalError(fmt::format(format, args...));
+	I_BaseFatalError(fmt::format(format, std::forward<ARGS>(args)...));
 }
 
 void addterm (void (STACK_ARGS *func)(void), const char *name);
