@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 8b850b59b232b0de20d0a1472b751708bd145d84 $
+// $Id: 9664cd4ffdd667dff69ed42f2dc8b766a4c5659a $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
@@ -393,7 +393,7 @@ bool G_CheckSpot (player_t &player, mapthing2_t *mthing)
 // zdoom 2.x still has it!
 static fixed_t PlayersRangeFromSpot (mapthing2_t *spot)
 {
-	fixed_t closest = MAXINT;
+	fixed_t closest = limits::MAXFIXED;
 	fixed_t distance;
 
 	for (const auto& player : players)
@@ -610,4 +610,4 @@ void G_DoReborn (player_t &player)
 	P_SpawnPlayer (player, &playerstarts[playernum%playerstarts.size()]);
 }
 
-VERSION_CONTROL (g_game_cpp, "$Id: 8b850b59b232b0de20d0a1472b751708bd145d84 $")
+VERSION_CONTROL (g_game_cpp, "$Id: 9664cd4ffdd667dff69ed42f2dc8b766a4c5659a $")
