@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 7060be419a0b7d95fb63b23ce0ce8aa99813d87d $
+// $Id: 54fe86133351dee73bf0ffc28b866f74c3408742 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
@@ -140,26 +140,16 @@ void G_DeferedReset()
 	gameaction = ga_resetlevel;
 }
 
-const char* GetBase(const char* in)
-{
-	const char* out = &in[strlen(in) - 1];
-
-	while (out > in && *(out-1) != PATHSEPCHAR)
-		out--;
-
-	return out;
-}
-
 BEGIN_COMMAND (wad) // denis - changes wads
 {
 	// [Russell] print out some useful info
 	if (argc == 1)
 	{
-	    Printf(PRINT_HIGH, "Usage: wad pwad [...] [deh/bex [...]]\n");
-	    Printf(PRINT_HIGH, "       wad iwad [pwad [...]] [deh/bex [...]]\n");
-	    Printf(PRINT_HIGH, "\n");
-	    Printf(PRINT_HIGH, "Load a wad file on the fly, pwads/dehs/bexs require extension\n");
-	    Printf(PRINT_HIGH, "eg: wad doom\n");
+	    PrintFmt(PRINT_HIGH, "Usage: wad pwad [...] [deh/bex [...]]\n");
+	    PrintFmt(PRINT_HIGH, "       wad iwad [pwad [...]] [deh/bex [...]]\n");
+	    PrintFmt(PRINT_HIGH, "\n");
+	    PrintFmt(PRINT_HIGH, "Load a wad file on the fly, pwads/dehs/bexs require extension\n");
+	    PrintFmt(PRINT_HIGH, "eg: wad doom\n");
 
 	    return;
 	}
@@ -188,8 +178,7 @@ EXTERN_CVAR(sv_shufflemaplist)
 
 bool isLastMap()
 {
-	return level.nextmap.empty() ||
-		std::any_of(
+	return std::any_of(
 			forcedlastmaps.entries.begin(), forcedlastmaps.entries.end(),
 			[&](const auto& entry) {
 				return entry.first == level.mapname && (entry.second.empty() || entry.second == level.nextmap);
@@ -224,6 +213,7 @@ OLumpName G_NextMap()
 			(((gamemode == registered && level.cluster == 3) ||
 			((gameinfo.flags & GI_MENUHACK_RETAIL) && level.cluster == 4))))
 		{
+			// FIXME: this doesn't play nicely with umapinfo defined episodes
 			next = CalcMapName(1, 1);
 		}
 		else
@@ -279,7 +269,7 @@ void G_ChangeMap()
 		// when onlcvars (addcommandstring's second param) is true.  Is there a
 		// reason why the mapscripts ahve to be safe mode?
 		if (strlen(sv_endmapscript.cstring()))
-			AddCommandString(sv_endmapscript.cstring());
+			AddCommandString(sv_endmapscript.str());
 	}
 }
 
@@ -288,7 +278,7 @@ void G_ChangeMap(size_t index) {
 	maplist_entry_t maplist_entry;
 	if (!Maplist::instance().get_map_by_index(index, maplist_entry)) {
 		// That maplist index doesn't actually exist
-		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error());
+		PrintFmt(PRINT_HIGH, "{}\n", Maplist::instance().get_error());
 		return;
 	}
 
@@ -303,7 +293,51 @@ void G_ChangeMap(size_t index) {
 	// when onlcvars (addcommandstring's second param) is true.  Is there a
 	// reason why the mapscripts ahve to be safe mode?
 	if(strlen(sv_endmapscript.cstring()))
-		AddCommandString(sv_endmapscript.cstring());
+		AddCommandString(sv_endmapscript.str());
+}
+
+// Determine first map to load on startup
+void G_ChangeMapStartup()
+{
+	unnatural_level_progression = false;
+
+	maplist_entry_t lobby_entry = Maplist::instance().get_lobbymap();
+
+	if (!Maplist::instance().lobbyempty())
+	{
+		std::string wadstr = C_EscapeWadList(lobby_entry.wads);
+		G_LoadWadString(wadstr, lobby_entry.map);
+	}
+	else
+	{
+		if (Maplist::instance().empty())
+		{
+			// We don't have a maplist, so grab the next 'natural' map lump.
+			G_DeferedInitNew(G_NextMap());
+		}
+		else
+		{
+			size_t this_index = 0;
+			// if gotomap was run before this, stay on map set by that
+			// otherwise this_index is unmodified, and go to first maplist entry
+			Maplist::instance().get_this_index(this_index);
+			maplist_entry_t maplist_entry;
+			Maplist::instance().get_map_by_index(this_index, maplist_entry);
+
+			std::string wadstr = C_EscapeWadList(maplist_entry.wads);
+			G_LoadWadString(wadstr, maplist_entry.map, maplist_entry.lastmaps);
+
+			// Set the new map as the current map
+			Maplist::instance().set_index(this_index);
+		}
+	}
+
+	// run script at the end of each map
+	// [ML] 8/22/2010: There are examples in the wiki that outright don't work
+	// when onlcvars (addcommandstring's second param) is true.  Is there a
+	// reason why the mapscripts ahve to be safe mode?
+	if (!sv_endmapscript.str().empty())
+		AddCommandString(sv_endmapscript.str());
 }
 
 // Restart the current map.
@@ -370,7 +404,7 @@ void G_DoNewGame()
 	// when onlcvars (addcommandstring's second param) is true.  Is there a
 	// reason why the mapscripts ahve to be safe mode?
 	if (strlen(sv_startmapscript.cstring()))
-		AddCommandString(sv_startmapscript.cstring());
+		AddCommandString(sv_startmapscript.str());
 
 	G_InitNew (d_mapname);
 	gameaction = ga_nothing;
@@ -399,8 +433,6 @@ void SV_ServerSettingChange();
 
 void G_InitNew(const char *mapname)
 {
-	size_t i;
-
 	DWORD previousLevelFlags = level.flags;
 
 	if (!savegamerestore)
@@ -442,38 +474,38 @@ void G_InitNew(const char *mapname)
 	{
 		if (wantFast)
 		{
-			for (i = 0; i < NUMSTATES; i++)
+			for (auto& [_, state] : states)
 			{
-				if (states[i].flags & STATEF_SKILL5FAST &&
-				    (states[i].tics != 1 || demoplayback))
-					states[i].tics >>= 1; // don't change 1->0 since it causes cycles
+				if (state.flags & STATEF_SKILL5FAST &&
+				    (state.tics != 1 || demoplayback))
+					state.tics >>= 1; // don't change 1->0 since it causes cycles
 			}
 
-			for (i = 0; i < NUMMOBJTYPES; ++i)
+			for (auto& [_, minfo] : mobjinfo)
 			{
-				if (mobjinfo[i].altspeed != NO_ALTSPEED)
+				if (minfo.altspeed != NO_ALTSPEED)
 				{
-					int swap = mobjinfo[i].speed;
-					mobjinfo[i].speed = mobjinfo[i].altspeed;
-					mobjinfo[i].altspeed = swap;
+					int swap = minfo.speed;
+					minfo.speed = minfo.altspeed;
+					minfo.altspeed = swap;
 				}
 			}
 		}
 		else
 		{
-			for (i = 0; i < NUMSTATES; i++)
+			for (auto& [_, state] : states)
 			{
-				if (states[i].flags & STATEF_SKILL5FAST)
-					states[i].tics <<= 1; // don't change 1->0 since it causes cycles
+				if (state.flags & STATEF_SKILL5FAST)
+					state.tics <<= 1; // don't change 1->0 since it causes cycles
 			}
 
-			for (i = 0; i < NUMMOBJTYPES; ++i)
+			for (auto& [_, minfo] : mobjinfo)
 			{
-				if (mobjinfo[i].altspeed != NO_ALTSPEED)
+				if (minfo.altspeed != NO_ALTSPEED)
 				{
-					int swap = mobjinfo[i].altspeed;
-					mobjinfo[i].altspeed = mobjinfo[i].speed;
-					mobjinfo[i].speed = swap;
+					int swap = minfo.altspeed;
+					minfo.altspeed = minfo.speed;
+					minfo.speed = swap;
 				}
 			}
 		}
@@ -689,7 +721,7 @@ void G_DoResetLevel(bool full_reset)
 		while ((mo = iterator.Next()))
 		{
 			// In sides-based games, destroy objectives that aren't relevant.
-			if (mo->netid && !CTF_ShouldSpawnHomeFlag(mo->type))
+			if (mo->netid && !CTF_ShouldSpawnHomeFlag(static_cast<mobjtype_t>(mo->type)))
 			{
 				CTF_ReplaceFlagWithWaypoint(mo);
 			}
@@ -938,7 +970,7 @@ void G_DoLoadLevel (int position)
 		TThinkerIterator<AActor> iterator;
 		while ((mo = iterator.Next()))
 		{
-			if (mo->netid && !CTF_ShouldSpawnHomeFlag(mo->type))
+			if (mo->netid && !CTF_ShouldSpawnHomeFlag(static_cast<mobjtype_t>(mo->type)))
 			{
 				CTF_ReplaceFlagWithWaypoint(mo);
 			}
@@ -993,4 +1025,4 @@ void G_WorldDone (void)
 }
 
 
-VERSION_CONTROL (g_level_cpp, "$Id: 7060be419a0b7d95fb63b23ce0ce8aa99813d87d $")
+VERSION_CONTROL (g_level_cpp, "$Id: 54fe86133351dee73bf0ffc28b866f74c3408742 $")
