@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 23b62c61c4e3fbc1e62bc3adda7a5df971b6cb24 $
+// $Id: 3587e81c90ba142c1e03dd144e38470378c1ab51 $
 //
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -56,24 +56,24 @@ void SV_BasePrint(client_t* cl, const int printlevel, const std::string& str);
 
 // Print directly to a specific client.
 template <typename... ARGS>
-void SV_ClientPrintFmt(client_t *cl, int level, const fmt::string_view format, const ARGS&... args)
+void SV_ClientPrintFmt(client_t *cl, int level, fmt::format_string<ARGS...> format, ARGS&&... args)
 {
-	SV_BasePrint(cl, level, fmt::format(format, args...));
+	SV_BasePrint(cl, level, fmt::format(format, std::forward<ARGS>(args)...));
 }
 
 // Print directly to a specific player.
 template <typename... ARGS>
-void SV_PlayerPrintFmt(int level, int player_id, const fmt::string_view format, const ARGS&... args)
+void SV_PlayerPrintFmt(int level, int player_id, fmt::format_string<ARGS...> format, ARGS&&... args)
 {
 	client_t* cl = &idplayer(player_id).client;
-	SV_ClientPrintFmt(cl, level, format, args...);
+	SV_ClientPrintFmt(cl, level, format, std::forward<ARGS>(args)...);
 }
 
 // Print to all spectators
 template <typename... ARGS>
-void SV_SpectatorPrintFmt(int level, const fmt::string_view format, const ARGS&... args)
+void SV_SpectatorPrintFmt(int level, fmt::format_string<ARGS...> format, ARGS&&... args)
 {
-	std::string string = fmt::format(format, args...);
+	std::string string = fmt::format(format, std::forward<ARGS>(args)...);
 	PrintFmt(level, "{}", string);  // print to the console
 
 	for (auto& player : players)
@@ -89,12 +89,12 @@ void SV_SpectatorPrintFmt(int level, const fmt::string_view format, const ARGS&.
 }
 
 template <typename... ARGS>
-void SV_TeamPrintFmt(int level, int who, const fmt::string_view format, const ARGS&... args)
+void SV_TeamPrintFmt(int level, int who, fmt::format_string<ARGS...> format, ARGS&&... args)
 {
 	if (sv_gametype != GM_TEAMDM && sv_gametype != GM_CTF)
 		return;
 
-	std::string string = fmt::format(format, args...);
+	std::string string = fmt::format(format, std::forward<ARGS>(args)...);
 	PrintFmt(level, "{}", string);  // print to the console
 
 	const team_t& team = idplayer(who).userinfo.team;
