@@ -1,7 +1,7 @@
-// Emacs style mode select   -*- C++ -*- 
+// Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: fac9be07f462e1a83f0ca8b8e117b025eba3f08e $
+// $Id: e4d29803b53efcac8e5553aa902e50af2e734aed $
 //
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -28,10 +28,9 @@
 #include "sv_main.h"
 #include "c_console.h"
 
-bool SV_AddMaster (const char *masterip);
 void SV_InitMasters();
-bool SV_AddMaster(const char *masterip);
 void SV_ListMasters ();
+bool SV_AddMaster(std::string_view masterip);
 bool SV_RemoveMaster (const char *masterip);
 void SV_UpdateMasterServers(void);
 void SV_UpdateMaster(void);
