@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b747f952e8013c5074d8465ebbf21f47e6ea8414 $
+// $Id: 0f9c0003c0f3d671de9aa96ff82d5d6a1ea8e734 $
 //
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -26,7 +26,6 @@
 
 #include "p_local.h"
 #include "sv_main.h"
-#include "huffman.h"
 #include "i_net.h"
 
 #ifdef SIMULATE_LATENCY
@@ -34,7 +33,7 @@
 #include <chrono>
 #endif
 
-QWORD I_MSTime (void);
+dtime_t I_MSTime (void);
 
 EXTERN_CVAR (log_packetdebug)
 #ifdef SIMULATE_LATENCY
@@ -209,7 +208,7 @@ bool SV_SendPacket(player_t &pl)
 
 	if (log_packetdebug)
 	{
-		Printf(PRINT_HIGH, "ply %03u, pkt %06u, size %04lu, tic %07u, time %011llu\n",
+		PrintFmt(PRINT_HIGH, "ply {:03}, pkt {:06}, size {:04}, tic {:07}, time {:011}\n",
 			   pl.id, cl->sequence - 1, sendd.cursize, gametic, I_MSTime());
 	}
 
@@ -268,8 +267,6 @@ void SV_AcknowledgePacket(player_t &player)
 
 	int sequence = MSG_ReadLong();
 
-	cl->compressor.packet_acked(sequence);
-
 	// packet is missed
 	if (sequence - cl->last_sequence > 1)
 	{
@@ -297,4 +294,4 @@ void SV_AcknowledgePacket(player_t &player)
 	}
 }
 
-VERSION_CONTROL (sv_rproto_cpp, "$Id: b747f952e8013c5074d8465ebbf21f47e6ea8414 $")
+VERSION_CONTROL (sv_rproto_cpp, "$Id: 0f9c0003c0f3d671de9aa96ff82d5d6a1ea8e734 $")
