@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: a297b18b0e66229a47de6073711febc0f6f3bf47 $
+// $Id: 5dea46c81f6589be466801742e76d96a4e8e759c $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -975,7 +975,7 @@ void Vote::parse(vote_result_t vote_result)
 		SV_BroadcastPrintFmt("Vote {} failed! (Yes: {}, No: {}, Abs: {})\n", this->votestring, yes, no, abs);
 
 		// Only set the timeout tic if the vote failed.
-		player_t caller = idplayer(this->caller_id);
+		player_t& caller = idplayer(this->caller_id);
 		if (validplayer(caller))
 		{
 			caller.timeout_callvote = level.time;
